@@ -6,6 +6,7 @@ package api4
 import (
 	"context"
 	"net/http"
+	"os"
 	"testing"
 
 	"github.com/mattermost/mattermost/server/public/model"
@@ -33,13 +34,12 @@ func setBasicCommonReviewerConfig(th *TestHelper) *model.AppError {
 
 func TestGetFlaggingConfiguration(t *testing.T) {
 	th := Setup(t)
-	defer th.TearDown()
 
 	client := th.Client
 
 	t.Run("Should return 501 when Enterprise Advanced license is not present even if feature is enabled", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterprise))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		th.App.UpdateConfig(func(config *model.Config) {
 			config.ContentFlaggingSettings.EnableContentFlagging = model.NewPointer(true)
@@ -54,7 +54,7 @@ func TestGetFlaggingConfiguration(t *testing.T) {
 
 	t.Run("Should return 501 when feature is disabled", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		th.App.UpdateConfig(func(config *model.Config) {
 			config.ContentFlaggingSettings.EnableContentFlagging = model.NewPointer(false)
@@ -69,14 +69,13 @@ func TestGetFlaggingConfiguration(t *testing.T) {
 }
 
 func TestSaveContentFlaggingSettings(t *testing.T) {
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	client := th.Client
 
 	t.Run("Should return 403 when user does not have manage system permission", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		config := model.ContentFlaggingSettingsRequest{
 			ContentFlaggingSettingsBase: model.ContentFlaggingSettingsBase{
@@ -93,7 +92,7 @@ func TestSaveContentFlaggingSettings(t *testing.T) {
 		}
 
 		// Use basic user who doesn't have manage system permission
-		th.LoginBasic()
+		th.LoginBasic(t)
 		resp, err := client.SaveContentFlaggingSettings(context.Background(), &config)
 		require.Error(t, err)
 		require.Equal(t, http.StatusForbidden, resp.StatusCode)
@@ -101,7 +100,7 @@ func TestSaveContentFlaggingSettings(t *testing.T) {
 
 	t.Run("Should return 400 when config is invalid", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		// Invalid config - missing required fields
 		config := model.ContentFlaggingSettingsRequest{
@@ -117,7 +116,7 @@ func TestSaveContentFlaggingSettings(t *testing.T) {
 		}
 		config.SetDefaults()
 
-		th.LoginSystemAdmin()
+		th.LoginSystemAdmin(t)
 		resp, err := th.SystemAdminClient.SaveContentFlaggingSettings(context.Background(), &config)
 		require.Error(t, err)
 		require.Equal(t, http.StatusBadRequest, resp.StatusCode)
@@ -125,7 +124,7 @@ func TestSaveContentFlaggingSettings(t *testing.T) {
 
 	t.Run("Should successfully save content flagging settings when user has manage system permission", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		config := model.ContentFlaggingSettingsRequest{
 			ContentFlaggingSettingsBase: model.ContentFlaggingSettingsBase{
@@ -149,15 +148,14 @@ func TestSaveContentFlaggingSettings(t *testing.T) {
 }
 
 func TestGetContentFlaggingSettings(t *testing.T) {
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	t.Run("Should return 403 when user does not have manage system permission", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		// Use basic user who doesn't have manage system permission
-		th.LoginBasic()
+		th.LoginBasic(t)
 		settings, resp, err := th.Client.GetContentFlaggingSettings(context.Background())
 		require.Error(t, err)
 		require.Equal(t, http.StatusForbidden, resp.StatusCode)
@@ -166,7 +164,7 @@ func TestGetContentFlaggingSettings(t *testing.T) {
 
 	t.Run("Should successfully get content flagging settings when user has manage system permission", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		// First save some settings
 		appErr := setBasicCommonReviewerConfig(th)
@@ -188,8 +186,7 @@ func TestGetContentFlaggingSettings(t *testing.T) {
 }
 
 func TestGetPostPropertyValues(t *testing.T) {
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	client := th.Client
 
@@ -200,7 +197,7 @@ func TestGetPostPropertyValues(t *testing.T) {
 			config.ContentFlaggingSettings.SetDefaults()
 		})
 
-		post := th.CreatePost()
+		post := th.CreatePost(t)
 		propertyValues, resp, err := client.GetPostPropertyValues(context.Background(), post.Id)
 		require.Error(t, err)
 		require.Equal(t, http.StatusNotImplemented, resp.StatusCode)
@@ -214,7 +211,7 @@ func TestGetPostPropertyValues(t *testing.T) {
 			config.ContentFlaggingSettings.SetDefaults()
 		})
 
-		post := th.CreatePost()
+		post := th.CreatePost(t)
 		propertyValues, resp, err := client.GetPostPropertyValues(context.Background(), post.Id)
 		require.Error(t, err)
 		require.Equal(t, http.StatusNotImplemented, resp.StatusCode)
@@ -241,7 +238,7 @@ func TestGetPostPropertyValues(t *testing.T) {
 			config.ContentFlaggingSettings.SetDefaults()
 		})
 
-		post := th.CreatePost()
+		post := th.CreatePost(t)
 		propertyValues, resp, err := client.GetPostPropertyValues(context.Background(), post.Id)
 		require.Error(t, err)
 		require.Equal(t, http.StatusForbidden, resp.StatusCode)
@@ -253,7 +250,7 @@ func TestGetPostPropertyValues(t *testing.T) {
 		appErr := setBasicCommonReviewerConfig(th)
 		require.Nil(t, appErr)
 
-		post := th.CreatePost()
+		post := th.CreatePost(t)
 		response, err := client.FlagPostForContentReview(context.Background(), post.Id, &model.FlagContentRequest{
 			Reason:  "Sensitive data",
 			Comment: "This is sensitive content",
@@ -271,8 +268,7 @@ func TestGetPostPropertyValues(t *testing.T) {
 }
 
 func TestGetFlaggedPost(t *testing.T) {
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	client := th.Client
 
@@ -283,7 +279,7 @@ func TestGetFlaggedPost(t *testing.T) {
 			config.ContentFlaggingSettings.SetDefaults()
 		})
 
-		post := th.CreatePost()
+		post := th.CreatePost(t)
 		flaggedPost, resp, err := client.GetContentFlaggedPost(context.Background(), post.Id)
 		require.Error(t, err)
 		require.Equal(t, http.StatusNotImplemented, resp.StatusCode)
@@ -297,7 +293,7 @@ func TestGetFlaggedPost(t *testing.T) {
 			config.ContentFlaggingSettings.SetDefaults()
 		})
 
-		post := th.CreatePost()
+		post := th.CreatePost(t)
 		flaggedPost, resp, err := client.GetContentFlaggedPost(context.Background(), post.Id)
 		require.Error(t, err)
 		require.Equal(t, http.StatusNotImplemented, resp.StatusCode)
@@ -342,7 +338,7 @@ func TestGetFlaggedPost(t *testing.T) {
 		appErr := th.App.SaveContentFlaggingConfig(config)
 		require.Nil(t, appErr)
 
-		post := th.CreatePost()
+		post := th.CreatePost(t)
 		flaggedPost, resp, err := client.GetContentFlaggedPost(context.Background(), post.Id)
 		require.Error(t, err)
 		require.Equal(t, http.StatusForbidden, resp.StatusCode)
@@ -355,7 +351,7 @@ func TestGetFlaggedPost(t *testing.T) {
 		appErr := setBasicCommonReviewerConfig(th)
 		require.Nil(t, appErr)
 
-		post := th.CreatePost()
+		post := th.CreatePost(t)
 		flaggedPost, resp, err := client.GetContentFlaggedPost(context.Background(), post.Id)
 		require.Error(t, err)
 		require.Equal(t, http.StatusNotFound, resp.StatusCode)
@@ -368,7 +364,7 @@ func TestGetFlaggedPost(t *testing.T) {
 		appErr := setBasicCommonReviewerConfig(th)
 		require.Nil(t, appErr)
 
-		post := th.CreatePost()
+		post := th.CreatePost(t)
 
 		// First flag the post
 		flagRequest := &model.FlagContentRequest{
@@ -401,7 +397,7 @@ func TestGetFlaggedPost(t *testing.T) {
 		require.Equal(t, 1, len(fileResponse.FileInfos))
 		fileInfo := fileResponse.FileInfos[0]
 
-		post := th.CreatePostInChannelWithFiles(th.BasicChannel, fileInfo)
+		post := th.CreatePostInChannelWithFiles(t, th.BasicChannel, fileInfo)
 
 		// First flag the post
 		flagRequest := &model.FlagContentRequest{
@@ -421,21 +417,24 @@ func TestGetFlaggedPost(t *testing.T) {
 }
 
 func TestFlagPost(t *testing.T) {
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	os.Setenv("MM_FEATUREFLAGS_BURNONREAD", "true")
+	t.Cleanup(func() {
+		os.Unsetenv("MM_FEATUREFLAGS_BURNONREAD")
+	})
+	th := Setup(t).InitBasic(t)
 
 	client := th.Client
 
 	t.Run("Should return 501 when Enterprise Advanced license is not present even if feature is enabled", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterprise))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		th.App.UpdateConfig(func(config *model.Config) {
 			config.ContentFlaggingSettings.EnableContentFlagging = model.NewPointer(true)
 			config.ContentFlaggingSettings.SetDefaults()
 		})
 
-		post := th.CreatePost()
+		post := th.CreatePost(t)
 		flagRequest := &model.FlagContentRequest{
 			Reason:  "spam",
 			Comment: "This is spam content",
@@ -448,14 +447,14 @@ func TestFlagPost(t *testing.T) {
 
 	t.Run("Should return 501 when feature is disabled", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		th.App.UpdateConfig(func(config *model.Config) {
 			config.ContentFlaggingSettings.EnableContentFlagging = model.NewPointer(false)
 			config.ContentFlaggingSettings.SetDefaults()
 		})
 
-		post := th.CreatePost()
+		post := th.CreatePost(t)
 		flagRequest := &model.FlagContentRequest{
 			Reason:  "spam",
 			Comment: "This is spam content",
@@ -468,7 +467,7 @@ func TestFlagPost(t *testing.T) {
 
 	t.Run("Should return 404 when post does not exist", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		th.App.UpdateConfig(func(config *model.Config) {
 			config.ContentFlaggingSettings.EnableContentFlagging = model.NewPointer(true)
@@ -487,7 +486,7 @@ func TestFlagPost(t *testing.T) {
 
 	t.Run("Should return 403 when user does not have permission to view post", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		th.App.UpdateConfig(func(config *model.Config) {
 			config.ContentFlaggingSettings.EnableContentFlagging = model.NewPointer(true)
@@ -495,9 +494,9 @@ func TestFlagPost(t *testing.T) {
 		})
 
 		// Create a private channel and post
-		privateChannel := th.CreatePrivateChannel()
-		post := th.CreatePostWithClient(th.Client, privateChannel)
-		th.RemoveUserFromChannel(th.BasicUser, privateChannel)
+		privateChannel := th.CreatePrivateChannel(t)
+		post := th.CreatePostWithClient(t, th.Client, privateChannel)
+		th.RemoveUserFromChannel(t, th.BasicUser, privateChannel)
 
 		flagRequest := &model.FlagContentRequest{
 			Reason:  "spam",
@@ -511,7 +510,7 @@ func TestFlagPost(t *testing.T) {
 
 	t.Run("Should return 400 when content flagging is not enabled for the team", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		config := model.ContentFlaggingSettingsRequest{
 			ContentFlaggingSettingsBase: model.ContentFlaggingSettingsBase{
@@ -532,7 +531,7 @@ func TestFlagPost(t *testing.T) {
 		appErr := th.App.SaveContentFlaggingConfig(config)
 		require.Nil(t, appErr)
 
-		post := th.CreatePost()
+		post := th.CreatePost(t)
 		flagRequest := &model.FlagContentRequest{
 			Reason:  "spam",
 			Comment: "This is spam content",
@@ -545,12 +544,12 @@ func TestFlagPost(t *testing.T) {
 
 	t.Run("Should successfully flag a post when all conditions are met", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		appErr := setBasicCommonReviewerConfig(th)
 		require.Nil(t, appErr)
 
-		post := th.CreatePost()
+		post := th.CreatePost(t)
 		flagRequest := &model.FlagContentRequest{
 			Reason:  "Sensitive data",
 			Comment: "This is sensitive data",
@@ -560,17 +559,46 @@ func TestFlagPost(t *testing.T) {
 		require.NoError(t, err)
 		require.Equal(t, http.StatusOK, resp.StatusCode)
 	})
+
+	t.Run("Should not allow flagging a burn on read post", func(t *testing.T) {
+		enableBurnOnReadFeature(th)
+		defer th.RemoveLicense(t)
+
+		th.App.UpdateConfig(func(config *model.Config) {
+			config.ContentFlaggingSettings.EnableContentFlagging = model.NewPointer(true)
+			config.ContentFlaggingSettings.SetDefaults()
+		})
+
+		post := &model.Post{
+			UserId:    th.BasicUser.Id,
+			ChannelId: th.BasicChannel.Id,
+			Message:   "This is a burn on read post",
+			Type:      model.PostTypeBurnOnRead,
+		}
+
+		createdPost, response, err := client.CreatePost(context.Background(), post)
+		require.NoError(t, err)
+		CheckCreatedStatus(t, response)
+
+		flagRequest := &model.FlagContentRequest{
+			Reason:  "spam",
+			Comment: "This is spam content",
+		}
+
+		response, err = client.FlagPostForContentReview(context.Background(), createdPost.Id, flagRequest)
+		require.Error(t, err)
+		CheckBadRequestStatus(t, response)
+	})
 }
 
 func TestGetTeamPostReportingFeatureStatus(t *testing.T) {
 	th := Setup(t)
-	defer th.TearDown()
 
 	client := th.Client
 
 	t.Run("Should return 501 when Enterprise Advanced license is not present even if feature is enabled", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterprise))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		th.App.UpdateConfig(func(config *model.Config) {
 			config.ContentFlaggingSettings.EnableContentFlagging = model.NewPointer(true)
@@ -585,7 +613,7 @@ func TestGetTeamPostReportingFeatureStatus(t *testing.T) {
 
 	t.Run("Should return 501 when feature is disabled", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		th.App.UpdateConfig(func(config *model.Config) {
 			config.ContentFlaggingSettings.EnableContentFlagging = model.NewPointer(false)
@@ -600,7 +628,7 @@ func TestGetTeamPostReportingFeatureStatus(t *testing.T) {
 
 	t.Run("Should return Forbidden error when calling for a team without the team membership", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		config := model.ContentFlaggingSettingsRequest{
 			ContentFlaggingSettingsBase: model.ContentFlaggingSettingsBase{
@@ -621,11 +649,11 @@ func TestGetTeamPostReportingFeatureStatus(t *testing.T) {
 
 		// using basic user because the default user is a system admin, and they have
 		// access to all teams even without being an explicit team member
-		th.LoginBasic()
-		team := th.CreateTeam()
+		th.LoginBasic(t)
+		team := th.CreateTeam(t)
 		// unlinking from the created team as by default the team's creator is
 		// a team member, so we need to leave the team explicitly
-		th.UnlinkUserFromTeam(th.BasicUser, team)
+		th.UnlinkUserFromTeam(t, th.BasicUser, team)
 
 		status, resp, err := client.GetTeamPostFlaggingFeatureStatus(context.Background(), team.Id)
 		require.Error(t, err)
@@ -633,7 +661,7 @@ func TestGetTeamPostReportingFeatureStatus(t *testing.T) {
 		require.Nil(t, status)
 
 		// now we will join the team and that will allow us to call the endpoint without error
-		th.LinkUserToTeam(th.BasicUser, team)
+		th.LinkUserToTeam(t, th.BasicUser, team)
 		status, resp, err = client.GetTeamPostFlaggingFeatureStatus(context.Background(), team.Id)
 		require.NoError(t, err)
 		require.Equal(t, http.StatusOK, resp.StatusCode)
@@ -642,14 +670,13 @@ func TestGetTeamPostReportingFeatureStatus(t *testing.T) {
 }
 
 func TestSearchReviewers(t *testing.T) {
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	client := th.Client
 
 	t.Run("Should return 501 when Enterprise Advanced license is not present even if feature is enabled", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterprise))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		th.App.UpdateConfig(func(config *model.Config) {
 			config.ContentFlaggingSettings.EnableContentFlagging = model.NewPointer(true)
@@ -664,7 +691,7 @@ func TestSearchReviewers(t *testing.T) {
 
 	t.Run("Should return 501 when feature is disabled", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		th.App.UpdateConfig(func(config *model.Config) {
 			config.ContentFlaggingSettings.EnableContentFlagging = model.NewPointer(false)
@@ -679,7 +706,7 @@ func TestSearchReviewers(t *testing.T) {
 
 	t.Run("Should return 403 when user is not a reviewer", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		config := model.ContentFlaggingSettingsRequest{
 			ContentFlaggingSettingsBase: model.ContentFlaggingSettingsBase{
@@ -711,7 +738,7 @@ func TestSearchReviewers(t *testing.T) {
 
 	t.Run("Should successfully search reviewers when user is a reviewer", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		appErr := setBasicCommonReviewerConfig(th)
 		require.Nil(t, appErr)
@@ -724,7 +751,7 @@ func TestSearchReviewers(t *testing.T) {
 
 	t.Run("Should successfully search reviewers when user is a team reviewer", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		config := model.ContentFlaggingSettingsRequest{
 			ContentFlaggingSettingsBase: model.ContentFlaggingSettingsBase{
@@ -756,21 +783,20 @@ func TestSearchReviewers(t *testing.T) {
 }
 
 func TestAssignContentFlaggingReviewer(t *testing.T) {
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	client := th.Client
 
 	t.Run("Should return 501 when Enterprise Advanced license is not present even if feature is enabled", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterprise))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		th.App.UpdateConfig(func(config *model.Config) {
 			config.ContentFlaggingSettings.EnableContentFlagging = model.NewPointer(true)
 			config.ContentFlaggingSettings.SetDefaults()
 		})
 
-		post := th.CreatePost()
+		post := th.CreatePost(t)
 		resp, err := client.AssignContentFlaggingReviewer(context.Background(), post.Id, th.BasicUser.Id)
 		require.Error(t, err)
 		require.Equal(t, http.StatusNotImplemented, resp.StatusCode)
@@ -778,14 +804,14 @@ func TestAssignContentFlaggingReviewer(t *testing.T) {
 
 	t.Run("Should return 501 when feature is disabled", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		th.App.UpdateConfig(func(config *model.Config) {
 			config.ContentFlaggingSettings.EnableContentFlagging = model.NewPointer(false)
 			config.ContentFlaggingSettings.SetDefaults()
 		})
 
-		post := th.CreatePost()
+		post := th.CreatePost(t)
 		resp, err := client.AssignContentFlaggingReviewer(context.Background(), post.Id, th.BasicUser.Id)
 		require.Error(t, err)
 		require.Equal(t, http.StatusNotImplemented, resp.StatusCode)
@@ -793,7 +819,7 @@ func TestAssignContentFlaggingReviewer(t *testing.T) {
 
 	t.Run("Should return 404 when post does not exist", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		th.App.UpdateConfig(func(config *model.Config) {
 			config.ContentFlaggingSettings.EnableContentFlagging = model.NewPointer(true)
@@ -807,12 +833,12 @@ func TestAssignContentFlaggingReviewer(t *testing.T) {
 
 	t.Run("Should return 400 when user ID is invalid", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		appErr := setBasicCommonReviewerConfig(th)
 		require.Nil(t, appErr)
 
-		post := th.CreatePost()
+		post := th.CreatePost(t)
 		resp, err := client.AssignContentFlaggingReviewer(context.Background(), post.Id, "invalidUserId")
 		require.Error(t, err)
 		require.Equal(t, http.StatusBadRequest, resp.StatusCode)
@@ -820,7 +846,7 @@ func TestAssignContentFlaggingReviewer(t *testing.T) {
 
 	t.Run("Should return 403 when assigning user is not a reviewer", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		config := model.ContentFlaggingSettingsRequest{
 			ContentFlaggingSettingsBase: model.ContentFlaggingSettingsBase{
@@ -844,7 +870,7 @@ func TestAssignContentFlaggingReviewer(t *testing.T) {
 		appErr := th.App.SaveContentFlaggingConfig(config)
 		require.Nil(t, appErr)
 
-		post := th.CreatePost()
+		post := th.CreatePost(t)
 		resp, err := client.AssignContentFlaggingReviewer(context.Background(), post.Id, th.BasicUser.Id)
 		require.Error(t, err)
 		require.Equal(t, http.StatusForbidden, resp.StatusCode)
@@ -852,11 +878,11 @@ func TestAssignContentFlaggingReviewer(t *testing.T) {
 
 	t.Run("Should return 400 when assignee is not a reviewer", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		// Create another user who will not be a reviewer
-		nonReviewerUser := th.CreateUser()
-		th.LinkUserToTeam(nonReviewerUser, th.BasicTeam)
+		nonReviewerUser := th.CreateUser(t)
+		th.LinkUserToTeam(t, nonReviewerUser, th.BasicTeam)
 
 		config := model.ContentFlaggingSettingsRequest{
 			ContentFlaggingSettingsBase: model.ContentFlaggingSettingsBase{
@@ -875,7 +901,7 @@ func TestAssignContentFlaggingReviewer(t *testing.T) {
 		appErr := th.App.SaveContentFlaggingConfig(config)
 		require.Nil(t, appErr)
 
-		post := th.CreatePost()
+		post := th.CreatePost(t)
 		// Try to assign non-reviewer user
 		resp, err := client.AssignContentFlaggingReviewer(context.Background(), post.Id, nonReviewerUser.Id)
 		require.Error(t, err)
@@ -884,11 +910,11 @@ func TestAssignContentFlaggingReviewer(t *testing.T) {
 
 	t.Run("Should successfully assign reviewer when all conditions are met", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		// Create another reviewer user
-		reviewerUser := th.CreateUser()
-		th.LinkUserToTeam(reviewerUser, th.BasicTeam)
+		reviewerUser := th.CreateUser(t)
+		th.LinkUserToTeam(t, reviewerUser, th.BasicTeam)
 
 		config := model.ContentFlaggingSettingsRequest{
 			ContentFlaggingSettingsBase: model.ContentFlaggingSettingsBase{
@@ -907,7 +933,7 @@ func TestAssignContentFlaggingReviewer(t *testing.T) {
 		appErr := th.App.SaveContentFlaggingConfig(config)
 		require.Nil(t, appErr)
 
-		post := th.CreatePost()
+		post := th.CreatePost(t)
 
 		// First flag the post so it can be assigned
 		flagRequest := &model.FlagContentRequest{
@@ -926,11 +952,11 @@ func TestAssignContentFlaggingReviewer(t *testing.T) {
 
 	t.Run("Should successfully assign reviewer when user is team reviewer", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicenseSKU(model.LicenseShortSkuEnterpriseAdvanced))
-		defer th.RemoveLicense()
+		defer th.RemoveLicense(t)
 
 		// Create another reviewer user
-		reviewerUser := th.CreateUser()
-		th.LinkUserToTeam(reviewerUser, th.BasicTeam)
+		reviewerUser := th.CreateUser(t)
+		th.LinkUserToTeam(t, reviewerUser, th.BasicTeam)
 
 		config := model.ContentFlaggingSettingsRequest{
 			ContentFlaggingSettingsBase: model.ContentFlaggingSettingsBase{
@@ -954,7 +980,7 @@ func TestAssignContentFlaggingReviewer(t *testing.T) {
 		appErr := th.App.SaveContentFlaggingConfig(config)
 		require.Nil(t, appErr)
 
-		post := th.CreatePost()
+		post := th.CreatePost(t)
 
 		// First flag the post so it can be assigned
 		flagRequest := &model.FlagContentRequest{
