@@ -19,7 +19,6 @@ import (
 func TestDataRetentionGetPolicy(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	_, resp, err := th.Client.GetDataRetentionPolicy(context.Background())
 	require.Error(t, err)
@@ -28,8 +27,7 @@ func TestDataRetentionGetPolicy(t *testing.T) {
 
 func TestGetPolicies(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	// Set up a test license with Data Retention enabled
 	ok := th.App.Srv().SetLicense(model.NewTestLicense("data_retention"))
@@ -93,7 +91,7 @@ func TestGetPolicies(t *testing.T) {
 
 	t.Run("as regular user", func(t *testing.T) {
 		// Ensure the basic user doesn't have the necessary permission
-		th.RemovePermissionFromRole(model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemUserRoleId)
+		th.RemovePermissionFromRole(t, model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemUserRoleId)
 
 		policies, resp, err := th.Client.GetDataRetentionPolicies(context.Background(), 0, 100)
 		require.Error(t, err)
@@ -115,8 +113,7 @@ func TestGetPolicies(t *testing.T) {
 
 func TestGetDataRetentionPoliciesCount(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	// Set up a test license with Data Retention enabled
 	ok := th.App.Srv().SetLicense(model.NewTestLicense("data_retention"))
@@ -145,7 +142,7 @@ func TestGetDataRetentionPoliciesCount(t *testing.T) {
 
 	t.Run("get policies count with permissions", func(t *testing.T) {
 		// Add necessary permissions
-		th.AddPermissionToRole(model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemUserRoleId)
 
 		count, resp, err := th.Client.GetDataRetentionPoliciesCount(context.Background())
 		require.NoError(t, err)
@@ -163,8 +160,7 @@ func TestGetDataRetentionPoliciesCount(t *testing.T) {
 
 func TestGetPolicy(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	// Set up a test license with Data Retention enabled
 	ok := th.App.Srv().SetLicense(model.NewTestLicense("data_retention"))
@@ -220,7 +216,7 @@ func TestGetPolicy(t *testing.T) {
 
 	t.Run("Forbidden", func(t *testing.T) {
 		// Ensure the basic user doesn't have the necessary permission
-		th.RemovePermissionFromRole(model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemUserRoleId)
+		th.RemovePermissionFromRole(t, model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemUserRoleId)
 
 		policy, resp, err := th.Client.GetDataRetentionPolicyByID(context.Background(), validPolicyId)
 		require.Error(t, err)
@@ -249,8 +245,7 @@ func TestGetPolicy(t *testing.T) {
 
 func TestCreatePolicy(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	ok := th.App.Srv().SetLicense(model.NewTestLicense("data_retention"))
 	require.True(t, ok, "SetLicense should return true")
@@ -308,7 +303,7 @@ func TestCreatePolicy(t *testing.T) {
 
 	t.Run("Forbidden", func(t *testing.T) {
 		// Ensure the basic user doesn't have the necessary permission
-		th.RemovePermissionFromRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemUserRoleId)
+		th.RemovePermissionFromRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemUserRoleId)
 
 		var postDurationDays int64 = 30
 		policyToCreate := &model.RetentionPolicyWithTeamAndChannelIDs{
@@ -346,8 +341,7 @@ func TestCreatePolicy(t *testing.T) {
 
 func TestPatchPolicy(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	// Set up a test license with Data Retention enabled
 	ok := th.App.Srv().SetLicense(model.NewTestLicense("data_retention"))
@@ -382,7 +376,7 @@ func TestPatchPolicy(t *testing.T) {
 
 	t.Run("Success", func(t *testing.T) {
 		// Grant necessary permission to system admin
-		th.AddPermissionToRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 
 		var postDurationDays int64 = 60
 		patchPayload := &model.RetentionPolicyWithTeamAndChannelIDs{
@@ -404,7 +398,7 @@ func TestPatchPolicy(t *testing.T) {
 		assert.Equal(t, int64(1), policy.TeamCount, "TeamCount should match")
 
 		// Clean up: remove the permission after the test
-		th.RemovePermissionFromRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.RemovePermissionFromRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 	})
 
 	t.Run("InvalidPolicyID", func(t *testing.T) {
@@ -462,8 +456,7 @@ func TestPatchPolicy(t *testing.T) {
 
 func TestDeletePolicy(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	// Set up a test license with Data Retention enabled
 	ok := th.App.Srv().SetLicense(model.NewTestLicense("data_retention"))
@@ -489,26 +482,26 @@ func TestDeletePolicy(t *testing.T) {
 
 	t.Run("Success", func(t *testing.T) {
 		// Grant necessary permission to system admin
-		th.AddPermissionToRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 
 		resp, err := th.SystemAdminClient.DeleteDataRetentionPolicy(context.Background(), validPolicyId)
 		require.NoError(t, err)
 		CheckOKStatus(t, resp)
 
 		// Clean up: remove the permission after the test
-		th.RemovePermissionFromRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.RemovePermissionFromRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 	})
 
 	t.Run("NonExistentPolicy", func(t *testing.T) {
 		// Grant necessary permission to system admin
-		th.AddPermissionToRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 
 		resp, err := th.SystemAdminClient.DeleteDataRetentionPolicy(context.Background(), nonExistentPolicyId)
 		require.Error(t, err)
 		CheckNotFoundStatus(t, resp)
 
 		// Clean up: remove the permission after the test
-		th.RemovePermissionFromRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.RemovePermissionFromRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 	})
 
 	t.Run("NoPermission", func(t *testing.T) {
@@ -530,8 +523,7 @@ func TestDeletePolicy(t *testing.T) {
 
 func TestGetTeamPoliciesForUser(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	// Set up a test license with Data Retention enabled
 	ok := th.App.Srv().SetLicense(model.NewTestLicense("data_retention"))
@@ -587,7 +579,7 @@ func TestGetTeamPoliciesForUser(t *testing.T) {
 	})
 
 	t.Run("AsOtherUser", func(t *testing.T) {
-		th.LoginBasic2()
+		th.LoginBasic2(t)
 
 		policies, resp, err := th.Client.GetTeamPoliciesForUser(context.Background(), th.BasicUser.Id, 0, 60)
 		require.Error(t, err)
@@ -616,8 +608,7 @@ func TestGetTeamPoliciesForUser(t *testing.T) {
 
 func TestGetChannelPoliciesForUser(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	// Set up a test license with Data Retention enabled
 	ok := th.App.Srv().SetLicense(model.NewTestLicense("data_retention"))
@@ -673,7 +664,7 @@ func TestGetChannelPoliciesForUser(t *testing.T) {
 	})
 
 	t.Run("AsOtherUser", func(t *testing.T) {
-		th.LoginBasic2()
+		th.LoginBasic2(t)
 
 		policies, resp, err := th.Client.GetChannelPoliciesForUser(context.Background(), th.BasicUser.Id, 0, 60)
 		require.Error(t, err)
@@ -702,8 +693,7 @@ func TestGetChannelPoliciesForUser(t *testing.T) {
 
 func TestGetTeamsForPolicy(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	// Set up a test license with Data Retention enabled
 	ok := th.App.Srv().SetLicense(model.NewTestLicense("data_retention"))
@@ -744,7 +734,7 @@ func TestGetTeamsForPolicy(t *testing.T) {
 
 	t.Run("Success", func(t *testing.T) {
 		// Grant necessary permission to system admin
-		th.AddPermissionToRole(model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 
 		teams, resp, err := th.SystemAdminClient.GetTeamsForRetentionPolicy(context.Background(), validPolicyId, 0, 100)
 		require.NoError(t, err)
@@ -756,12 +746,12 @@ func TestGetTeamsForPolicy(t *testing.T) {
 		assert.Equal(t, int64(2), teams.TotalCount, "Total count should be 2")
 
 		// Clean up: remove the permission after the test
-		th.RemovePermissionFromRole(model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.RemovePermissionFromRole(t, model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 	})
 
 	t.Run("NonExistentPolicy", func(t *testing.T) {
 		// Grant necessary permission to system admin
-		th.AddPermissionToRole(model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 
 		teams, resp, err := th.SystemAdminClient.GetTeamsForRetentionPolicy(context.Background(), nonExistentPolicyId, 0, 100)
 		require.Error(t, err)
@@ -769,7 +759,7 @@ func TestGetTeamsForPolicy(t *testing.T) {
 		assert.Nil(t, teams, "Teams should be nil for non-existent policy")
 
 		// Clean up: remove the permission after the test
-		th.RemovePermissionFromRole(model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.RemovePermissionFromRole(t, model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 	})
 
 	t.Run("NoPermission", func(t *testing.T) {
@@ -793,8 +783,7 @@ func TestGetTeamsForPolicy(t *testing.T) {
 
 func TestAddTeamsToPolicy(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	// Set up a test license with Data Retention enabled
 	ok := th.App.Srv().SetLicense(model.NewTestLicense("data_retention"))
@@ -823,26 +812,26 @@ func TestAddTeamsToPolicy(t *testing.T) {
 
 	t.Run("Success", func(t *testing.T) {
 		// Grant necessary permission to system admin
-		th.AddPermissionToRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 
 		resp, err := th.SystemAdminClient.AddTeamsToRetentionPolicy(context.Background(), validPolicyId, validTeamIDs)
 		require.NoError(t, err)
 		CheckOKStatus(t, resp)
 
 		// Clean up: remove the permission after the test
-		th.RemovePermissionFromRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.RemovePermissionFromRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 	})
 
 	t.Run("NonExistentPolicy", func(t *testing.T) {
 		// Grant necessary permission to system admin
-		th.AddPermissionToRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 
 		resp, err := th.SystemAdminClient.AddTeamsToRetentionPolicy(context.Background(), nonExistentPolicyId, validTeamIDs)
 		require.Error(t, err)
 		CheckNotFoundStatus(t, resp)
 
 		// Clean up: remove the permission after the test
-		th.RemovePermissionFromRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.RemovePermissionFromRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 	})
 
 	t.Run("NoPermission", func(t *testing.T) {
@@ -864,8 +853,7 @@ func TestAddTeamsToPolicy(t *testing.T) {
 
 func TestRemoveTeamsFromPolicy(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	// Set up a test license with Data Retention enabled
 	ok := th.App.Srv().SetLicense(model.NewTestLicense("data_retention"))
@@ -894,26 +882,26 @@ func TestRemoveTeamsFromPolicy(t *testing.T) {
 
 	t.Run("Success", func(t *testing.T) {
 		// Grant necessary permission to system admin
-		th.AddPermissionToRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 
 		resp, err := th.SystemAdminClient.RemoveTeamsFromRetentionPolicy(context.Background(), validPolicyId, validTeamIDs)
 		require.NoError(t, err)
 		CheckOKStatus(t, resp)
 
 		// Clean up: remove the permission after the test
-		th.RemovePermissionFromRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.RemovePermissionFromRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 	})
 
 	t.Run("NonExistentPolicy", func(t *testing.T) {
 		// Grant necessary permission to system admin
-		th.AddPermissionToRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 
 		resp, err := th.SystemAdminClient.RemoveTeamsFromRetentionPolicy(context.Background(), nonExistentPolicyId, validTeamIDs)
 		require.Error(t, err)
 		CheckNotFoundStatus(t, resp)
 
 		// Clean up: remove the permission after the test
-		th.RemovePermissionFromRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.RemovePermissionFromRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 	})
 
 	t.Run("NoPermission", func(t *testing.T) {
@@ -935,8 +923,7 @@ func TestRemoveTeamsFromPolicy(t *testing.T) {
 
 func TestGetChannelsForPolicy(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	// Set up a test license with Data Retention enabled
 	ok := th.App.Srv().SetLicense(model.NewTestLicense("data_retention"))
@@ -987,7 +974,7 @@ func TestGetChannelsForPolicy(t *testing.T) {
 
 	t.Run("Success", func(t *testing.T) {
 		// Grant necessary permission to system admin
-		th.AddPermissionToRole(model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 
 		channels, resp, err := th.SystemAdminClient.GetChannelsForRetentionPolicy(context.Background(), validPolicyId, 0, 100)
 		require.NoError(t, err)
@@ -999,12 +986,12 @@ func TestGetChannelsForPolicy(t *testing.T) {
 		assert.Equal(t, int64(2), channels.TotalCount, "Total count should be 2")
 
 		// Clean up: remove the permission after the test
-		th.RemovePermissionFromRole(model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.RemovePermissionFromRole(t, model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 	})
 
 	t.Run("NonExistentPolicy", func(t *testing.T) {
 		// Grant necessary permission to system admin
-		th.AddPermissionToRole(model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 
 		channels, resp, err := th.SystemAdminClient.GetChannelsForRetentionPolicy(context.Background(), nonExistentPolicyId, 0, 100)
 		require.Error(t, err)
@@ -1012,7 +999,7 @@ func TestGetChannelsForPolicy(t *testing.T) {
 		assert.Nil(t, channels, "Channels should be nil for non-existent policy")
 
 		// Clean up: remove the permission after the test
-		th.RemovePermissionFromRole(model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.RemovePermissionFromRole(t, model.PermissionSysconsoleReadComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 	})
 
 	t.Run("NoPermission", func(t *testing.T) {
@@ -1036,8 +1023,7 @@ func TestGetChannelsForPolicy(t *testing.T) {
 
 func TestAddChannelsToPolicy(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	// Set up a test license with Data Retention enabled
 	ok := th.App.Srv().SetLicense(model.NewTestLicense("data_retention"))
@@ -1103,38 +1089,38 @@ func TestAddChannelsToPolicy(t *testing.T) {
 
 	t.Run("Success", func(t *testing.T) {
 		// Grant necessary permission to system admin
-		th.AddPermissionToRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 
 		resp, err := th.SystemAdminClient.AddChannelsToRetentionPolicy(context.Background(), validPolicyId, validChannelIDs)
 		require.NoError(t, err)
 		CheckOKStatus(t, resp)
 
 		// Clean up: remove the permission after the test
-		th.RemovePermissionFromRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.RemovePermissionFromRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 	})
 
 	t.Run("NonExistentPolicy", func(t *testing.T) {
 		// Grant necessary permission to system admin
-		th.AddPermissionToRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 
 		resp, err := th.SystemAdminClient.AddChannelsToRetentionPolicy(context.Background(), nonExistentPolicyId, validChannelIDs)
 		require.Error(t, err)
 		CheckNotFoundStatus(t, resp)
 
 		// Clean up: remove the permission after the test
-		th.RemovePermissionFromRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.RemovePermissionFromRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 	})
 
 	t.Run("InvalidChannelIDs", func(t *testing.T) {
 		// Grant necessary permission to system admin
-		th.AddPermissionToRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 
 		resp, err := th.SystemAdminClient.AddChannelsToRetentionPolicy(context.Background(), validPolicyId, invalidChannelIDs)
 		require.Error(t, err)
 		CheckBadRequestStatus(t, resp)
 
 		// Clean up: remove the permission after the test
-		th.RemovePermissionFromRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.RemovePermissionFromRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 	})
 
 	t.Run("NoPermission", func(t *testing.T) {
@@ -1156,8 +1142,7 @@ func TestAddChannelsToPolicy(t *testing.T) {
 
 func TestRemoveChannelsFromPolicy(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	// Set up a test license with Data Retention enabled
 	ok := th.App.Srv().SetLicense(model.NewTestLicense("data_retention"))
@@ -1205,38 +1190,38 @@ func TestRemoveChannelsFromPolicy(t *testing.T) {
 
 	t.Run("Success", func(t *testing.T) {
 		// Grant necessary permission to system admin
-		th.AddPermissionToRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 
 		resp, err := th.SystemAdminClient.RemoveChannelsFromRetentionPolicy(context.Background(), validPolicyId, validChannelIDs)
 		require.NoError(t, err)
 		CheckOKStatus(t, resp)
 
 		// Clean up: remove the permission after the test
-		th.RemovePermissionFromRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.RemovePermissionFromRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 	})
 
 	t.Run("NonExistentPolicy", func(t *testing.T) {
 		// Grant necessary permission to system admin
-		th.AddPermissionToRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 
 		resp, err := th.SystemAdminClient.RemoveChannelsFromRetentionPolicy(context.Background(), nonExistentPolicyId, validChannelIDs)
 		require.Error(t, err)
 		CheckNotFoundStatus(t, resp)
 
 		// Clean up: remove the permission after the test
-		th.RemovePermissionFromRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.RemovePermissionFromRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 	})
 
 	t.Run("InvalidChannelIDs", func(t *testing.T) {
 		// Grant necessary permission to system admin
-		th.AddPermissionToRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 
 		resp, err := th.SystemAdminClient.RemoveChannelsFromRetentionPolicy(context.Background(), validPolicyId, invalidChannelIDs)
 		require.Error(t, err)
 		CheckBadRequestStatus(t, resp)
 
 		// Clean up: remove the permission after the test
-		th.RemovePermissionFromRole(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
+		th.RemovePermissionFromRole(t, model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id, model.SystemAdminRoleId)
 	})
 
 	t.Run("NoPermission", func(t *testing.T) {
