@@ -24,7 +24,6 @@ import (
 func TestGetOldClientLicense(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 	client := th.Client
 
 	license, _, err := client.GetOldClientLicense(context.Background(), "")
@@ -56,7 +55,6 @@ func TestGetOldClientLicense(t *testing.T) {
 
 func TestUploadLicenseFile(t *testing.T) {
 	th := Setup(t)
-	defer th.TearDown()
 	client := th.Client
 	LocalClient := th.LocalClient
 
@@ -196,7 +194,6 @@ func TestUploadLicenseFile(t *testing.T) {
 func TestRemoveLicenseFile(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 	client := th.Client
 	LocalClient := th.LocalClient
 
@@ -229,7 +226,6 @@ func TestRemoveLicenseFile(t *testing.T) {
 
 func TestRequestTrialLicenseWithExtraFields(t *testing.T) {
 	th := Setup(t)
-	defer th.TearDown()
 
 	licenseManagerMock := &mocks.LicenseInterface{}
 	licenseManagerMock.On("CanStartTrial").Return(true, nil)
@@ -377,7 +373,6 @@ func TestRequestTrialLicenseWithExtraFields(t *testing.T) {
 func TestRequestTrialLicense(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	licenseManagerMock := &mocks.LicenseInterface{}
 	licenseManagerMock.On("CanStartTrial").Return(true, nil)
@@ -480,7 +475,6 @@ func TestRequestTrialLicense(t *testing.T) {
 func TestGetLicenseLoadMetric(t *testing.T) {
 	t.Run("when user is logged out", func(t *testing.T) {
 		th := Setup(t)
-		defer th.TearDown()
 
 		client := th.CreateClient()
 		_, resp, err := client.GetLicenseLoadMetric(context.Background())
@@ -490,7 +484,6 @@ func TestGetLicenseLoadMetric(t *testing.T) {
 
 	t.Run("when no license is loaded", func(t *testing.T) {
 		th := Setup(t)
-		defer th.TearDown()
 
 		th.App.Srv().Platform().SetLicense(nil)
 		data, resp, err := th.Client.GetLicenseLoadMetric(context.Background())
@@ -501,7 +494,6 @@ func TestGetLicenseLoadMetric(t *testing.T) {
 
 	t.Run("with 50 users on a license count of 1000", func(t *testing.T) {
 		th := Setup(t)
-		defer th.TearDown()
 
 		// Create a license with 1000 users
 		license := model.NewTestLicense()
@@ -520,7 +512,7 @@ func TestGetLicenseLoadMetric(t *testing.T) {
 
 		// Add 50 active users (50/1000 * 1000 = 50)
 		for range 49 { // 49 + 1 basic user = 50 active users
-			user := th.CreateUser()
+			user := th.CreateUser(t)
 
 			// Make user active
 			status := &model.Status{
@@ -544,7 +536,6 @@ func TestGetLicenseLoadMetric(t *testing.T) {
 
 	t.Run("with 19 users on a license count of 20", func(t *testing.T) {
 		th := Setup(t)
-		defer th.TearDown()
 
 		// Create a license with 20 users
 		license := model.NewTestLicense()
@@ -563,7 +554,7 @@ func TestGetLicenseLoadMetric(t *testing.T) {
 
 		// Add 19 active users (19/20 * 1000 = 950)
 		for range 18 { // 18 + 1 basic user = 19 active users
-			user := th.CreateUser()
+			user := th.CreateUser(t)
 
 			// Make user active
 			status := &model.Status{
@@ -587,7 +578,6 @@ func TestGetLicenseLoadMetric(t *testing.T) {
 
 	t.Run("with 30 users on a license count of 20", func(t *testing.T) {
 		th := Setup(t)
-		defer th.TearDown()
 
 		// Create a license with 20 users
 		license := model.NewTestLicense()
@@ -606,7 +596,7 @@ func TestGetLicenseLoadMetric(t *testing.T) {
 
 		// Add 30 active users (30/20 * 1000 = 1500)
 		for range 29 { // 29 + 1 basic user = 30 active users
-			user := th.CreateUser()
+			user := th.CreateUser(t)
 
 			// Make user active
 			status := &model.Status{
