@@ -20,16 +20,29 @@ func (api *API) InitOAuth() {
 	api.BaseRoutes.OAuthApp.Handle("", api.APISessionRequired(deleteOAuthApp)).Methods(http.MethodDelete)
 	api.BaseRoutes.OAuthApp.Handle("/regen_secret", api.APISessionRequired(regenerateOAuthAppSecret)).Methods(http.MethodPost)
 
+	// DCR (Dynamic Client Registration) endpoints as per RFC 7591
+	api.BaseRoutes.OAuthApps.Handle("/register", api.RateLimitedHandler(api.APIHandler(registerOAuthClient), model.RateLimitSettings{PerSec: model.NewPointer(2), MaxBurst: model.NewPointer(1)})).Methods(http.MethodPost)
+
 	api.BaseRoutes.User.Handle("/oauth/apps/authorized", api.APISessionRequired(getAuthorizedOAuthApps)).Methods(http.MethodGet)
 }
 
 func createOAuthApp(c *Context, w http.ResponseWriter, r *http.Request) {
-	var oauthApp model.OAuthApp
-	if jsonErr := json.NewDecoder(r.Body).Decode(&oauthApp); jsonErr != nil {
+	var appRequest model.OAuthAppRequest
+	if jsonErr := json.NewDecoder(r.Body).Decode(&appRequest); jsonErr != nil {
 		c.SetInvalidParamWithErr("oauth_app", jsonErr)
 		return
 	}
 
+	// Build OAuthApp from request
+	oauthApp := model.OAuthApp{
+		Name:         appRequest.Name,
+		Description:  appRequest.Description,
+		IconURL:      appRequest.IconURL,
+		CallbackUrls: appRequest.CallbackUrls,
+		Homepage:     appRequest.Homepage,
+		IsTrusted:    appRequest.IsTrusted,
+	}
+
 	auditRec := c.MakeAuditRecord(model.AuditEventCreateOAuthApp, model.AuditStatusFail)
 	model.AddEventParameterAuditableToAuditRec(auditRec, "oauth_app", &oauthApp)
 
@@ -45,8 +58,13 @@ func createOAuthApp(c *Context, w http.ResponseWriter, r *http.Request) {
 	}
 
 	oauthApp.CreatorId = c.AppContext.Session().UserId
+	oauthApp.IsDynamicallyRegistered = false
 
-	rapp, err := c.App.CreateOAuthApp(&oauthApp)
+	// Use internal method to control secret generation
+	// Public clients: generateSecret = false (keeps empty secret)
+	// Confidential clients: generateSecret = true (auto-generates secret)
+	generateSecret := !appRequest.IsPublic
+	rapp, err := c.App.CreateOAuthAppInternal(&oauthApp, generateSecret)
 	if err != nil {
 		c.Err = err
 		return
@@ -271,6 +289,12 @@ func regenerateOAuthAppSecret(c *Context, w http.ResponseWriter, r *http.Request
 		return
 	}
 
+	// Prevent regenerating secrets for public clients
+	if oauthApp.IsPublicClient() {
+		c.Err = model.NewAppError("regenerateOAuthAppSecret", "api.oauth.regenerate_secret.public_client.app_error", nil, "app_id="+oauthApp.Id, http.StatusBadRequest)
+		return
+	}
+
 	oauthApp, err = c.App.RegenerateOAuthAppSecret(oauthApp)
 	if err != nil {
 		c.Err = err
@@ -313,3 +337,94 @@ func getAuthorizedOAuthApps(c *Context, w http.ResponseWriter, r *http.Request)
 		c.Logger.Warn("Error while writing response", mlog.Err(err))
 	}
 }
+
+// DCR (Dynamic Client Registration) endpoint handlers as per RFC 7591
+func registerOAuthClient(c *Context, w http.ResponseWriter, r *http.Request) {
+	// Session and permission checks removed for DCR endpoint to allow external client registration
+
+	auditRec := c.MakeAuditRecord(model.AuditEventRegisterOAuthClient, model.AuditStatusFail)
+	defer c.LogAuditRec(auditRec)
+
+	var clientRequest model.ClientRegistrationRequest
+	if jsonErr := json.NewDecoder(r.Body).Decode(&clientRequest); jsonErr != nil {
+		dcrError := model.NewDCRError(model.DCRErrorInvalidClientMetadata, "Invalid JSON in request body")
+
+		w.WriteHeader(http.StatusBadRequest)
+		if err := json.NewEncoder(w).Encode(dcrError); err != nil {
+			c.Logger.Warn("Error while writing response", mlog.Err(err))
+		}
+		return
+	}
+
+	// Add DCR request parameters to audit record
+	model.AddEventParameterToAuditRec(auditRec, "redirect_uris", clientRequest.RedirectURIs)
+	if clientRequest.ClientName != nil {
+		model.AddEventParameterToAuditRec(auditRec, "client_name", *clientRequest.ClientName)
+	}
+	if clientRequest.TokenEndpointAuthMethod != nil {
+		model.AddEventParameterToAuditRec(auditRec, "token_endpoint_auth_method", *clientRequest.TokenEndpointAuthMethod)
+	}
+	if clientRequest.ClientURI != nil {
+		model.AddEventParameterToAuditRec(auditRec, "client_uri", *clientRequest.ClientURI)
+	}
+
+	// Check if OAuth service provider is enabled
+	if !*c.App.Config().ServiceSettings.EnableOAuthServiceProvider {
+		dcrError := model.NewDCRError(model.DCRErrorUnsupportedOperation, "OAuth service provider is disabled")
+
+		w.WriteHeader(http.StatusBadRequest)
+		if err := json.NewEncoder(w).Encode(dcrError); err != nil {
+			c.Logger.Warn("Error while writing response", mlog.Err(err))
+		}
+		return
+	}
+
+	// Check if DCR is enabled
+	if c.App.Config().ServiceSettings.EnableDynamicClientRegistration == nil || !*c.App.Config().ServiceSettings.EnableDynamicClientRegistration {
+		dcrError := model.NewDCRError(model.DCRErrorUnsupportedOperation, "Dynamic client registration is disabled")
+
+		w.WriteHeader(http.StatusBadRequest)
+		if err := json.NewEncoder(w).Encode(dcrError); err != nil {
+			c.Logger.Warn("Error while writing response", mlog.Err(err))
+		}
+		return
+	}
+
+	// Validate the request
+	if err := clientRequest.IsValid(); err != nil {
+		dcrError := model.NewDCRError(model.DCRErrorInvalidClientMetadata, err.Message)
+
+		w.WriteHeader(http.StatusBadRequest)
+		if err := json.NewEncoder(w).Encode(dcrError); err != nil {
+			c.Logger.Warn("Error while writing response", mlog.Err(err))
+		}
+		return
+	}
+
+	// No user ID for DCR
+	userID := ""
+
+	app, appErr := c.App.RegisterOAuthClient(c.AppContext, &clientRequest, userID)
+	if appErr != nil {
+		dcrError := model.NewDCRError(model.DCRErrorInvalidClientMetadata, appErr.Message)
+
+		w.WriteHeader(appErr.StatusCode)
+		if err := json.NewEncoder(w).Encode(dcrError); err != nil {
+			c.Logger.Warn("Error while writing response", mlog.Err(err))
+		}
+		return
+	}
+
+	auditRec.Success()
+	auditRec.AddEventResultState(app)
+	auditRec.AddEventObjectType("oauth_app")
+	c.LogAudit("client_id=" + app.Id)
+
+	siteURL := *c.App.Config().ServiceSettings.SiteURL
+	response := app.ToClientRegistrationResponse(siteURL)
+
+	w.WriteHeader(http.StatusCreated)
+	if err := json.NewEncoder(w).Encode(response); err != nil {
+		c.Logger.Warn("Error writing DCR response", mlog.Err(err))
+	}
+}
