@@ -47,8 +47,7 @@ func TestCheckOutgoingOAuthConnectionReadPermissions(t *testing.T) {
 	t.Skip("https://mattermost.atlassian.net/browse/MM-61690")
 
 	t.Run("no permissions", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		session := model.Session{
 			Id:     model.NewId(),
@@ -65,8 +64,7 @@ func TestCheckOutgoingOAuthConnectionReadPermissions(t *testing.T) {
 	})
 
 	t.Run("with management permissions", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		session := model.Session{
 			Id:     model.NewId(),
@@ -78,7 +76,7 @@ func TestCheckOutgoingOAuthConnectionReadPermissions(t *testing.T) {
 		c.App = th.App
 		c.Logger = th.App.Srv().Log()
 
-		th.AddPermissionToRole(model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
 
 		canReadWithTeam := checkOutgoingOAuthConnectionReadPermissions(c, th.BasicTeam.Id)
 		require.True(t, canReadWithTeam)
@@ -88,8 +86,7 @@ func TestCheckOutgoingOAuthConnectionReadPermissions(t *testing.T) {
 	})
 
 	t.Run("with slash command management permissions", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		session := model.Session{
 			Id:     model.NewId(),
@@ -101,15 +98,14 @@ func TestCheckOutgoingOAuthConnectionReadPermissions(t *testing.T) {
 		c.App = th.App
 		c.Logger = th.App.Srv().Log()
 
-		th.AddPermissionToRole(model.PermissionManageSlashCommands.Id, model.TeamAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOwnSlashCommands.Id, model.TeamAdminRoleId)
 
 		canRead := checkOutgoingOAuthConnectionReadPermissions(c, th.BasicTeam.Id)
 		require.True(t, canRead)
 	})
 
 	t.Run("with outgoing webhooks management permissions", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		session := model.Session{
 			Id:     model.NewId(),
@@ -121,7 +117,7 @@ func TestCheckOutgoingOAuthConnectionReadPermissions(t *testing.T) {
 		c.App = th.App
 		c.Logger = th.App.Srv().Log()
 
-		th.AddPermissionToRole(model.PermissionManageOutgoingWebhooks.Id, model.TeamAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOwnOutgoingWebhooks.Id, model.TeamAdminRoleId)
 
 		canRead := checkOutgoingOAuthConnectionReadPermissions(c, th.BasicTeam.Id)
 		require.True(t, canRead)
@@ -132,8 +128,7 @@ func TestCheckOutgoingOAuthConnectionWritePermissions(t *testing.T) {
 	t.Skip("https://mattermost.atlassian.net/browse/MM-61690")
 
 	t.Run("no permissions", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		session := model.Session{
 			Id:     model.NewId(),
@@ -150,8 +145,7 @@ func TestCheckOutgoingOAuthConnectionWritePermissions(t *testing.T) {
 	})
 
 	t.Run("with permissions", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		session := model.Session{
 			Id:     model.NewId(),
@@ -163,7 +157,7 @@ func TestCheckOutgoingOAuthConnectionWritePermissions(t *testing.T) {
 		c.App = th.App
 		c.Logger = th.App.Srv().Log()
 
-		th.AddPermissionToRole(model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
 
 		canWrite := checkOutgoingOAuthConnectionWritePermissions(c)
 		require.True(t, canWrite)
@@ -178,14 +172,13 @@ func TestClientOutgoingOAuthConnectionGet(t *testing.T) {
 	t.Run("No license returns 501", func(t *testing.T) {
 		os.Setenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTION", "true")
 		defer os.Unsetenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTION")
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
-		defaultRolePermissions := th.SaveDefaultRolePermissions()
+		th := Setup(t).InitBasic(t)
+		defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 		defer func() {
-			th.RestoreDefaultRolePermissions(defaultRolePermissions)
+			th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 		}()
-		th.AddPermissionToRole(model.PermissionManageOutgoingWebhooks.Id, model.TeamAdminRoleId)
-		th.AddPermissionToRole(model.PermissionManageSlashCommands.Id, model.TeamAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOwnOutgoingWebhooks.Id, model.TeamAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOwnSlashCommands.Id, model.TeamAdminRoleId)
 
 		outgoingOauthIface := &mocks.OutgoingOAuthConnectionInterface{}
 		outgoingOauthImpl := th.App.Srv().OutgoingOAuthConnection
@@ -195,7 +188,7 @@ func TestClientOutgoingOAuthConnectionGet(t *testing.T) {
 		th.App.Srv().OutgoingOAuthConnection = outgoingOauthIface
 
 		// th.Client.Login(context.Background(), th.BasicUser.Email, th.BasicUser.Password)
-		th.LoginTeamAdmin()
+		th.LoginTeamAdmin(t)
 
 		filters := model.OutgoingOAuthConnectionGetConnectionsFilter{
 			Limit:  10,
@@ -208,15 +201,14 @@ func TestClientOutgoingOAuthConnectionGet(t *testing.T) {
 	})
 
 	t.Run("license but no config enabled returns 501", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
-		defaultRolePermissions := th.SaveDefaultRolePermissions()
+		defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 		defer func() {
-			th.RestoreDefaultRolePermissions(defaultRolePermissions)
+			th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 		}()
-		th.AddPermissionToRole(model.PermissionManageOutgoingWebhooks.Id, model.TeamAdminRoleId)
-		th.AddPermissionToRole(model.PermissionManageSlashCommands.Id, model.TeamAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOwnOutgoingWebhooks.Id, model.TeamAdminRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOwnSlashCommands.Id, model.TeamAdminRoleId)
 
 		outgoingOauthIface := &mocks.OutgoingOAuthConnectionInterface{}
 		outgoingOauthImpl := th.App.Srv().OutgoingOAuthConnection
@@ -233,7 +225,7 @@ func TestClientOutgoingOAuthConnectionGet(t *testing.T) {
 		appErr := th.App.Srv().RemoveLicense()
 		require.Nil(t, appErr)
 
-		th.LoginTeamAdmin()
+		th.LoginTeamAdmin(t)
 
 		filters := model.OutgoingOAuthConnectionGetConnectionsFilter{
 			Limit:  10,
@@ -251,8 +243,7 @@ func TestClientListOutgoingOAuthConnection(t *testing.T) {
 
 	os.Setenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTIONS", "true")
 	defer os.Unsetenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTIONS")
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	license := model.NewTestLicenseSKU(model.LicenseShortSkuEnterprise, "outgoing_oauth_connections")
 	license.Id = "test-license-id"
@@ -287,11 +278,11 @@ func TestClientListOutgoingOAuthConnection(t *testing.T) {
 	t.Run("manager do not require team id", func(t *testing.T) {
 		defer outgoingOauthConnectionsCleanup(t, th)
 
-		defaultRolePermissions := th.SaveDefaultRolePermissions()
+		defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 		defer func() {
-			th.RestoreDefaultRolePermissions(defaultRolePermissions)
+			th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 		}()
-		th.AddPermissionToRole(model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
 
 		outgoingOauthIface := &mocks.OutgoingOAuthConnectionInterface{}
 		th.App.Srv().OutgoingOAuthConnection = outgoingOauthIface
@@ -323,12 +314,12 @@ func TestClientListOutgoingOAuthConnection(t *testing.T) {
 	t.Run("empty", func(t *testing.T) {
 		defer outgoingOauthConnectionsCleanup(t, th)
 
-		defaultRolePermissions := th.SaveDefaultRolePermissions()
+		defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 		defer func() {
-			th.RestoreDefaultRolePermissions(defaultRolePermissions)
+			th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 		}()
-		th.AddPermissionToRole(model.PermissionManageOutgoingWebhooks.Id, model.SystemUserRoleId)
-		th.AddPermissionToRole(model.PermissionManageSlashCommands.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOwnOutgoingWebhooks.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOwnSlashCommands.Id, model.SystemUserRoleId)
 
 		outgoingOauthIface := &mocks.OutgoingOAuthConnectionInterface{}
 		th.App.Srv().OutgoingOAuthConnection = outgoingOauthIface
@@ -361,12 +352,12 @@ func TestClientListOutgoingOAuthConnection(t *testing.T) {
 	t.Run("filter by audience", func(t *testing.T) {
 		defer outgoingOauthConnectionsCleanup(t, th)
 
-		defaultRolePermissions := th.SaveDefaultRolePermissions()
+		defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 		defer func() {
-			th.RestoreDefaultRolePermissions(defaultRolePermissions)
+			th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 		}()
-		th.AddPermissionToRole(model.PermissionManageOutgoingWebhooks.Id, model.SystemUserRoleId)
-		th.AddPermissionToRole(model.PermissionManageSlashCommands.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOwnOutgoingWebhooks.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOwnSlashCommands.Id, model.SystemUserRoleId)
 
 		conn := newOutgoingOAuthConnection()
 		conn.Audiences = []string{"http://knowhere.com"}
@@ -407,12 +398,12 @@ func TestClientListOutgoingOAuthConnection(t *testing.T) {
 	t.Run("return result", func(t *testing.T) {
 		defer outgoingOauthConnectionsCleanup(t, th)
 
-		defaultRolePermissions := th.SaveDefaultRolePermissions()
+		defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 		defer func() {
-			th.RestoreDefaultRolePermissions(defaultRolePermissions)
+			th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 		}()
-		th.AddPermissionToRole(model.PermissionManageOutgoingWebhooks.Id, model.SystemUserRoleId)
-		th.AddPermissionToRole(model.PermissionManageSlashCommands.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOwnOutgoingWebhooks.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOwnSlashCommands.Id, model.SystemUserRoleId)
 
 		conn := newOutgoingOAuthConnection()
 		conn.CreatorId = model.NewId()
@@ -455,8 +446,7 @@ func TestClientGetOutgoingOAuthConnection(t *testing.T) {
 
 	os.Setenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTIONS", "true")
 	defer os.Unsetenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTIONS")
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 	defer func() {
 		appErr := th.App.Srv().RemoveLicense()
 		require.Nil(t, appErr)
@@ -491,11 +481,11 @@ func TestClientGetOutgoingOAuthConnection(t *testing.T) {
 	t.Run("return result (management permissions)", func(t *testing.T) {
 		defer outgoingOauthConnectionsCleanup(t, th)
 
-		defaultRolePermissions := th.SaveDefaultRolePermissions()
+		defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 		defer func() {
-			th.RestoreDefaultRolePermissions(defaultRolePermissions)
+			th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 		}()
-		th.AddPermissionToRole(model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
 
 		conn := newOutgoingOAuthConnection()
 		conn.CreatorId = model.NewId()
@@ -516,7 +506,7 @@ func TestClientGetOutgoingOAuthConnection(t *testing.T) {
 		})
 		th.App.Srv().OutgoingOAuthConnection = outgoingOauthIface
 
-		th.LoginSystemAdmin()
+		th.LoginSystemAdmin(t)
 		connection, response, err := th.Client.GetOutgoingOAuthConnection(context.Background(), conn.Id)
 		require.NoError(t, err)
 
@@ -532,8 +522,7 @@ func TestClientCreateOutgoingOAuthConnection(t *testing.T) {
 
 	os.Setenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTIONS", "true")
 	defer os.Unsetenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTIONS")
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 	defer func() {
 		appErr := th.App.Srv().RemoveLicense()
 		require.Nil(t, appErr)
@@ -562,7 +551,7 @@ func TestClientCreateOutgoingOAuthConnection(t *testing.T) {
 		})
 		th.App.Srv().OutgoingOAuthConnection = outgoingOauthIface
 
-		th.LoginSystemAdmin()
+		th.LoginSystemAdmin(t)
 
 		connection, response, err := th.Client.CreateOutgoingOAuthConnection(context.Background(), conn)
 		require.Error(t, err)
@@ -573,11 +562,11 @@ func TestClientCreateOutgoingOAuthConnection(t *testing.T) {
 	t.Run("ok", func(t *testing.T) {
 		defer outgoingOauthConnectionsCleanup(t, th)
 
-		defaultRolePermissions := th.SaveDefaultRolePermissions()
+		defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 		defer func() {
-			th.RestoreDefaultRolePermissions(defaultRolePermissions)
+			th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 		}()
-		th.AddPermissionToRole(model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
 
 		conn := newOutgoingOAuthConnection()
 		conn.CreatorId = model.NewId()
@@ -595,7 +584,7 @@ func TestClientCreateOutgoingOAuthConnection(t *testing.T) {
 		})
 		th.App.Srv().OutgoingOAuthConnection = outgoingOauthIface
 
-		th.LoginSystemAdmin()
+		th.LoginSystemAdmin(t)
 
 		connection, response, err := th.Client.CreateOutgoingOAuthConnection(context.Background(), conn)
 		require.NoError(t, err)
@@ -610,8 +599,7 @@ func TestClientUpdateOutgoingOAuthConnection(t *testing.T) {
 
 	os.Setenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTIONS", "true")
 	defer os.Unsetenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTIONS")
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 	defer func() {
 		appErr := th.App.Srv().RemoveLicense()
 		require.Nil(t, appErr)
@@ -639,7 +627,7 @@ func TestClientUpdateOutgoingOAuthConnection(t *testing.T) {
 		})
 		th.App.Srv().OutgoingOAuthConnection = outgoingOauthIface
 
-		th.LoginSystemAdmin()
+		th.LoginSystemAdmin(t)
 
 		connection, response, err := th.Client.UpdateOutgoingOAuthConnection(context.Background(), conn)
 		require.Error(t, err)
@@ -650,11 +638,11 @@ func TestClientUpdateOutgoingOAuthConnection(t *testing.T) {
 	t.Run("ok", func(t *testing.T) {
 		defer outgoingOauthConnectionsCleanup(t, th)
 
-		defaultRolePermissions := th.SaveDefaultRolePermissions()
+		defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 		defer func() {
-			th.RestoreDefaultRolePermissions(defaultRolePermissions)
+			th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 		}()
-		th.AddPermissionToRole(model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
 
 		conn := newOutgoingOAuthConnection()
 		conn.CreatorId = model.NewId()
@@ -675,7 +663,7 @@ func TestClientUpdateOutgoingOAuthConnection(t *testing.T) {
 		})
 		th.App.Srv().OutgoingOAuthConnection = outgoingOauthIface
 
-		th.LoginSystemAdmin()
+		th.LoginSystemAdmin(t)
 
 		updatedConn := conn
 		updatedConn.Name = "updated name"
@@ -694,8 +682,7 @@ func TestClientDeleteOutgoingOAuthConnection(t *testing.T) {
 
 	os.Setenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTIONS", "true")
 	defer os.Unsetenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTIONS")
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 	defer func() {
 		appErr := th.App.Srv().RemoveLicense()
 		require.Nil(t, appErr)
@@ -723,7 +710,7 @@ func TestClientDeleteOutgoingOAuthConnection(t *testing.T) {
 		})
 		th.App.Srv().OutgoingOAuthConnection = outgoingOauthIface
 
-		th.LoginSystemAdmin()
+		th.LoginSystemAdmin(t)
 
 		response, err := th.Client.DeleteOutgoingOAuthConnection(context.Background(), conn.Id)
 		require.Error(t, err)
@@ -733,11 +720,11 @@ func TestClientDeleteOutgoingOAuthConnection(t *testing.T) {
 	t.Run("ok", func(t *testing.T) {
 		defer outgoingOauthConnectionsCleanup(t, th)
 
-		defaultRolePermissions := th.SaveDefaultRolePermissions()
+		defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 		defer func() {
-			th.RestoreDefaultRolePermissions(defaultRolePermissions)
+			th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 		}()
-		th.AddPermissionToRole(model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
 
 		conn := newOutgoingOAuthConnection()
 		conn.CreatorId = model.NewId()
@@ -757,7 +744,7 @@ func TestClientDeleteOutgoingOAuthConnection(t *testing.T) {
 		})
 		th.App.Srv().OutgoingOAuthConnection = outgoingOauthIface
 
-		th.LoginSystemAdmin()
+		th.LoginSystemAdmin(t)
 
 		response, err := th.Client.DeleteOutgoingOAuthConnection(context.Background(), conn.Id)
 		require.NoError(t, err)
@@ -771,8 +758,7 @@ func TestEnsureOutgoingOAuthConnectionInterface(t *testing.T) {
 	t.Skip("https://mattermost.atlassian.net/browse/MM-61690")
 
 	t.Run("no feature flag, no interface, no license", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		c := &Context{}
 		c.AppContext = th.Context
@@ -786,8 +772,7 @@ func TestEnsureOutgoingOAuthConnectionInterface(t *testing.T) {
 	})
 
 	t.Run("config, no interface, no license", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		outgoingOAuthConnectionConfig := th.App.Config().ServiceSettings.EnableOutgoingOAuthConnections
 		th.App.Config().ServiceSettings.EnableOutgoingOAuthConnections = model.NewPointer(true)
@@ -807,8 +792,7 @@ func TestEnsureOutgoingOAuthConnectionInterface(t *testing.T) {
 	})
 
 	t.Run("feature flag, interface defined, no license", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		outgoingOauthIface := &mocks.OutgoingOAuthConnectionInterface{}
 		outgoingOauthImpl := th.App.Srv().OutgoingOAuthConnection
@@ -830,8 +814,7 @@ func TestEnsureOutgoingOAuthConnectionInterface(t *testing.T) {
 	})
 
 	t.Run("feature flag, interface defined, valid license", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		outgoingOauthIface := &mocks.OutgoingOAuthConnectionInterface{}
 		outgoingOauthImpl := th.App.Srv().OutgoingOAuthConnection
@@ -867,8 +850,7 @@ func TestHandlerOutgoingOAuthConnectionListGet(t *testing.T) {
 
 	os.Setenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTIONS", "true")
 	defer os.Unsetenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTIONS")
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	license := model.NewTestLicenseSKU(model.LicenseShortSkuEnterprise, "outgoing_oauth_connections")
 	license.Id = "test-license-id"
@@ -898,13 +880,13 @@ func TestHandlerOutgoingOAuthConnectionListGet(t *testing.T) {
 	th.App.Config().ServiceSettings.EnableOutgoingOAuthConnections = model.NewPointer(true)
 	th.App.Srv().OutgoingOAuthConnection = outgoingOauthIface
 
-	defaultRolePermissions := th.SaveDefaultRolePermissions()
+	defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 	defer func() {
 		th.App.Srv().OutgoingOAuthConnection = outgoingOauthImpl
 		th.App.Config().ServiceSettings.EnableOutgoingOAuthConnections = outgoingOAuthConnectionConfig
-		th.RestoreDefaultRolePermissions(defaultRolePermissions)
+		th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 	}()
-	th.AddPermissionToRole(model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
+	th.AddPermissionToRole(t, model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
 
 	t.Run("getOutgoingOAuthConnection", func(t *testing.T) {
 		req, err := http.NewRequest("GET", "/", nil)
@@ -995,8 +977,7 @@ func TestHandlerOutgoingOAuthConnectionListReadOnly(t *testing.T) {
 
 	os.Setenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTIONS", "true")
 	defer os.Unsetenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTIONS")
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	license := model.NewTestLicenseSKU(model.LicenseShortSkuEnterprise, "outgoing_oauth_connections")
 	license.Id = "test-license-id"
@@ -1026,13 +1007,13 @@ func TestHandlerOutgoingOAuthConnectionListReadOnly(t *testing.T) {
 	th.App.Config().ServiceSettings.EnableOutgoingOAuthConnections = model.NewPointer(true)
 	th.App.Srv().OutgoingOAuthConnection = outgoingOauthIface
 
-	defaultRolePermissions := th.SaveDefaultRolePermissions()
+	defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 	defer func() {
 		th.App.Srv().OutgoingOAuthConnection = outgoingOauthImpl
 		th.App.Config().ServiceSettings.EnableOutgoingOAuthConnections = outgoingOAuthConnectionConfig
-		th.RestoreDefaultRolePermissions(defaultRolePermissions)
+		th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 	}()
-	th.AddPermissionToRole(model.PermissionManageOthersOutgoingWebhooks.Id, model.TeamAdminRoleId)
+	th.AddPermissionToRole(t, model.PermissionManageOthersOutgoingWebhooks.Id, model.TeamAdminRoleId)
 
 	t.Run("listOutgoingOAuthConnections", func(t *testing.T) {
 		req, err := http.NewRequest("GET", "/?team_id="+th.BasicTeam.Id, nil)
@@ -1094,8 +1075,7 @@ func TestHandlerOutgoingOAuthConnectionUpdate(t *testing.T) {
 
 	os.Setenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTIONS", "true")
 	defer os.Unsetenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTIONS")
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	license := model.NewTestLicenseSKU(model.LicenseShortSkuEnterprise, "outgoing_oauth_connections")
 	license.Id = "test-license-id"
@@ -1146,12 +1126,12 @@ func TestHandlerOutgoingOAuthConnectionUpdate(t *testing.T) {
 		}
 		c.AppContext = th.Context.WithSession(&session)
 
-		defaultRolePermissions := th.SaveDefaultRolePermissions()
+		defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 		defer func() {
-			th.RestoreDefaultRolePermissions(defaultRolePermissions)
+			th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 		}()
 
-		th.AddPermissionToRole(model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
 
 		body := &bytes.Buffer{}
 		body.Write([]byte(`{/}`))
@@ -1198,12 +1178,12 @@ func TestHandlerOutgoingOAuthConnectionUpdate(t *testing.T) {
 		}
 		c.AppContext = th.Context.WithSession(&session)
 
-		defaultRolePermissions := th.SaveDefaultRolePermissions()
+		defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 		defer func() {
-			th.RestoreDefaultRolePermissions(defaultRolePermissions)
+			th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 		}()
 
-		th.AddPermissionToRole(model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
 
 		body := &bytes.Buffer{}
 		body.Write([]byte(`{"Id": "` + model.NewId() + `", "name": "changed name"}`))
@@ -1252,11 +1232,11 @@ func TestHandlerOutgoingOAuthConnectionUpdate(t *testing.T) {
 		}
 		c.AppContext = th.Context.WithSession(&session)
 
-		defaultRolePermissions := th.SaveDefaultRolePermissions()
+		defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 		defer func() {
-			th.RestoreDefaultRolePermissions(defaultRolePermissions)
+			th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 		}()
-		th.AddPermissionToRole(model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
 
 		conn.Id = model.NewId() // Faking an ID for the connection
 		t.Cleanup(func() {
@@ -1309,8 +1289,7 @@ func TestHandlerOutgoingOAuthConnectionHandlerCreate(t *testing.T) {
 
 	os.Setenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTIONS", "true")
 	defer os.Unsetenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTIONS")
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	license := model.NewTestLicenseSKU(model.LicenseShortSkuEnterprise, "outgoing_oauth_connections")
 	license.Id = "test-license-id"
@@ -1363,12 +1342,12 @@ func TestHandlerOutgoingOAuthConnectionHandlerCreate(t *testing.T) {
 		}
 		c.AppContext = th.Context.WithSession(&session)
 
-		defaultRolePermissions := th.SaveDefaultRolePermissions()
+		defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 		defer func() {
-			th.RestoreDefaultRolePermissions(defaultRolePermissions)
+			th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 		}()
 
-		th.AddPermissionToRole(model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
 
 		body := &bytes.Buffer{}
 		body.Write([]byte(`{/}`))
@@ -1413,11 +1392,11 @@ func TestHandlerOutgoingOAuthConnectionHandlerCreate(t *testing.T) {
 		}
 		c.AppContext = th.Context.WithSession(&session)
 
-		defaultRolePermissions := th.SaveDefaultRolePermissions()
+		defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 		defer func() {
-			th.RestoreDefaultRolePermissions(defaultRolePermissions)
+			th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 		}()
-		th.AddPermissionToRole(model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
 
 		body := &bytes.Buffer{}
 		require.NoError(t, json.NewEncoder(body).Encode(conn))
@@ -1460,8 +1439,7 @@ func TestHandlerOutgoingOAuthConnectionHandlerValidate(t *testing.T) {
 
 	os.Setenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTIONS", "true")
 	defer os.Unsetenv("MM_FEATUREFLAGS_OUTGOINGOAUTHCONNECTIONS")
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	license := model.NewTestLicenseSKU(model.LicenseShortSkuEnterprise, "outgoing_oauth_connections")
 	license.Id = "test-license-id"
@@ -1535,11 +1513,11 @@ func TestHandlerOutgoingOAuthConnectionHandlerValidate(t *testing.T) {
 		}
 		c.AppContext = th.Context.WithSession(&session)
 
-		defaultRolePermissions := th.SaveDefaultRolePermissions()
+		defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 		defer func() {
-			th.RestoreDefaultRolePermissions(defaultRolePermissions)
+			th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 		}()
-		th.AddPermissionToRole(model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
 
 		outgoingOauthImpl := th.App.Srv().OutgoingOAuthConnection
 		defer func() {
@@ -1574,11 +1552,11 @@ func TestHandlerOutgoingOAuthConnectionHandlerValidate(t *testing.T) {
 		}
 		c.AppContext = th.Context.WithSession(&session)
 
-		defaultRolePermissions := th.SaveDefaultRolePermissions()
+		defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 		defer func() {
-			th.RestoreDefaultRolePermissions(defaultRolePermissions)
+			th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 		}()
-		th.AddPermissionToRole(model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
 
 		body := &bytes.Buffer{}
 		require.NoError(t, json.NewEncoder(body).Encode(conn))
@@ -1625,11 +1603,11 @@ func TestHandlerOutgoingOAuthConnectionHandlerValidate(t *testing.T) {
 		}
 		c.AppContext = th.Context.WithSession(&session)
 
-		defaultRolePermissions := th.SaveDefaultRolePermissions()
+		defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 		defer func() {
-			th.RestoreDefaultRolePermissions(defaultRolePermissions)
+			th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 		}()
-		th.AddPermissionToRole(model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
 
 		body := &bytes.Buffer{}
 		require.NoError(t, json.NewEncoder(body).Encode(conn))
@@ -1680,11 +1658,11 @@ func TestHandlerOutgoingOAuthConnectionHandlerValidate(t *testing.T) {
 			OutgoingOAuthConnectionID: conn.Id,
 		}
 
-		defaultRolePermissions := th.SaveDefaultRolePermissions()
+		defaultRolePermissions := th.SaveDefaultRolePermissions(t)
 		defer func() {
-			th.RestoreDefaultRolePermissions(defaultRolePermissions)
+			th.RestoreDefaultRolePermissions(t, defaultRolePermissions)
 		}()
-		th.AddPermissionToRole(model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
+		th.AddPermissionToRole(t, model.PermissionManageOutgoingOAuthConnections.Id, model.SystemUserRoleId)
 
 		body := &bytes.Buffer{}
 		require.NoError(t, json.NewEncoder(body).Encode(conn))
