@@ -17,13 +17,12 @@ import (
 
 func TestGetPreferences(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 	client := th.Client
 
 	// recreate basic user (cached has no default preferences)
-	th.BasicUser = th.CreateUser()
-	th.LoginBasic()
+	th.BasicUser = th.CreateUser(t)
+	th.LoginBasic(t)
 
 	user1 := th.BasicUser
 
@@ -60,8 +59,8 @@ func TestGetPreferences(t *testing.T) {
 	}
 
 	// recreate basic user2
-	th.BasicUser2 = th.CreateUser()
-	th.LoginBasic2()
+	th.BasicUser2 = th.CreateUser(t)
+	th.LoginBasic2(t)
 
 	prefs, _, err = client.GetPreferences(context.Background(), th.BasicUser2.Id)
 	require.NoError(t, err)
@@ -89,11 +88,10 @@ func TestGetPreferences(t *testing.T) {
 
 func TestGetPreferencesByCategory(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 	client := th.Client
 
-	th.LoginBasic()
+	th.LoginBasic(t)
 	user1 := th.BasicUser
 
 	category := model.NewId()
@@ -127,7 +125,7 @@ func TestGetPreferencesByCategory(t *testing.T) {
 	require.Error(t, err)
 	CheckNotFoundStatus(t, resp)
 
-	th.LoginBasic2()
+	th.LoginBasic2(t)
 
 	_, resp, err = client.GetPreferencesByCategory(context.Background(), th.BasicUser2.Id, category)
 	require.Error(t, err)
@@ -160,11 +158,10 @@ func TestGetPreferencesByCategory(t *testing.T) {
 
 func TestGetPreferenceByCategoryAndName(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 	client := th.Client
 
-	th.LoginBasic()
+	th.LoginBasic(t)
 	user := th.BasicUser
 	name := model.NewId()
 	value := model.NewId()
@@ -230,11 +227,10 @@ func TestGetPreferenceByCategoryAndName(t *testing.T) {
 
 func TestUpdatePreferences(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 	client := th.Client
 
-	th.LoginBasic()
+	th.LoginBasic(t)
 	user1 := th.BasicUser
 
 	category := model.NewId()
@@ -310,11 +306,10 @@ func TestUpdatePreferences(t *testing.T) {
 
 func TestUpdatePreferencesOverload(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 	client := th.Client
 
-	th.LoginBasic()
+	th.LoginBasic(t)
 	user1 := th.BasicUser
 
 	t.Run("No preferences", func(t *testing.T) {
@@ -347,8 +342,7 @@ func TestUpdatePreferencesOverload(t *testing.T) {
 
 func TestUpdatePreferencesWebsocket(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	WebSocketClient := th.CreateConnectedWebSocketClient(t)
 
@@ -400,19 +394,18 @@ func TestUpdatePreferencesWebsocket(t *testing.T) {
 func TestUpdateSidebarPreferences(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("when favoriting a channel, should add it to the Favorites sidebar category", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		user := th.BasicUser
 
-		team1 := th.CreateTeam()
-		th.LinkUserToTeam(user, team1)
+		team1 := th.CreateTeam(t)
+		th.LinkUserToTeam(t, user, team1)
 
 		_, _, err := th.Client.GetSidebarCategoriesForTeamForUser(context.Background(), user.Id, team1.Id, "")
 		require.NoError(t, err)
 
-		channel := th.CreateChannelWithClientAndTeam(th.Client, model.ChannelTypeOpen, team1.Id)
-		th.AddUserToChannel(user, channel)
+		channel := th.CreateChannelWithClientAndTeam(t, th.Client, model.ChannelTypeOpen, team1.Id)
+		th.AddUserToChannel(t, user, channel)
 
 		// Confirm that the sidebar is populated correctly to begin with
 		categories, _, err := th.Client.GetSidebarCategoriesForTeamForUser(context.Background(), user.Id, team1.Id, "")
@@ -462,18 +455,17 @@ func TestUpdateSidebarPreferences(t *testing.T) {
 	})
 
 	t.Run("when favoriting a DM channel, should add it to the Favorites sidebar category for all teams", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		user := th.BasicUser
 		user2 := th.BasicUser2
 
-		team1 := th.CreateTeam()
-		th.LinkUserToTeam(user, team1)
-		team2 := th.CreateTeam()
-		th.LinkUserToTeam(user, team2)
+		team1 := th.CreateTeam(t)
+		th.LinkUserToTeam(t, user, team1)
+		team2 := th.CreateTeam(t)
+		th.LinkUserToTeam(t, user, team2)
 
-		dmChannel := th.CreateDmChannel(user2)
+		dmChannel := th.CreateDmChannel(t, user2)
 
 		// Favorite the channel
 		_, err := th.Client.UpdatePreferences(context.Background(), user.Id, model.Preferences{
@@ -529,27 +521,26 @@ func TestUpdateSidebarPreferences(t *testing.T) {
 	})
 
 	t.Run("when favoriting a channel, should not affect other users' favorites categories", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		user := th.BasicUser
 		user2 := th.BasicUser2
 
 		client2 := th.CreateClient()
-		th.LoginBasic2WithClient(client2)
+		th.LoginBasic2WithClient(t, client2)
 
-		team1 := th.CreateTeam()
-		th.LinkUserToTeam(user, team1)
-		th.LinkUserToTeam(user2, team1)
+		team1 := th.CreateTeam(t)
+		th.LinkUserToTeam(t, user, team1)
+		th.LinkUserToTeam(t, user2, team1)
 
 		_, _, err := th.Client.GetSidebarCategoriesForTeamForUser(context.Background(), user.Id, team1.Id, "")
 		require.NoError(t, err)
 		_, _, err = client2.GetSidebarCategoriesForTeamForUser(context.Background(), user2.Id, team1.Id, "")
 		require.NoError(t, err)
 
-		channel := th.CreateChannelWithClientAndTeam(th.Client, model.ChannelTypeOpen, team1.Id)
-		th.AddUserToChannel(user, channel)
-		th.AddUserToChannel(user2, channel)
+		channel := th.CreateChannelWithClientAndTeam(t, th.Client, model.ChannelTypeOpen, team1.Id)
+		th.AddUserToChannel(t, user, channel)
+		th.AddUserToChannel(t, user2, channel)
 
 		// Confirm that the sidebar is populated correctly to begin with
 		categories, _, err := th.Client.GetSidebarCategoriesForTeamForUser(context.Background(), user.Id, team1.Id, "")
@@ -627,11 +618,10 @@ func TestUpdateSidebarPreferences(t *testing.T) {
 
 func TestDeletePreferences(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 	client := th.Client
 
-	th.LoginBasic()
+	th.LoginBasic(t)
 
 	prefs, _, _ := client.GetPreferences(context.Background(), th.BasicUser.Id)
 	originalCount := len(prefs)
@@ -651,13 +641,13 @@ func TestDeletePreferences(t *testing.T) {
 	require.NoError(t, err)
 
 	// delete 10 preferences
-	th.LoginBasic2()
+	th.LoginBasic2(t)
 
 	resp, err := client.DeletePreferences(context.Background(), th.BasicUser2.Id, preferences)
 	require.Error(t, err)
 	CheckForbiddenStatus(t, resp)
 
-	th.LoginBasic()
+	th.LoginBasic(t)
 
 	_, err = client.DeletePreferences(context.Background(), th.BasicUser.Id, preferences)
 	require.NoError(t, err)
@@ -698,11 +688,10 @@ func TestDeletePreferences(t *testing.T) {
 
 func TestDeletePreferencesOverload(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 	client := th.Client
 
-	th.LoginBasic()
+	th.LoginBasic(t)
 	user1 := th.BasicUser
 
 	t.Run("No preferences", func(t *testing.T) {
@@ -735,8 +724,7 @@ func TestDeletePreferencesOverload(t *testing.T) {
 
 func TestDeletePreferencesWebsocket(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	userId := th.BasicUser.Id
 	preferences := model.Preferences{
@@ -790,19 +778,18 @@ func TestDeletePreferencesWebsocket(t *testing.T) {
 func TestDeleteSidebarPreferences(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("when removing a favorited channel preference, should remove it from the Favorites sidebar category", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		user := th.BasicUser
 
-		team1 := th.CreateTeam()
-		th.LinkUserToTeam(user, team1)
+		team1 := th.CreateTeam(t)
+		th.LinkUserToTeam(t, user, team1)
 
 		_, _, err := th.Client.GetSidebarCategoriesForTeamForUser(context.Background(), user.Id, team1.Id, "")
 		require.NoError(t, err)
 
-		channel := th.CreateChannelWithClientAndTeam(th.Client, model.ChannelTypeOpen, team1.Id)
-		th.AddUserToChannel(user, channel)
+		channel := th.CreateChannelWithClientAndTeam(t, th.Client, model.ChannelTypeOpen, team1.Id)
+		th.AddUserToChannel(t, user, channel)
 
 		// Confirm that the sidebar is populated correctly to begin with
 		categories, _, err := th.Client.GetSidebarCategoriesForTeamForUser(context.Background(), user.Id, team1.Id, "")
@@ -850,18 +837,17 @@ func TestDeleteSidebarPreferences(t *testing.T) {
 	})
 
 	t.Run("when removing a favorited DM preference, should remove it from the Favorites sidebar category", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		user := th.BasicUser
 		user2 := th.BasicUser2
 
-		team1 := th.CreateTeam()
-		th.LinkUserToTeam(user, team1)
-		team2 := th.CreateTeam()
-		th.LinkUserToTeam(user, team2)
+		team1 := th.CreateTeam(t)
+		th.LinkUserToTeam(t, user, team1)
+		team2 := th.CreateTeam(t)
+		th.LinkUserToTeam(t, user, team2)
 
-		dmChannel := th.CreateDmChannel(user2)
+		dmChannel := th.CreateDmChannel(t, user2)
 
 		// Favorite the channel
 		_, err := th.Client.UpdatePreferences(context.Background(), user.Id, model.Preferences{
@@ -916,27 +902,26 @@ func TestDeleteSidebarPreferences(t *testing.T) {
 	})
 
 	t.Run("when removing a favorited channel preference, should not affect other users' favorites categories", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		user := th.BasicUser
 		user2 := th.BasicUser2
 
 		client2 := th.CreateClient()
-		th.LoginBasic2WithClient(client2)
+		th.LoginBasic2WithClient(t, client2)
 
-		team1 := th.CreateTeam()
-		th.LinkUserToTeam(user, team1)
-		th.LinkUserToTeam(user2, team1)
+		team1 := th.CreateTeam(t)
+		th.LinkUserToTeam(t, user, team1)
+		th.LinkUserToTeam(t, user2, team1)
 
 		_, _, err := th.Client.GetSidebarCategoriesForTeamForUser(context.Background(), user.Id, team1.Id, "")
 		require.NoError(t, err)
 		_, _, err = client2.GetSidebarCategoriesForTeamForUser(context.Background(), user2.Id, team1.Id, "")
 		require.NoError(t, err)
 
-		channel := th.CreateChannelWithClientAndTeam(th.Client, model.ChannelTypeOpen, team1.Id)
-		th.AddUserToChannel(user, channel)
-		th.AddUserToChannel(user2, channel)
+		channel := th.CreateChannelWithClientAndTeam(t, th.Client, model.ChannelTypeOpen, team1.Id)
+		th.AddUserToChannel(t, user, channel)
+		th.AddUserToChannel(t, user2, channel)
 
 		// Confirm that the sidebar is populated correctly to begin with
 		categories, _, err := th.Client.GetSidebarCategoriesForTeamForUser(context.Background(), user.Id, team1.Id, "")
@@ -1006,11 +991,10 @@ func TestDeleteSidebarPreferences(t *testing.T) {
 func TestUpdateLimitVisibleDMsGMs(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("Update limit_visible_dms_gms to a valid value", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 		client := th.Client
 
-		th.LoginBasic()
+		th.LoginBasic(t)
 		user := th.BasicUser
 
 		_, err := client.UpdatePreferences(context.Background(), user.Id, model.Preferences{
@@ -1030,11 +1014,10 @@ func TestUpdateLimitVisibleDMsGMs(t *testing.T) {
 	})
 
 	t.Run("Update limit_visible_dms_gms to a value greater PreferenceMaxLimitVisibleDmsGmsValue", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 		client := th.Client
 
-		th.LoginBasic()
+		th.LoginBasic(t)
 		user := th.BasicUser
 
 		resp, err := client.UpdatePreferences(context.Background(), user.Id, model.Preferences{
@@ -1050,11 +1033,10 @@ func TestUpdateLimitVisibleDMsGMs(t *testing.T) {
 	})
 
 	t.Run("Update limit_visible_dms_gms to an invalid value", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 		client := th.Client
 
-		th.LoginBasic()
+		th.LoginBasic(t)
 		user := th.BasicUser
 
 		resp, err := client.UpdatePreferences(context.Background(), user.Id, model.Preferences{
@@ -1070,11 +1052,10 @@ func TestUpdateLimitVisibleDMsGMs(t *testing.T) {
 	})
 
 	t.Run("Update limit_visible_dms_gms to a negative number", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 		client := th.Client
 
-		th.LoginBasic()
+		th.LoginBasic(t)
 		user := th.BasicUser
 
 		resp, err := client.UpdatePreferences(context.Background(), user.Id, model.Preferences{
