@@ -17,7 +17,6 @@ import (
 func TestCreateScheme(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	th.App.Srv().SetLicense(model.NewTestLicense("custom_permissions_schemes"))
 
@@ -180,7 +179,7 @@ func TestCreateScheme(t *testing.T) {
 	err = th.App.SetPhase2PermissionsMigrationStatus(false)
 	require.NoError(t, err)
 
-	th.LoginSystemAdmin()
+	th.LoginSystemAdmin(t)
 	th.App.Srv().SetLicense(model.NewTestLicense("custom_permissions_schemes"))
 
 	scheme7 := &model.Scheme{
@@ -195,8 +194,7 @@ func TestCreateScheme(t *testing.T) {
 
 func TestGetScheme(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	th.App.Srv().SetLicense(model.NewTestLicense("custom_permissions_schemes"))
 
@@ -263,8 +261,7 @@ func TestGetScheme(t *testing.T) {
 
 func TestGetSchemes(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	th.App.Srv().SetLicense(model.NewTestLicense("custom_permissions_schemes"))
 
@@ -332,8 +329,7 @@ func TestGetSchemes(t *testing.T) {
 
 func TestGetTeamsForScheme(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	th.App.Srv().SetLicense(model.NewTestLicense("custom_permissions_schemes"))
 
@@ -430,8 +426,7 @@ func TestGetTeamsForScheme(t *testing.T) {
 
 func TestGetChannelsForScheme(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	th.App.Srv().SetLicense(model.NewTestLicense("custom_permissions_schemes"))
 
@@ -531,7 +526,6 @@ func TestGetChannelsForScheme(t *testing.T) {
 func TestPatchScheme(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	th.App.Srv().SetLicense(model.NewTestLicense("custom_permissions_schemes"))
 
@@ -650,7 +644,7 @@ func TestPatchScheme(t *testing.T) {
 	err = th.App.SetPhase2PermissionsMigrationStatus(false)
 	require.NoError(t, err)
 
-	th.LoginSystemAdmin()
+	th.LoginSystemAdmin(t)
 	th.App.Srv().SetLicense(model.NewTestLicense("custom_permissions_schemes"))
 
 	_, r12, _ := th.SystemAdminClient.PatchScheme(context.Background(), s6.Id, schemePatch)
@@ -660,7 +654,6 @@ func TestPatchScheme(t *testing.T) {
 func TestDeleteScheme(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	t.Run("ValidTeamScheme", func(t *testing.T) {
 		th.App.Srv().SetLicense(model.NewTestLicense("custom_permissions_schemes"))
@@ -879,18 +872,17 @@ func TestDeleteScheme(t *testing.T) {
 
 func TestUpdateTeamSchemeWithTeamMembers(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	t.Run("Correctly invalidates team member cache", func(t *testing.T) {
 		err := th.App.SetPhase2PermissionsMigrationStatus(true)
 		require.NoError(t, err)
 
-		team := th.CreateTeam()
+		team := th.CreateTeam(t)
 		_, _, appErr := th.App.AddUserToTeam(th.Context, team.Id, th.BasicUser.Id, th.SystemAdminUser.Id)
 		require.Nil(t, appErr)
 
-		teamScheme := th.SetupTeamScheme()
+		teamScheme := th.SetupTeamScheme(t)
 
 		teamUserRole, appErr := th.App.GetRoleByName(th.Context, teamScheme.DefaultTeamUserRole)
 		require.Nil(t, appErr)
@@ -898,7 +890,7 @@ func TestUpdateTeamSchemeWithTeamMembers(t *testing.T) {
 		_, appErr = th.App.UpdateRole(teamUserRole)
 		require.Nil(t, appErr)
 
-		th.LoginBasic()
+		th.LoginBasic(t)
 
 		_, _, err = th.Client.CreateChannel(context.Background(), &model.Channel{DisplayName: "Test API Name", Name: GenerateTestChannelName(), Type: model.ChannelTypeOpen, TeamId: team.Id})
 		require.NoError(t, err)
