@@ -35,8 +35,7 @@ func setupForSharedChannels(tb testing.TB) *TestHelper {
 
 func TestGetAllSharedChannels(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := setupForSharedChannels(t).InitBasic()
-	defer th.TearDown()
+	th := setupForSharedChannels(t).InitBasic(t)
 
 	const pages = 3
 	const pageSize = 7
@@ -45,7 +44,7 @@ func TestGetAllSharedChannels(t *testing.T) {
 
 	// make some shared channels
 	for i := range pages * pageSize {
-		channel := th.CreateChannelWithClientAndTeam(th.Client, model.ChannelTypeOpen, th.BasicTeam.Id)
+		channel := th.CreateChannelWithClientAndTeam(t, th.Client, model.ChannelTypeOpen, th.BasicTeam.Id)
 		sc := &model.SharedChannel{
 			ChannelId: channel.Id,
 			TeamId:    channel.TeamId,
@@ -107,8 +106,7 @@ func randomBool() bool {
 
 func TestGetRemoteClusterById(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := setupForSharedChannels(t).InitBasic()
-	defer th.TearDown()
+	th := setupForSharedChannels(t).InitBasic(t)
 
 	// for this test we need a user that belongs to a channel that
 	// is shared with the requested remote id.
@@ -163,8 +161,8 @@ func TestGetRemoteClusterById(t *testing.T) {
 func TestCreateDirectChannelWithRemoteUser(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("should not create a local DM channel that is shared", func(t *testing.T) {
-		th := setupForSharedChannels(t).InitBasic()
-		defer th.TearDown()
+		th := setupForSharedChannels(t).InitBasic(t)
+
 		client := th.Client
 		defer func() {
 			_, err := client.Logout(context.Background())
@@ -172,7 +170,7 @@ func TestCreateDirectChannelWithRemoteUser(t *testing.T) {
 		}()
 
 		localUser := th.BasicUser
-		remoteUser := th.CreateUser()
+		remoteUser := th.CreateUser(t)
 		remoteUser.RemoteId = model.NewPointer(model.NewId())
 		remoteUser, appErr := th.App.UpdateUser(th.Context, remoteUser, false)
 		require.Nil(t, appErr)
@@ -185,8 +183,8 @@ func TestCreateDirectChannelWithRemoteUser(t *testing.T) {
 	t.Run("creates a local DM channel that is shared", func(t *testing.T) {
 		t.Skip("Remote DMs are currently disabled")
 
-		th := setupForSharedChannels(t).InitBasic()
-		defer th.TearDown()
+		th := setupForSharedChannels(t).InitBasic(t)
+
 		client := th.Client
 		defer func() {
 			_, err := client.Logout(context.Background())
@@ -194,7 +192,7 @@ func TestCreateDirectChannelWithRemoteUser(t *testing.T) {
 		}()
 
 		localUser := th.BasicUser
-		remoteUser := th.CreateUser()
+		remoteUser := th.CreateUser(t)
 		remoteUser.RemoteId = model.NewPointer(model.NewId())
 		remoteUser, appErr := th.App.UpdateUser(th.Context, remoteUser, false)
 		require.Nil(t, appErr)
@@ -210,8 +208,8 @@ func TestCreateDirectChannelWithRemoteUser(t *testing.T) {
 	t.Run("sends a shared channel invitation to the remote", func(t *testing.T) {
 		t.Skip("Remote DMs are currently disabled")
 
-		th := setupForSharedChannels(t).InitBasic()
-		defer th.TearDown()
+		th := setupForSharedChannels(t).InitBasic(t)
+
 		client := th.Client
 		defer func() {
 			_, err := client.Logout(context.Background())
@@ -219,7 +217,7 @@ func TestCreateDirectChannelWithRemoteUser(t *testing.T) {
 		}()
 
 		localUser := th.BasicUser
-		remoteUser := th.CreateUser()
+		remoteUser := th.CreateUser(t)
 
 		rc := &model.RemoteCluster{
 			Name:      "test",
@@ -244,8 +242,8 @@ func TestCreateDirectChannelWithRemoteUser(t *testing.T) {
 	t.Run("does not send a shared channel invitation to the remote when creator is remote", func(t *testing.T) {
 		t.Skip("Remote DMs are currently disabled")
 
-		th := setupForSharedChannels(t).InitBasic()
-		defer th.TearDown()
+		th := setupForSharedChannels(t).InitBasic(t)
+
 		client := th.Client
 		defer func() {
 			_, err := client.Logout(context.Background())
@@ -253,7 +251,7 @@ func TestCreateDirectChannelWithRemoteUser(t *testing.T) {
 		}()
 
 		localUser := th.BasicUser
-		remoteUser := th.CreateUser()
+		remoteUser := th.CreateUser(t)
 
 		rc := &model.RemoteCluster{
 			Name:      "test",
@@ -280,15 +278,13 @@ func TestGetSharedChannelRemotesByRemoteCluster(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("Should not work if the remote cluster service is not enabled", func(t *testing.T) {
 		th := Setup(t)
-		defer th.TearDown()
 
 		resp, err := th.SystemAdminClient.DeleteRemoteCluster(context.Background(), model.NewId())
 		CheckNotImplementedStatus(t, resp)
 		require.Error(t, err)
 	})
 
-	th := setupForSharedChannels(t).InitBasic()
-	defer th.TearDown()
+	th := setupForSharedChannels(t).InitBasic(t)
 
 	newRC1 := &model.RemoteCluster{Name: "rc1", SiteURL: "http://example1.com", CreatorId: th.SystemAdminUser.Id}
 	newRC2 := &model.RemoteCluster{Name: "rc2", SiteURL: "http://example2.com", CreatorId: th.SystemAdminUser.Id}
@@ -298,7 +294,7 @@ func TestGetSharedChannelRemotesByRemoteCluster(t *testing.T) {
 	rc2, appErr := th.App.AddRemoteCluster(newRC2)
 	require.Nil(t, appErr)
 
-	c1 := th.CreateChannelWithClientAndTeam(th.Client, model.ChannelTypeOpen, th.BasicTeam.Id)
+	c1 := th.CreateChannelWithClientAndTeam(t, th.Client, model.ChannelTypeOpen, th.BasicTeam.Id)
 	sc1 := &model.SharedChannel{
 		ChannelId:        c1.Id,
 		TeamId:           th.BasicTeam.Id,
@@ -311,7 +307,7 @@ func TestGetSharedChannelRemotesByRemoteCluster(t *testing.T) {
 	_, err := th.App.ShareChannel(th.Context, sc1)
 	require.NoError(t, err)
 
-	c2 := th.CreateChannelWithClientAndTeam(th.Client, model.ChannelTypeOpen, th.BasicTeam.Id)
+	c2 := th.CreateChannelWithClientAndTeam(t, th.Client, model.ChannelTypeOpen, th.BasicTeam.Id)
 	sc2 := &model.SharedChannel{
 		ChannelId:        c2.Id,
 		TeamId:           th.BasicTeam.Id,
@@ -325,7 +321,7 @@ func TestGetSharedChannelRemotesByRemoteCluster(t *testing.T) {
 	_, err = th.App.ShareChannel(th.Context, sc2)
 	require.NoError(t, err)
 
-	c3 := th.CreateChannelWithClientAndTeam(th.Client, model.ChannelTypeOpen, th.BasicTeam.Id)
+	c3 := th.CreateChannelWithClientAndTeam(t, th.Client, model.ChannelTypeOpen, th.BasicTeam.Id)
 	sc3 := &model.SharedChannel{
 		ChannelId: c3.Id,
 		TeamId:    th.BasicTeam.Id,
@@ -336,7 +332,7 @@ func TestGetSharedChannelRemotesByRemoteCluster(t *testing.T) {
 	_, err = th.App.ShareChannel(th.Context, sc3)
 	require.NoError(t, err)
 
-	c4 := th.CreateChannelWithClientAndTeam(th.Client, model.ChannelTypeOpen, th.BasicTeam.Id)
+	c4 := th.CreateChannelWithClientAndTeam(t, th.Client, model.ChannelTypeOpen, th.BasicTeam.Id)
 	sc4 := &model.SharedChannel{
 		ChannelId:        c4.Id,
 		TeamId:           th.BasicTeam.Id,
@@ -350,7 +346,7 @@ func TestGetSharedChannelRemotesByRemoteCluster(t *testing.T) {
 	_, err = th.App.ShareChannel(th.Context, sc4)
 	require.NoError(t, err)
 
-	c5 := th.CreateChannelWithClientAndTeam(th.Client, model.ChannelTypeOpen, th.BasicTeam.Id)
+	c5 := th.CreateChannelWithClientAndTeam(t, th.Client, model.ChannelTypeOpen, th.BasicTeam.Id)
 	sc5 := &model.SharedChannel{
 		ChannelId:        c5.Id,
 		TeamId:           th.BasicTeam.Id,
@@ -539,15 +535,13 @@ func TestInviteRemoteClusterToChannel(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("Should not work if the remote cluster service is not enabled", func(t *testing.T) {
 		th := Setup(t)
-		defer th.TearDown()
 
 		resp, err := th.SystemAdminClient.InviteRemoteClusterToChannel(context.Background(), model.NewId(), model.NewId())
 		CheckNotImplementedStatus(t, resp)
 		require.Error(t, err)
 	})
 
-	th := setupForSharedChannels(t).InitBasic()
-	defer th.TearDown()
+	th := setupForSharedChannels(t).InitBasic(t)
 
 	newRC := &model.RemoteCluster{Name: "rc", SiteURL: "http://example.com", CreatorId: th.SystemAdminUser.Id}
 
@@ -585,15 +579,13 @@ func TestUninviteRemoteClusterToChannel(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("Should not work if the remote cluster service is not enabled", func(t *testing.T) {
 		th := Setup(t)
-		defer th.TearDown()
 
 		resp, err := th.SystemAdminClient.UninviteRemoteClusterToChannel(context.Background(), model.NewId(), model.NewId())
 		CheckNotImplementedStatus(t, resp)
 		require.Error(t, err)
 	})
 
-	th := setupForSharedChannels(t).InitBasic()
-	defer th.TearDown()
+	th := setupForSharedChannels(t).InitBasic(t)
 
 	newRC := &model.RemoteCluster{Name: "rc", SiteURL: "http://example.com", CreatorId: th.SystemAdminUser.Id}
 
