@@ -28,7 +28,6 @@ import (
 
 func TestGetPing(t *testing.T) {
 	th := Setup(t)
-	defer th.TearDown()
 
 	th.TestForAllClients(t, func(t *testing.T, client *model.Client4) {
 		t.Run("healthy", func(t *testing.T) {
@@ -113,7 +112,6 @@ func TestGetPing(t *testing.T) {
 func TestGetAudits(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 	client := th.Client
 
 	audits, _, err := th.SystemAdminClient.GetAudits(context.Background(), 0, 100, "")
@@ -146,7 +144,6 @@ func TestGetAudits(t *testing.T) {
 func TestEmailTest(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 	client := th.Client
 
 	dir, err := os.MkdirTemp("", "")
@@ -228,8 +225,8 @@ func TestEmailTest(t *testing.T) {
 func TestGenerateSupportPacket(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	th.LoginSystemManager()
-	defer th.TearDown()
+
+	th.LoginSystemManager(t)
 
 	t.Run("system admin and local client can generate Support Packet", func(t *testing.T) {
 		l := model.NewTestLicense()
@@ -323,7 +320,6 @@ func TestSupportPacketFileName(t *testing.T) {
 func TestSiteURLTest(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 	client := th.Client
 
 	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
@@ -370,7 +366,6 @@ func TestSiteURLTest(t *testing.T) {
 func TestDatabaseRecycle(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 	client := th.Client
 
 	t.Run("as system user", func(t *testing.T) {
@@ -396,7 +391,6 @@ func TestDatabaseRecycle(t *testing.T) {
 func TestInvalidateCaches(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 	client := th.Client
 
 	t.Run("as system user", func(t *testing.T) {
@@ -422,7 +416,6 @@ func TestInvalidateCaches(t *testing.T) {
 func TestGetLogs(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	for i := range 20 {
 		th.TestLogger.Info(strconv.Itoa(i))
@@ -471,7 +464,6 @@ func TestGetLogs(t *testing.T) {
 func TestDownloadLogs(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	for i := range 20 {
 		th.TestLogger.Info(strconv.Itoa(i))
@@ -514,7 +506,6 @@ func TestDownloadLogs(t *testing.T) {
 func TestPostLog(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 	client := th.Client
 
 	enableDev := *th.App.Config().ServiceSettings.EnableDeveloper
@@ -556,8 +547,7 @@ func TestPostLog(t *testing.T) {
 
 func TestGetAnalyticsOld(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 	client := th.Client
 
 	rows, resp, err := client.GetAnalyticsOld(context.Background(), "", "")
@@ -631,7 +621,6 @@ func TestGetAnalyticsOld(t *testing.T) {
 func TestS3TestConnection(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 	client := th.Client
 
 	s3Host := os.Getenv("CI_MINIO_HOST")
@@ -717,7 +706,6 @@ func TestS3TestConnection(t *testing.T) {
 func TestSupportedTimezones(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 	client := th.Client
 
 	supportedTimezonesFromConfig := th.App.Timezones().GetSupported()
@@ -742,7 +730,6 @@ func TestRedirectLocation(t *testing.T) {
 	mockBitlyLink := testServer.URL
 
 	th := Setup(t)
-	defer th.TearDown()
 	client := th.Client
 	enableLinkPreviews := *th.App.Config().ServiceSettings.EnableLinkPreviews
 	defer func() {
@@ -821,7 +808,6 @@ func TestRedirectLocation(t *testing.T) {
 func TestSetServerBusy(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	const secs = 30
 
@@ -842,7 +828,6 @@ func TestSetServerBusy(t *testing.T) {
 func TestSetServerBusyInvalidParam(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	th.TestForSystemAdminAndLocal(t, func(t *testing.T, c *model.Client4) {
 		params := []int{-1, 0, MaxServerBusySeconds + 1}
@@ -858,7 +843,6 @@ func TestSetServerBusyInvalidParam(t *testing.T) {
 func TestClearServerBusy(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	th.App.Srv().Platform().Busy.Set(time.Second * 30)
 	t.Run("as system user", func(t *testing.T) {
@@ -879,7 +863,6 @@ func TestClearServerBusy(t *testing.T) {
 func TestGetServerBusy(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	th.App.Srv().Platform().Busy.Set(time.Second * 30)
 
@@ -900,7 +883,6 @@ func TestGetServerBusy(t *testing.T) {
 func TestServerBusy503(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	th.App.Srv().Platform().Busy.Set(time.Second * 30)
 
@@ -936,11 +918,12 @@ func TestServerBusy503(t *testing.T) {
 
 func TestPushNotificationAck(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
+	th := Setup(t).InitBasic(t)
+
 	api, err := Init(th.Server)
 	require.NoError(t, err)
-	session, _ := th.App.GetSession(th.Client.AuthToken)
-	defer th.TearDown()
+	session, appErr := th.App.GetSession(th.Client.AuthToken)
+	require.Nil(t, appErr)
 
 	t.Run("should return error when the ack body is not passed", func(t *testing.T) {
 		handler := api.APIHandler(pushNotificationAck)
@@ -954,8 +937,8 @@ func TestPushNotificationAck(t *testing.T) {
 	})
 
 	t.Run("should return error when the ack post is not authorized for the user", func(t *testing.T) {
-		privateChannel := th.CreateChannelWithClient(th.SystemAdminClient, model.ChannelTypePrivate)
-		privatePost := th.CreatePostWithClient(th.SystemAdminClient, privateChannel)
+		privateChannel := th.CreateChannelWithClient(t, th.SystemAdminClient, model.ChannelTypePrivate)
+		privatePost := th.CreatePostWithClient(t, th.SystemAdminClient, privateChannel)
 
 		handler := api.APIHandler(pushNotificationAck)
 		resp := httptest.NewRecorder()
@@ -1031,7 +1014,6 @@ func TestPushNotificationAck(t *testing.T) {
 func TestCompleteOnboarding(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	path, _ := fileutils.FindDir("tests")
 	signatureFilename := "testplugin2.tar.gz.sig"
@@ -1165,7 +1147,6 @@ func TestCompleteOnboarding(t *testing.T) {
 func TestGetAppliedSchemaMigrations(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	t.Run("as a regular user", func(t *testing.T) {
 		_, resp, err := th.Client.GetAppliedSchemaMigrations(context.Background())
@@ -1176,7 +1157,7 @@ func TestGetAppliedSchemaMigrations(t *testing.T) {
 	t.Run("as a system manager role", func(t *testing.T) {
 		_, appErr := th.App.UpdateUserRoles(th.Context, th.BasicUser2.Id, model.SystemManagerRoleId, false)
 		require.Nil(t, appErr)
-		th.LoginBasic2()
+		th.LoginBasic2(t)
 
 		_, resp, err := th.Client.GetAppliedSchemaMigrations(context.Background())
 		require.NoError(t, err)
