@@ -42,7 +42,7 @@ func (a *App) ServerId() string {
 }
 
 func (s *Server) TemplatesContainer() *templates.Container {
-	return s.htmlTemplateWatcher
+	return s.htmlTemplates
 }
 
 func (s *Server) getFirstServerRunTimestamp() (int64, *model.AppError) {
@@ -100,6 +100,9 @@ func (a *App) Notification() einterfaces.NotificationInterface {
 func (a *App) Saml() einterfaces.SamlInterface {
 	return a.ch.Saml
 }
+func (a *App) Intune() einterfaces.IntuneInterface {
+	return a.ch.Intune
+}
 func (a *App) Cloud() einterfaces.CloudInterface {
 	return a.ch.srv.Cloud
 }
