@@ -16,9 +16,8 @@ import (
 func TestSetAutoResponderStatus(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
-	user := th.CreateUser()
+	user := th.CreateUser(t)
 	defer func() {
 		err := th.App.PermanentDeleteUser(th.Context, user)
 		require.Nil(t, err)
@@ -58,9 +57,8 @@ func TestSetAutoResponderStatus(t *testing.T) {
 func TestDisableAutoResponder(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
-	user := th.CreateUser()
+	user := th.CreateUser(t)
 	defer func() {
 		err := th.App.PermanentDeleteUser(th.Context, user)
 		require.Nil(t, err)
@@ -94,10 +92,9 @@ func TestDisableAutoResponder(t *testing.T) {
 func TestSendAutoResponseIfNecessary(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("should send auto response when enabled", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
-		receiver := th.CreateUser()
+		receiver := th.CreateUser(t)
 
 		patch := &model.UserPatch{
 			NotifyProps: map[string]string{
@@ -108,7 +105,7 @@ func TestSendAutoResponseIfNecessary(t *testing.T) {
 		receiver, err := th.App.PatchUser(th.Context, receiver.Id, patch, true)
 		require.Nil(t, err)
 
-		channel := th.CreateDmChannel(receiver)
+		channel := th.CreateDmChannel(t, receiver)
 
 		savedPost, _ := th.App.CreatePost(th.Context, &model.Post{
 			ChannelId: channel.Id,
@@ -125,10 +122,9 @@ func TestSendAutoResponseIfNecessary(t *testing.T) {
 	})
 
 	t.Run("should not send auto response when disabled", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
-		receiver := th.CreateUser()
+		receiver := th.CreateUser(t)
 
 		patch := &model.UserPatch{
 			NotifyProps: map[string]string{
@@ -139,7 +135,7 @@ func TestSendAutoResponseIfNecessary(t *testing.T) {
 		receiver, err := th.App.PatchUser(th.Context, receiver.Id, patch, true)
 		require.Nil(t, err)
 
-		channel := th.CreateDmChannel(receiver)
+		channel := th.CreateDmChannel(t, receiver)
 
 		savedPost, _ := th.App.CreatePost(th.Context, &model.Post{
 			ChannelId: channel.Id,
@@ -156,8 +152,7 @@ func TestSendAutoResponseIfNecessary(t *testing.T) {
 	})
 
 	t.Run("should not send auto response for non-DM channel", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		savedPost, _ := th.App.CreatePost(th.Context, &model.Post{
 			ChannelId: th.BasicChannel.Id,
@@ -174,10 +169,9 @@ func TestSendAutoResponseIfNecessary(t *testing.T) {
 	})
 
 	t.Run("should not send auto response for bot", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
-		receiver := th.CreateUser()
+		receiver := th.CreateUser(t)
 
 		patch := &model.UserPatch{
 			NotifyProps: map[string]string{
@@ -188,7 +182,7 @@ func TestSendAutoResponseIfNecessary(t *testing.T) {
 		receiver, err := th.App.PatchUser(th.Context, receiver.Id, patch, true)
 		require.Nil(t, err)
 
-		channel := th.CreateDmChannel(receiver)
+		channel := th.CreateDmChannel(t, receiver)
 
 		bot, err := th.App.CreateBot(th.Context, &model.Bot{
 			Username:    "botusername",
@@ -215,10 +209,9 @@ func TestSendAutoResponseIfNecessary(t *testing.T) {
 	})
 
 	t.Run("should send auto response in dm channel if not already sent today", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
-		receiver := th.CreateUser()
+		receiver := th.CreateUser(t)
 
 		patch := &model.UserPatch{
 			NotifyProps: map[string]string{
@@ -229,7 +222,7 @@ func TestSendAutoResponseIfNecessary(t *testing.T) {
 		receiver, err := th.App.PatchUser(th.Context, receiver.Id, patch, true)
 		require.Nil(t, err)
 
-		channel := th.CreateDmChannel(receiver)
+		channel := th.CreateDmChannel(t, receiver)
 
 		// Clean up all posts from this user.
 		// There are some dummy messages like "user joined team" etc.
@@ -257,10 +250,9 @@ func TestSendAutoResponseIfNecessary(t *testing.T) {
 
 func TestSendAutoResponseSuccess(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
-	user := th.CreateUser()
+	user := th.CreateUser(t)
 	defer func() {
 		err := th.App.PermanentDeleteUser(th.Context, user)
 		require.Nil(t, err)
@@ -302,10 +294,9 @@ func TestSendAutoResponseSuccess(t *testing.T) {
 
 func TestSendAutoResponseSuccessOnThread(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
-	user := th.CreateUser()
+	user := th.CreateUser(t)
 	defer func() {
 		err := th.App.PermanentDeleteUser(th.Context, user)
 		require.Nil(t, err)
@@ -356,10 +347,9 @@ func TestSendAutoResponseSuccessOnThread(t *testing.T) {
 
 func TestSendAutoResponseFailure(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
-	user := th.CreateUser()
+	user := th.CreateUser(t)
 	defer func() {
 		err := th.App.PermanentDeleteUser(th.Context, user)
 		require.Nil(t, err)
