@@ -18,8 +18,7 @@ func TestCreateBot(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("invalid bot", func(t *testing.T) {
 		t.Run("relative to user", func(t *testing.T) {
-			th := Setup(t).InitBasic()
-			defer th.TearDown()
+			th := Setup(t).InitBasic(t)
 
 			_, err := th.App.CreateBot(th.Context, &model.Bot{
 				Username:    "invalid username",
@@ -31,8 +30,7 @@ func TestCreateBot(t *testing.T) {
 		})
 
 		t.Run("relative to bot", func(t *testing.T) {
-			th := Setup(t).InitBasic()
-			defer th.TearDown()
+			th := Setup(t).InitBasic(t)
 
 			_, err := th.App.CreateBot(th.Context, &model.Bot{
 				Username:    "username",
@@ -44,8 +42,7 @@ func TestCreateBot(t *testing.T) {
 		})
 
 		t.Run("username contains . character", func(t *testing.T) {
-			th := Setup(t).InitBasic()
-			defer th.TearDown()
+			th := Setup(t).InitBasic(t)
 
 			bot, err := th.App.CreateBot(th.Context, &model.Bot{
 				Username:    "username.",
@@ -58,8 +55,8 @@ func TestCreateBot(t *testing.T) {
 		})
 
 		t.Run("username missing", func(t *testing.T) {
-			th := Setup(t).InitBasic()
-			defer th.TearDown()
+			th := Setup(t).InitBasic(t)
+
 			bot, err := th.App.CreateBot(th.Context, &model.Bot{
 				Description: "a bot",
 				OwnerId:     th.BasicUser.Id,
@@ -71,8 +68,7 @@ func TestCreateBot(t *testing.T) {
 	})
 
 	t.Run("create bot", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		bot, err := th.App.CreateBot(th.Context, &model.Bot{
 			Username:    "username",
@@ -103,8 +99,7 @@ func TestCreateBot(t *testing.T) {
 	})
 
 	t.Run("create bot, username already used by a non-bot user", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		_, err := th.App.CreateBot(th.Context, &model.Bot{
 			Username:    th.BasicUser.Username,
@@ -119,8 +114,8 @@ func TestCreateBot(t *testing.T) {
 func TestEnsureBot(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("ensure bot should pass if already exist bot user", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
+
 		pluginId := "pluginId"
 
 		appErr := th.App.SetPluginKey(pluginId, "key", []byte("test"))
@@ -153,8 +148,8 @@ func TestEnsureBot(t *testing.T) {
 	})
 
 	t.Run("ensure bot should pass even after delete bot user", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
+
 		pluginId := "pluginId"
 
 		appErr := th.App.SetPluginKey(pluginId, "key", []byte("test"))
@@ -194,8 +189,7 @@ func TestEnsureBot(t *testing.T) {
 func TestPatchBot(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("invalid patch for user", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		bot, err := th.App.CreateBot(th.Context, &model.Bot{
 			Username:    "username",
@@ -220,8 +214,7 @@ func TestPatchBot(t *testing.T) {
 	})
 
 	t.Run("invalid patch for bot", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		bot, err := th.App.CreateBot(th.Context, &model.Bot{
 			Username:    "username",
@@ -246,8 +239,7 @@ func TestPatchBot(t *testing.T) {
 	})
 
 	t.Run("patch bot", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		bot := &model.Bot{
 			Username:    "username",
@@ -283,8 +275,7 @@ func TestPatchBot(t *testing.T) {
 	})
 
 	t.Run("patch bot, username already used by a non-bot user", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		bot, err := th.App.CreateBot(th.Context, &model.Bot{
 			Username:    "username",
@@ -310,8 +301,7 @@ func TestPatchBot(t *testing.T) {
 
 func TestGetBot(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	bot1, err := th.App.CreateBot(th.Context, &model.Bot{
 		Username:    "username",
@@ -381,8 +371,7 @@ func TestGetBot(t *testing.T) {
 
 func TestGetBots(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).DeleteBots()
-	defer th.TearDown()
+	th := Setup(t).DeleteBots(t)
 
 	OwnerId1 := model.NewId()
 	OwnerId2 := model.NewId()
@@ -593,8 +582,7 @@ func TestGetBots(t *testing.T) {
 func TestUpdateBotActive(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("unknown bot", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		_, err := th.App.UpdateBotActive(th.Context, model.NewId(), false)
 		require.NotNil(t, err)
@@ -602,8 +590,7 @@ func TestUpdateBotActive(t *testing.T) {
 	})
 
 	t.Run("disable/enable bot", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		bot, err := th.App.CreateBot(th.Context, &model.Bot{
 			Username:    "username",
@@ -638,8 +625,7 @@ func TestUpdateBotActive(t *testing.T) {
 
 func TestPermanentDeleteBot(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	bot, err := th.App.CreateBot(th.Context, &model.Bot{
 		Username:    "username",
@@ -658,7 +644,6 @@ func TestPermanentDeleteBot(t *testing.T) {
 func TestDisableUserBots(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	ownerId1 := model.NewId()
 	ownerId2 := model.NewId()
@@ -720,7 +705,6 @@ func TestDisableUserBots(t *testing.T) {
 func TestNotifySysadminsBotOwnerDisabled(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	userBots := []*model.Bot{}
 	defer func() {
@@ -860,8 +844,7 @@ func TestConvertUserToBot(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("invalid user", func(t *testing.T) {
 		t.Run("invalid user id", func(t *testing.T) {
-			th := Setup(t).InitBasic()
-			defer th.TearDown()
+			th := Setup(t).InitBasic(t)
 
 			_, err := th.App.ConvertUserToBot(th.Context, &model.User{
 				Username: "username",
@@ -872,8 +855,7 @@ func TestConvertUserToBot(t *testing.T) {
 		})
 
 		t.Run("invalid username", func(t *testing.T) {
-			th := Setup(t).InitBasic()
-			defer th.TearDown()
+			th := Setup(t).InitBasic(t)
 
 			_, err := th.App.ConvertUserToBot(th.Context, &model.User{
 				Username: "invalid username",
@@ -885,8 +867,7 @@ func TestConvertUserToBot(t *testing.T) {
 	})
 
 	t.Run("valid user and session revoked", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		session, err := th.App.CreateSession(th.Context, &model.Session{UserId: th.BasicUser.Id, Props: model.StringMap{}})
 		require.Nil(t, err)
@@ -915,8 +896,7 @@ func TestConvertUserToBot(t *testing.T) {
 	})
 
 	t.Run("user with oauth credentials", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		// Create a user first
 		oauthUser := &model.User{
@@ -966,8 +946,7 @@ func TestConvertUserToBot(t *testing.T) {
 func TestGetSystemBot(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("An error should be returned if there are no sysadmins in the instance", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		require.Nil(t, th.App.PermanentDeleteAllUsers(th.Context))
 
@@ -976,8 +955,7 @@ func TestGetSystemBot(t *testing.T) {
 		require.Equal(t, "app.bot.get_system_bot.empty_admin_list.app_error", err.Id)
 	})
 
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	t.Run("The bot should be created the first time it's retrieved", func(t *testing.T) {
 		// assert no bot with username exists
@@ -1005,7 +983,7 @@ func TestGetSystemBot(t *testing.T) {
 func TestIsBotOwnedByCurrentUserOrPlugin(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("bot owned by current user", func(t *testing.T) {
-		th := Setup(t).InitBasic()
+		th := Setup(t).InitBasic(t)
 
 		bot, err := th.App.CreateBot(th.Context, &model.Bot{
 			Username:    "username",
@@ -1031,7 +1009,7 @@ func TestIsBotOwnedByCurrentUserOrPlugin(t *testing.T) {
 	})
 
 	t.Run("bot owned by different user", func(t *testing.T) {
-		th := Setup(t).InitBasic()
+		th := Setup(t).InitBasic(t)
 
 		bot, err := th.App.CreateBot(th.Context, &model.Bot{
 			Username:    "username",
@@ -1057,7 +1035,7 @@ func TestIsBotOwnedByCurrentUserOrPlugin(t *testing.T) {
 	})
 
 	t.Run("invalid bot ID", func(t *testing.T) {
-		th := Setup(t).InitBasic()
+		th := Setup(t).InitBasic(t)
 
 		session, err := th.App.CreateSession(th.Context, &model.Session{
 			UserId: th.BasicUser.Id,
@@ -1073,7 +1051,7 @@ func TestIsBotOwnedByCurrentUserOrPlugin(t *testing.T) {
 	})
 
 	t.Run("bot owned by plugin when no plugins environment", func(t *testing.T) {
-		th := Setup(t).InitBasic()
+		th := Setup(t).InitBasic(t)
 
 		pluginID := "test-plugin-id"
 		bot, err := th.App.CreateBot(th.Context, &model.Bot{
@@ -1100,7 +1078,7 @@ func TestIsBotOwnedByCurrentUserOrPlugin(t *testing.T) {
 	})
 
 	t.Run("bot owned by plugin", func(t *testing.T) {
-		th := Setup(t).InitBasic()
+		th := Setup(t).InitBasic(t)
 
 		pluginID := "com.mattermost.testplugin"
 		pluginCode := `
