@@ -41,8 +41,7 @@ func createBookmark(name string, bookmarkType model.ChannelBookmarkType, channel
 
 func TestCreateBookmark(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	t.Run("create a channel bookmark", func(t *testing.T) {
 		th.Context.Session().UserId = th.BasicUser.Id // set the user for the session
@@ -83,8 +82,7 @@ func TestCreateBookmark(t *testing.T) {
 
 func TestUpdateBookmark(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	var updateBookmark *model.ChannelBookmarkWithFileInfo
 
@@ -179,7 +177,7 @@ func TestUpdateBookmark(t *testing.T) {
 		require.Nil(t, appErr)
 		require.NotNil(t, bookmarkToEdit)
 
-		otherChannel := th.CreateChannel(th.Context, th.BasicTeam)
+		otherChannel := th.CreateChannel(t, th.BasicTeam)
 
 		createAt := time.Now().Add(-1 * time.Minute)
 		deleteAt := createAt.Add(1 * time.Second)
@@ -331,8 +329,7 @@ func TestUpdateBookmark(t *testing.T) {
 
 func TestDeleteBookmark(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	t.Run("delete a channel bookmark", func(t *testing.T) {
 		bookmark1 := &model.ChannelBookmark{
@@ -357,8 +354,7 @@ func TestDeleteBookmark(t *testing.T) {
 
 func TestGetChannelBookmarks(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	th.Context.Session().UserId = th.BasicUser.Id // set the user for the session
 
@@ -442,8 +438,7 @@ func TestGetChannelBookmarks(t *testing.T) {
 
 func TestUpdateChannelBookmarkSortOrder(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	channelId := th.BasicChannel.Id
 	th.Context.Session().UserId = th.BasicUser.Id // set the user for the session
