@@ -17,8 +17,7 @@ import (
 
 func TestGetDraft(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	th.Server.platform.SetConfigReadOnlyFF(false)
 	defer th.Server.platform.SetConfigReadOnlyFF(true)
@@ -58,8 +57,7 @@ func TestGetDraft(t *testing.T) {
 
 func TestUpsertDraft(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	th.Server.platform.SetConfigReadOnlyFF(false)
 	defer th.Server.platform.SetConfigReadOnlyFF(true)
@@ -117,8 +115,7 @@ func TestUpsertDraft(t *testing.T) {
 
 func TestCreateDraft(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	th.Server.platform.SetConfigReadOnlyFF(false)
 	defer th.Server.platform.SetConfigReadOnlyFF(true)
@@ -127,8 +124,8 @@ func TestCreateDraft(t *testing.T) {
 
 	user := th.BasicUser
 	channel := th.BasicChannel
-	channel2 := th.CreateChannel(th.Context, th.BasicTeam)
-	th.AddUserToChannel(user, channel2)
+	channel2 := th.CreateChannel(t, th.BasicTeam)
+	th.AddUserToChannel(t, user, channel2)
 
 	draft1 := &model.Draft{
 		CreateAt:  00001,
@@ -176,8 +173,7 @@ func TestCreateDraft(t *testing.T) {
 
 func TestUpdateDraft(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	th.Server.platform.SetConfigReadOnlyFF(false)
 	defer th.Server.platform.SetConfigReadOnlyFF(true)
@@ -225,7 +221,7 @@ func TestUpdateDraft(t *testing.T) {
 		})
 
 		// Create a DM channel between two users who don't share a team
-		dmChannel := th.CreateDmChannel(th.BasicUser2)
+		dmChannel := th.CreateDmChannel(t, th.BasicUser2)
 
 		// Ensure the two users do not share a team
 		teams, err := th.App.GetTeamsForUser(th.BasicUser.Id)
@@ -242,10 +238,10 @@ func TestUpdateDraft(t *testing.T) {
 		}
 
 		// Create separate teams for each user
-		team1 := th.CreateTeam()
-		team2 := th.CreateTeam()
-		th.LinkUserToTeam(th.BasicUser, team1)
-		th.LinkUserToTeam(th.BasicUser2, team2)
+		team1 := th.CreateTeam(t)
+		team2 := th.CreateTeam(t)
+		th.LinkUserToTeam(t, th.BasicUser, team1)
+		th.LinkUserToTeam(t, th.BasicUser2, team2)
 
 		draft := &model.Draft{
 			CreateAt:  00001,
@@ -269,8 +265,7 @@ func TestUpdateDraft(t *testing.T) {
 
 func TestGetDraftsForUser(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	th.Server.platform.SetConfigReadOnlyFF(false)
 	defer th.Server.platform.SetConfigReadOnlyFF(true)
@@ -279,8 +274,8 @@ func TestGetDraftsForUser(t *testing.T) {
 
 	user := th.BasicUser
 	channel := th.BasicChannel
-	channel2 := th.CreateChannel(th.Context, th.BasicTeam)
-	th.AddUserToChannel(user, channel2)
+	channel2 := th.CreateChannel(t, th.BasicTeam)
+	th.AddUserToChannel(t, user, channel2)
 
 	draft1 := &model.Draft{
 		CreateAt:  00001,
@@ -393,8 +388,7 @@ func TestGetDraftsForUser(t *testing.T) {
 
 func TestDeleteDraft(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	th.Server.platform.SetConfigReadOnlyFF(false)
 	defer th.Server.platform.SetConfigReadOnlyFF(true)
