@@ -16,8 +16,7 @@ import (
 
 func TestSendInviteEmailRateLimits(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	th.BasicTeam.AllowedDomains = "common.com"
 	_, err := th.App.UpdateTeam(th.BasicTeam)
