@@ -50,7 +50,6 @@ func TestGeneratePublicLinkHash(t *testing.T) {
 func TestDoUploadFile(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	teamID := model.NewId()
 	channelID := model.NewId()
@@ -121,8 +120,7 @@ func TestDoUploadFile(t *testing.T) {
 
 func TestUploadFile(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	channelID := th.BasicChannel.Id
 	filename := "test"
@@ -152,8 +150,7 @@ func TestUploadFile(t *testing.T) {
 
 func TestParseOldFilenames(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	fileID := model.NewId()
 
@@ -250,8 +247,7 @@ func TestParseOldFilenames(t *testing.T) {
 
 func TestGetInfoForFilename(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	post := th.BasicPost
 	teamID := th.BasicTeam.Id
@@ -262,8 +258,7 @@ func TestGetInfoForFilename(t *testing.T) {
 
 func TestFindTeamIdForFilename(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	teamID := th.App.findTeamIdForFilename(th.Context, th.BasicPost, "someid", "somefile.png")
 	assert.Equal(t, th.BasicTeam.Id, teamID)
@@ -277,8 +272,7 @@ func TestFindTeamIdForFilename(t *testing.T) {
 
 func TestMigrateFilenamesToFileInfos(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	post := th.BasicPost
 	infos := th.App.MigrateFilenamesToFileInfos(th.Context, post)
@@ -313,7 +307,6 @@ func TestMigrateFilenamesToFileInfos(t *testing.T) {
 func TestWriteZipFile(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	t.Run("write no file", func(t *testing.T) {
 		buf := new(bytes.Buffer)
@@ -410,7 +403,6 @@ func TestWriteZipFile(t *testing.T) {
 func TestCopyFileInfos(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	teamID := model.NewId()
 	channelID := model.NewId()
@@ -446,7 +438,7 @@ func TestGenerateThumbnailImage(t *testing.T) {
 	t.Run("test generating thumbnail image", func(t *testing.T) {
 		// given
 		th := Setup(t)
-		defer th.TearDown()
+
 		img := createDummyImage()
 		dataPath := *th.App.Config().FileSettings.Directory
 		thumbnailName := "thumb.jpg"
@@ -477,7 +469,7 @@ func TestSearchFilesInTeamForUser(t *testing.T) {
 	searchTerm := "searchTerm"
 
 	setup := func(t *testing.T, enableElasticsearch bool) (*TestHelper, []*model.FileInfo) {
-		th := Setup(t).InitBasic()
+		th := Setup(t).InitBasic(t)
 
 		fileInfos := make([]*model.FileInfo, 7)
 		for i := 0; i < cap(fileInfos); i++ {
@@ -516,7 +508,6 @@ func TestSearchFilesInTeamForUser(t *testing.T) {
 
 	t.Run("should return everything as first page of fileInfos from database", func(t *testing.T) {
 		th, fileInfos := setup(t, false)
-		defer th.TearDown()
 
 		page := 0
 
@@ -537,7 +528,6 @@ func TestSearchFilesInTeamForUser(t *testing.T) {
 
 	t.Run("should not return later pages of fileInfos from database", func(t *testing.T) {
 		th, _ := setup(t, false)
-		defer th.TearDown()
 
 		page := 1
 
@@ -550,7 +540,6 @@ func TestSearchFilesInTeamForUser(t *testing.T) {
 
 	t.Run("should return first page of fileInfos from ElasticSearch", func(t *testing.T) {
 		th, fileInfos := setup(t, true)
-		defer th.TearDown()
 
 		page := 0
 		resultsPage := []string{
@@ -581,7 +570,6 @@ func TestSearchFilesInTeamForUser(t *testing.T) {
 
 	t.Run("should return later pages of fileInfos from ElasticSearch", func(t *testing.T) {
 		th, fileInfos := setup(t, true)
-		defer th.TearDown()
 
 		page := 1
 		resultsPage := []string{
@@ -609,7 +597,6 @@ func TestSearchFilesInTeamForUser(t *testing.T) {
 
 	t.Run("should fall back to database if ElasticSearch fails on first page", func(t *testing.T) {
 		th, fileInfos := setup(t, true)
-		defer th.TearDown()
 
 		page := 0
 
@@ -642,7 +629,6 @@ func TestSearchFilesInTeamForUser(t *testing.T) {
 
 	t.Run("should return nothing if ElasticSearch fails on later pages", func(t *testing.T) {
 		th, _ := setup(t, true)
-		defer th.TearDown()
 
 		page := 1
 
@@ -679,7 +665,6 @@ func TestExtractContentFromFileInfo(t *testing.T) {
 func TestGetLastAccessibleFileTime(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := SetupWithStoreMock(t)
-	defer th.TearDown()
 
 	r, err := th.App.GetLastAccessibleFileTime()
 	require.Nil(t, err)
@@ -714,7 +699,6 @@ func TestComputeLastAccessibleFileTime(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("Updates the time, if cloud limit is applicable", func(t *testing.T) {
 		th := SetupWithStoreMock(t)
-		defer th.TearDown()
 
 		th.App.Srv().SetLicense(model.NewTestLicense("cloud"))
 
@@ -743,7 +727,6 @@ func TestComputeLastAccessibleFileTime(t *testing.T) {
 
 	t.Run("Removes the time, if cloud limit is not applicable", func(t *testing.T) {
 		th := SetupWithStoreMock(t)
-		defer th.TearDown()
 
 		th.App.Srv().SetLicense(model.NewTestLicense("cloud"))
 
@@ -772,8 +755,7 @@ func TestComputeLastAccessibleFileTime(t *testing.T) {
 
 func TestSetFileSearchableContent(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	fileInfo, err := th.App.Srv().Store().FileInfo().Save(th.Context,
 		&model.FileInfo{
@@ -801,8 +783,7 @@ func TestSetFileSearchableContent(t *testing.T) {
 
 func TestPermanentDeleteFilesByPost(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	t.Run("should delete files for post", func(t *testing.T) {
 		// Create a post with a file attachment.
