@@ -12,7 +12,6 @@ import (
 	"path/filepath"
 	"slices"
 	"strings"
-	"sync"
 	"testing"
 	"time"
 
@@ -61,9 +60,7 @@ func setupTestHelper(dbStore store.Store, sqlStore *sqlstore.SqlStore, sqlSettin
 	updateConfig func(*model.Config), options []Option, tb testing.TB,
 ) *TestHelper {
 	tempWorkspace, err := os.MkdirTemp("", "apptest")
-	if err != nil {
-		panic(err)
-	}
+	require.NoError(tb, err)
 
 	configStore := config.NewTestMemoryStore()
 	memoryConfig := configStore.Get()
@@ -75,7 +72,14 @@ func setupTestHelper(dbStore store.Store, sqlStore *sqlstore.SqlStore, sqlSettin
 	*memoryConfig.PluginSettings.ClientDirectory = filepath.Join(tempWorkspace, "webapp")
 	*memoryConfig.PluginSettings.AutomaticPrepackagedPlugins = false
 	*memoryConfig.LogSettings.EnableSentry = false // disable error reporting during tests
-	*memoryConfig.LogSettings.ConsoleLevel = mlog.LvlStdLog.Name
+
+	// Check for environment variable override for console log level (useful for debugging tests)
+	consoleLevel := os.Getenv("MM_LOGSETTINGS_CONSOLELEVEL")
+	if consoleLevel == "" {
+		consoleLevel = mlog.LvlStdLog.Name
+	}
+	*memoryConfig.LogSettings.ConsoleLevel = consoleLevel
+
 	*memoryConfig.AnnouncementSettings.AdminNoticesEnabled = false
 	*memoryConfig.AnnouncementSettings.UserNoticesEnabled = false
 	*memoryConfig.LogSettings.FileLocation = filepath.Join(tempWorkspace, "logs", "mattermost.log")
@@ -87,9 +91,11 @@ func setupTestHelper(dbStore store.Store, sqlStore *sqlstore.SqlStore, sqlSettin
 		var signaturePublicKey []byte
 		signaturePublicKey, err = os.ReadFile(signaturePublicKeyFile)
 		require.NoError(tb, err, "failed to read signature public key file %s", signaturePublicKeyFile)
-		configStore.SetFile(signaturePublicKeyFile, signaturePublicKey)
+		err = configStore.SetFile(signaturePublicKeyFile, signaturePublicKey)
+		require.NoError(tb, err)
 	}
-	configStore.Set(memoryConfig)
+	_, _, err = configStore.Set(memoryConfig)
+	require.NoError(tb, err)
 
 	buffer := &mlog.Buffer{}
 
@@ -101,22 +107,22 @@ func setupTestHelper(dbStore store.Store, sqlStore *sqlstore.SqlStore, sqlSettin
 		options = append(options, StoreOverride(dbStore))
 	}
 
-	testLogger, _ := mlog.NewLogger()
-	logCfg, _ := config.MloggerConfigFromLoggerConfig(&memoryConfig.LogSettings, nil, config.GetLogFileLocation)
-	if errCfg := testLogger.ConfigureTargets(logCfg, nil); errCfg != nil {
-		panic("failed to configure test logger: " + errCfg.Error())
-	}
-	if errW := mlog.AddWriterTarget(testLogger, buffer, true, mlog.StdAll...); errW != nil {
-		panic("failed to add writer target to test logger: " + errW.Error())
-	}
+	testLogger, err := mlog.NewLogger()
+	require.NoError(tb, err)
+	logCfg, err := config.MloggerConfigFromLoggerConfig(&memoryConfig.LogSettings, nil, config.GetLogFileLocation)
+	require.NoError(tb, err)
+	err = testLogger.ConfigureTargets(logCfg, nil)
+	require.NoError(tb, err)
+
+	err = mlog.AddWriterTarget(testLogger, buffer, true, mlog.StdAll...)
+	require.NoError(tb, err)
+
 	// lock logger config so server init cannot override it during testing.
 	testLogger.LockConfiguration()
 	options = append(options, SetLogger(testLogger))
 
 	s, err := NewServer(options...)
-	if err != nil {
-		panic(err)
-	}
+	require.NoError(tb, err)
 
 	th := &TestHelper{
 		App:               New(ServerConnector(s.Channels())),
@@ -128,6 +134,7 @@ func setupTestHelper(dbStore store.Store, sqlStore *sqlstore.SqlStore, sqlSettin
 		ConfigStore:       configStore,
 		Store:             dbStore,
 		SQLStore:          sqlStore,
+		tempWorkspace:     tempWorkspace,
 	}
 
 	th.App.Srv().SetLicense(getLicense(enterprise, memoryConfig))
@@ -144,10 +151,8 @@ func setupTestHelper(dbStore store.Store, sqlStore *sqlstore.SqlStore, sqlSettin
 		th.App.UpdateConfig(updateConfig)
 	}
 
-	serverErr := th.Server.Start()
-	if serverErr != nil {
-		panic(serverErr)
-	}
+	err = th.Server.Start()
+	require.NoError(tb, err)
 
 	th.App.UpdateConfig(func(cfg *model.Config) { *cfg.ServiceSettings.ListenAddress = prevListenAddress })
 
@@ -166,9 +171,20 @@ func setupTestHelper(dbStore store.Store, sqlStore *sqlstore.SqlStore, sqlSettin
 		*cfg.PasswordSettings.Number = false
 	})
 
-	if th.tempWorkspace == "" {
-		th.tempWorkspace = tempWorkspace
-	}
+	tb.Cleanup(func() {
+		if th.IncludeCacheLayer {
+			// Clean all the caches
+			appErr := th.App.Srv().InvalidateAllCaches()
+			require.Nil(tb, appErr)
+		}
+
+		th.ShutdownApp()
+
+		if th.tempWorkspace != "" {
+			err := os.RemoveAll(th.tempWorkspace)
+			require.NoError(tb, err)
+		}
+	})
 
 	return th
 }
@@ -293,64 +309,35 @@ func SetupWithClusterMock(tb testing.TB, cluster einterfaces.ClusterInterface) *
 	return setupTestHelper(dbStore, sqlStore, dbSettings, searchEngine, true, true, nil, []Option{SetCluster(cluster)}, tb)
 }
 
-var (
-	initBasicOnce sync.Once
-	userCache     struct {
-		SystemAdminUser *model.User
-		BasicUser       *model.User
-		BasicUser2      *model.User
-	}
-)
+func (th *TestHelper) InitBasic(tb testing.TB) *TestHelper {
+	th.SystemAdminUser = th.CreateUser(tb)
+	_, appErr := th.App.UpdateUserRoles(th.Context, th.SystemAdminUser.Id, model.SystemUserRoleId+" "+model.SystemAdminRoleId, false)
+	require.Nil(tb, appErr)
+	th.SystemAdminUser, appErr = th.App.GetUser(th.SystemAdminUser.Id)
+	require.Nil(tb, appErr)
 
-func (th *TestHelper) InitBasic() *TestHelper {
-	// create users once and cache them because password hashing is slow
-	initBasicOnce.Do(func() {
-		var err *model.AppError
+	th.BasicUser = th.CreateUser(tb)
+	th.BasicUser, appErr = th.App.GetUser(th.BasicUser.Id)
+	require.Nil(tb, appErr)
 
-		th.SystemAdminUser = th.CreateUser()
-		th.App.UpdateUserRoles(th.Context, th.SystemAdminUser.Id, model.SystemUserRoleId+" "+model.SystemAdminRoleId, false)
-		th.SystemAdminUser, err = th.App.GetUser(th.SystemAdminUser.Id)
-		if err != nil {
-			panic(err)
-		}
-		userCache.SystemAdminUser = th.SystemAdminUser.DeepCopy()
+	th.BasicUser2 = th.CreateUser(tb)
+	th.BasicUser2, appErr = th.App.GetUser(th.BasicUser2.Id)
+	require.Nil(tb, appErr)
 
-		th.BasicUser = th.CreateUser()
-		th.BasicUser, err = th.App.GetUser(th.BasicUser.Id)
-		if err != nil {
-			panic(err)
-		}
-		userCache.BasicUser = th.BasicUser.DeepCopy()
+	th.BasicTeam = th.CreateTeam(tb)
 
-		th.BasicUser2 = th.CreateUser()
-		th.BasicUser2, err = th.App.GetUser(th.BasicUser2.Id)
-		if err != nil {
-			panic(err)
-		}
-		userCache.BasicUser2 = th.BasicUser2.DeepCopy()
-	})
-
-	// restore cached users
-	th.SystemAdminUser = userCache.SystemAdminUser.DeepCopy()
-	th.BasicUser = userCache.BasicUser.DeepCopy()
-	th.BasicUser2 = userCache.BasicUser2.DeepCopy()
-
-	users := []*model.User{th.SystemAdminUser, th.BasicUser, th.BasicUser2}
-	th.Store.User().InsertUsers(users)
-
-	th.BasicTeam = th.CreateTeam()
-
-	th.LinkUserToTeam(th.BasicUser, th.BasicTeam)
-	th.LinkUserToTeam(th.BasicUser2, th.BasicTeam)
-	th.BasicChannel = th.CreateChannel(th.Context, th.BasicTeam)
-	th.BasicPost = th.CreatePost(th.BasicChannel)
+	th.LinkUserToTeam(tb, th.BasicUser, th.BasicTeam)
+	th.LinkUserToTeam(tb, th.BasicUser2, th.BasicTeam)
+	th.BasicChannel = th.CreateChannel(tb, th.BasicTeam)
+	th.BasicPost = th.CreatePost(tb, th.BasicChannel)
 	return th
 }
 
-func (th *TestHelper) DeleteBots() *TestHelper {
+func (th *TestHelper) DeleteBots(tb testing.TB) *TestHelper {
 	preexistingBots, _ := th.App.GetBots(th.Context, &model.BotGetOptions{Page: 0, PerPage: 100})
 	for _, bot := range preexistingBots {
-		th.App.PermanentDeleteBot(th.Context, bot.UserId)
+		appErr := th.App.PermanentDeleteBot(th.Context, bot.UserId)
+		require.Nil(tb, appErr)
 	}
 	return th
 }
@@ -359,7 +346,7 @@ func (*TestHelper) MakeEmail() string {
 	return "success_" + model.NewId() + "@simulator.amazonses.com"
 }
 
-func (th *TestHelper) CreateTeam() *model.Team {
+func (th *TestHelper) CreateTeam(tb testing.TB) *model.Team {
 	id := model.NewId()
 	team := &model.Team{
 		DisplayName: "dn_" + id,
@@ -368,22 +355,20 @@ func (th *TestHelper) CreateTeam() *model.Team {
 		Type:        model.TeamOpen,
 	}
 
-	var err *model.AppError
-	if team, err = th.App.CreateTeam(th.Context, team); err != nil {
-		panic(err)
-	}
+	team, err := th.App.CreateTeam(th.Context, team)
+	require.Nil(tb, err)
 	return team
 }
 
-func (th *TestHelper) CreateUser() *model.User {
-	return th.CreateUserOrGuest(false)
+func (th *TestHelper) CreateUser(tb testing.TB) *model.User {
+	return th.CreateUserOrGuest(tb, false)
 }
 
-func (th *TestHelper) CreateGuest() *model.User {
-	return th.CreateUserOrGuest(true)
+func (th *TestHelper) CreateGuest(tb testing.TB) *model.User {
+	return th.CreateUserOrGuest(tb, true)
 }
 
-func (th *TestHelper) CreateUserOrGuest(guest bool) *model.User {
+func (th *TestHelper) CreateUserOrGuest(tb testing.TB, guest bool) *model.User {
 	id := model.NewId()
 
 	user := &model.User{
@@ -396,18 +381,16 @@ func (th *TestHelper) CreateUserOrGuest(guest bool) *model.User {
 
 	var err *model.AppError
 	if guest {
-		if user, err = th.App.CreateGuest(th.Context, user); err != nil {
-			panic(err)
-		}
+		user, err = th.App.CreateGuest(th.Context, user)
+		require.Nil(tb, err)
 	} else {
-		if user, err = th.App.CreateUser(th.Context, user); err != nil {
-			panic(err)
-		}
+		user, err = th.App.CreateUser(th.Context, user)
+		require.Nil(tb, err)
 	}
 	return user
 }
 
-func (th *TestHelper) CreateBot() *model.Bot {
+func (th *TestHelper) CreateBot(tb testing.TB) *model.Bot {
 	id := model.NewId()
 
 	bot := &model.Bot{
@@ -418,9 +401,7 @@ func (th *TestHelper) CreateBot() *model.Bot {
 	}
 
 	bot, err := th.App.CreateBot(th.Context, bot)
-	if err != nil {
-		panic(err)
-	}
+	require.Nil(tb, err)
 	return bot
 }
 
@@ -438,15 +419,15 @@ func WithCreateAt(v int64) ChannelOption {
 	}
 }
 
-func (th *TestHelper) CreateChannel(rctx request.CTX, team *model.Team, options ...ChannelOption) *model.Channel {
-	return th.createChannel(rctx, team, model.ChannelTypeOpen, options...)
+func (th *TestHelper) CreateChannel(tb testing.TB, team *model.Team, options ...ChannelOption) *model.Channel {
+	return th.createChannel(tb, team, model.ChannelTypeOpen, options...)
 }
 
-func (th *TestHelper) CreatePrivateChannel(rctx request.CTX, team *model.Team, options ...ChannelOption) *model.Channel {
-	return th.createChannel(rctx, team, model.ChannelTypePrivate, options...)
+func (th *TestHelper) CreatePrivateChannel(tb testing.TB, team *model.Team, options ...ChannelOption) *model.Channel {
+	return th.createChannel(tb, team, model.ChannelTypePrivate, options...)
 }
 
-func (th *TestHelper) createChannel(rctx request.CTX, team *model.Team, channelType model.ChannelType, options ...ChannelOption) *model.Channel {
+func (th *TestHelper) createChannel(tb testing.TB, team *model.Team, channelType model.ChannelType, options ...ChannelOption) *model.Channel {
 	id := model.NewId()
 
 	channel := &model.Channel{
@@ -461,14 +442,12 @@ func (th *TestHelper) createChannel(rctx request.CTX, team *model.Team, channelT
 		option(channel)
 	}
 
-	var appErr *model.AppError
-	if channel, appErr = th.App.CreateChannel(th.Context, channel, true); appErr != nil {
-		panic(appErr)
-	}
+	channel, appErr := th.App.CreateChannel(th.Context, channel, true)
+	require.Nil(tb, appErr)
 
 	if channel.IsShared() {
 		id := model.NewId()
-		_, err := th.App.ShareChannel(rctx, &model.SharedChannel{
+		_, err := th.App.ShareChannel(th.Context, &model.SharedChannel{
 			ChannelId:        channel.Id,
 			TeamId:           channel.TeamId,
 			Home:             false,
@@ -478,32 +457,24 @@ func (th *TestHelper) createChannel(rctx request.CTX, team *model.Team, channelT
 			CreatorId:        th.BasicUser.Id,
 			RemoteId:         model.NewId(),
 		})
-		if err != nil {
-			panic(err)
-		}
+		require.NoError(tb, err)
 	}
 	return channel
 }
 
-func (th *TestHelper) CreateDmChannel(user *model.User) *model.Channel {
-	var err *model.AppError
-	var channel *model.Channel
-	if channel, err = th.App.GetOrCreateDirectChannel(th.Context, th.BasicUser.Id, user.Id); err != nil {
-		panic(err)
-	}
+func (th *TestHelper) CreateDmChannel(tb testing.TB, user *model.User) *model.Channel {
+	channel, err := th.App.GetOrCreateDirectChannel(th.Context, th.BasicUser.Id, user.Id)
+	require.Nil(tb, err)
 	return channel
 }
 
-func (th *TestHelper) CreateGroupChannel(rctx request.CTX, user1 *model.User, user2 *model.User) *model.Channel {
-	var err *model.AppError
-	var channel *model.Channel
-	if channel, err = th.App.CreateGroupChannel(rctx, []string{th.BasicUser.Id, user1.Id, user2.Id}, th.BasicUser.Id); err != nil {
-		panic(err)
-	}
+func (th *TestHelper) CreateGroupChannel(tb testing.TB, user1 *model.User, user2 *model.User) *model.Channel {
+	channel, err := th.App.CreateGroupChannel(th.Context, []string{th.BasicUser.Id, user1.Id, user2.Id}, th.BasicUser.Id)
+	require.Nil(tb, err)
 	return channel
 }
 
-func (th *TestHelper) CreatePost(channel *model.Channel, postOptions ...PostOptions) *model.Post {
+func (th *TestHelper) CreatePost(tb testing.TB, channel *model.Channel, postOptions ...PostOptions) *model.Post {
 	id := model.NewId()
 
 	post := &model.Post{
@@ -517,14 +488,12 @@ func (th *TestHelper) CreatePost(channel *model.Channel, postOptions ...PostOpti
 		option(post)
 	}
 
-	var err *model.AppError
-	if post, err = th.App.CreatePost(th.Context, post, channel, model.CreatePostFlags{SetOnline: true}); err != nil {
-		panic(err)
-	}
+	post, err := th.App.CreatePost(th.Context, post, channel, model.CreatePostFlags{SetOnline: true})
+	require.Nil(tb, err)
 	return post
 }
 
-func (th *TestHelper) CreateMessagePost(channel *model.Channel, message string) *model.Post {
+func (th *TestHelper) CreateMessagePost(tb testing.TB, channel *model.Channel, message string) *model.Post {
 	post := &model.Post{
 		UserId:    th.BasicUser.Id,
 		ChannelId: channel.Id,
@@ -532,14 +501,12 @@ func (th *TestHelper) CreateMessagePost(channel *model.Channel, message string)
 		CreateAt:  model.GetMillis() - 10000,
 	}
 
-	var err *model.AppError
-	if post, err = th.App.CreatePost(th.Context, post, channel, model.CreatePostFlags{SetOnline: true}); err != nil {
-		panic(err)
-	}
+	post, err := th.App.CreatePost(th.Context, post, channel, model.CreatePostFlags{SetOnline: true})
+	require.Nil(tb, err)
 	return post
 }
 
-func (th *TestHelper) CreatePostReply(root *model.Post) *model.Post {
+func (th *TestHelper) CreatePostReply(tb testing.TB, root *model.Post) *model.Post {
 	id := model.NewId()
 	post := &model.Post{
 		UserId:    th.BasicUser.Id,
@@ -550,60 +517,48 @@ func (th *TestHelper) CreatePostReply(root *model.Post) *model.Post {
 	}
 
 	ch, err := th.App.GetChannel(th.Context, root.ChannelId)
-	if err != nil {
-		panic(err)
-	}
-	if post, err = th.App.CreatePost(th.Context, post, ch, model.CreatePostFlags{SetOnline: true}); err != nil {
-		panic(err)
-	}
+	require.Nil(tb, err)
+	post, err = th.App.CreatePost(th.Context, post, ch, model.CreatePostFlags{SetOnline: true})
+	require.Nil(tb, err)
 	return post
 }
 
-func (th *TestHelper) LinkUserToTeam(user *model.User, team *model.Team) {
+func (th *TestHelper) LinkUserToTeam(tb testing.TB, user *model.User, team *model.Team) {
 	_, err := th.App.JoinUserToTeam(th.Context, team, user, "")
-	if err != nil {
-		panic(err)
-	}
+	require.Nil(tb, err)
 }
 
-func (th *TestHelper) RemoveUserFromTeam(user *model.User, team *model.Team) {
+func (th *TestHelper) RemoveUserFromTeam(tb testing.TB, user *model.User, team *model.Team) {
 	err := th.App.RemoveUserFromTeam(th.Context, team.Id, user.Id, "")
-	if err != nil {
-		panic(err)
-	}
+	require.Nil(tb, err)
 }
 
-func (th *TestHelper) AddUserToChannel(user *model.User, channel *model.Channel) *model.ChannelMember {
+func (th *TestHelper) AddUserToChannel(tb testing.TB, user *model.User, channel *model.Channel) *model.ChannelMember {
 	member, err := th.App.AddUserToChannel(th.Context, user, channel, false)
-	if err != nil {
-		panic(err)
-	}
+	require.Nil(tb, err)
 	return member
 }
 
-func (th *TestHelper) RemoveUserFromChannel(user *model.User, channel *model.Channel) *model.AppError {
+func (th *TestHelper) RemoveUserFromChannel(tb testing.TB, user *model.User, channel *model.Channel) *model.AppError {
 	appErr := th.App.RemoveUserFromChannel(th.Context, user.Id, user.Id, channel)
-	if appErr != nil {
-		panic(appErr)
-	}
+	require.Nil(tb, appErr)
 	return appErr
 }
 
-func (th *TestHelper) CreateRole(roleName string) *model.Role {
-	role, _ := th.App.CreateRole(&model.Role{Name: roleName, DisplayName: roleName, Description: roleName, Permissions: []string{}})
+func (th *TestHelper) CreateRole(tb testing.TB, roleName string) *model.Role {
+	role, err := th.App.CreateRole(&model.Role{Name: roleName, DisplayName: roleName, Description: roleName, Permissions: []string{}})
+	require.Nil(tb, err)
 	return role
 }
 
-func (th *TestHelper) CreateScheme() (*model.Scheme, []*model.Role) {
+func (th *TestHelper) CreateScheme(tb testing.TB) (*model.Scheme, []*model.Role) {
 	scheme, err := th.App.CreateScheme(&model.Scheme{
 		DisplayName: "Test Scheme Display Name",
 		Name:        model.NewId(),
 		Description: "Test scheme description",
 		Scope:       model.SchemeScopeTeam,
 	})
-	if err != nil {
-		panic(err)
-	}
+	require.Nil(tb, err)
 
 	roleNames := []string{
 		scheme.DefaultTeamAdminRole,
@@ -617,15 +572,13 @@ func (th *TestHelper) CreateScheme() (*model.Scheme, []*model.Role) {
 	var roles []*model.Role
 	for _, roleName := range roleNames {
 		role, err := th.App.GetRoleByName(th.Context, roleName)
-		if err != nil {
-			panic(err)
-		}
+		require.Nil(tb, err)
 		roles = append(roles, role)
 	}
 	return scheme, roles
 }
 
-func (th *TestHelper) CreateGroup() *model.Group {
+func (th *TestHelper) CreateGroup(tb testing.TB) *model.Group {
 	id := model.NewId()
 	group := &model.Group{
 		DisplayName: "dn_" + id,
@@ -635,33 +588,27 @@ func (th *TestHelper) CreateGroup() *model.Group {
 		RemoteId:    model.NewPointer(model.NewId()),
 	}
 
-	var err *model.AppError
-	if group, err = th.App.CreateGroup(group); err != nil {
-		panic(err)
-	}
+	group, err := th.App.CreateGroup(group)
+	require.Nil(tb, err)
 	return group
 }
 
-func (th *TestHelper) CreateEmoji() *model.Emoji {
+func (th *TestHelper) CreateEmoji(tb testing.TB) *model.Emoji {
 	emoji, err := th.App.Srv().Store().Emoji().Save(&model.Emoji{
 		CreatorId: th.BasicUser.Id,
 		Name:      model.NewRandomString(10),
 	})
-	if err != nil {
-		panic(err)
-	}
+	require.NoError(tb, err)
 	return emoji
 }
 
-func (th *TestHelper) AddReactionToPost(post *model.Post, user *model.User, emojiName string) *model.Reaction {
+func (th *TestHelper) AddReactionToPost(tb testing.TB, post *model.Post, user *model.User, emojiName string) *model.Reaction {
 	reaction, err := th.App.SaveReactionForPost(th.Context, &model.Reaction{
 		UserId:    user.Id,
 		PostId:    post.Id,
 		EmojiName: emojiName,
 	})
-	if err != nil {
-		panic(err)
-	}
+	require.Nil(tb, err)
 	return reaction
 }
 
@@ -681,17 +628,6 @@ func (th *TestHelper) ShutdownApp() {
 	}
 }
 
-func (th *TestHelper) TearDown() {
-	if th.IncludeCacheLayer {
-		// Clean all the caches
-		th.App.Srv().InvalidateAllCaches()
-	}
-	th.ShutdownApp()
-	if th.tempWorkspace != "" {
-		os.RemoveAll(th.tempWorkspace)
-	}
-}
-
 func (th *TestHelper) GetSqlStore() *sqlstore.SqlStore {
 	return th.SQLStore
 }
@@ -711,38 +647,32 @@ func (th *TestHelper) ConfigureInbucketMail() {
 	})
 }
 
-func (th *TestHelper) ResetRoleMigration() {
+func (th *TestHelper) ResetRoleMigration(tb testing.TB) {
 	sqlStore := th.SQLStore
-	if _, err := sqlStore.GetMaster().Exec("DELETE from Roles"); err != nil {
-		panic(err)
-	}
+	_, err := sqlStore.GetMaster().Exec("DELETE from Roles")
+	require.NoError(tb, err)
 
 	mainHelper.GetClusterInterface().SendClearRoleCacheMessage()
 
-	if _, err := sqlStore.GetMaster().Exec("DELETE from Systems where Name = ?", model.AdvancedPermissionsMigrationKey); err != nil {
-		panic(err)
-	}
+	_, err = sqlStore.GetMaster().Exec("DELETE from Systems where Name = ?", model.AdvancedPermissionsMigrationKey)
+	require.NoError(tb, err)
 }
 
-func (th *TestHelper) ResetEmojisMigration() {
+func (th *TestHelper) ResetEmojisMigration(tb testing.TB) {
 	sqlStore := th.SQLStore
-	if _, err := sqlStore.GetMaster().Exec("UPDATE Roles SET Permissions=REPLACE(Permissions, ' create_emojis', '') WHERE builtin=True"); err != nil {
-		panic(err)
-	}
+	_, err := sqlStore.GetMaster().Exec("UPDATE Roles SET Permissions=REPLACE(Permissions, ' create_emojis', '') WHERE builtin=True")
+	require.NoError(tb, err)
 
-	if _, err := sqlStore.GetMaster().Exec("UPDATE Roles SET Permissions=REPLACE(Permissions, ' delete_emojis', '') WHERE builtin=True"); err != nil {
-		panic(err)
-	}
+	_, err = sqlStore.GetMaster().Exec("UPDATE Roles SET Permissions=REPLACE(Permissions, ' delete_emojis', '') WHERE builtin=True")
+	require.NoError(tb, err)
 
-	if _, err := sqlStore.GetMaster().Exec("UPDATE Roles SET Permissions=REPLACE(Permissions, ' delete_others_emojis', '') WHERE builtin=True"); err != nil {
-		panic(err)
-	}
+	_, err = sqlStore.GetMaster().Exec("UPDATE Roles SET Permissions=REPLACE(Permissions, ' delete_others_emojis', '') WHERE builtin=True")
+	require.NoError(tb, err)
 
 	mainHelper.GetClusterInterface().SendClearRoleCacheMessage()
 
-	if _, err := sqlStore.GetMaster().Exec("DELETE from Systems where Name = ?", EmojisPermissionsMigrationKey); err != nil {
-		panic(err)
-	}
+	_, err = sqlStore.GetMaster().Exec("DELETE from Systems where Name = ?", EmojisPermissionsMigrationKey)
+	require.NoError(tb, err)
 }
 
 func (th *TestHelper) CheckTeamCount(t *testing.T, expected int64) {
@@ -757,27 +687,23 @@ func (th *TestHelper) CheckChannelsCount(t *testing.T, expected int64) {
 	require.Equalf(t, count, expected, "Unexpected number of channels. Expected: %v, found: %v", expected, count)
 }
 
-func (th *TestHelper) SetupTeamScheme() *model.Scheme {
+func (th *TestHelper) SetupTeamScheme(tb testing.TB) *model.Scheme {
 	scheme, err := th.App.CreateScheme(&model.Scheme{
 		Name:        model.NewId(),
 		DisplayName: model.NewId(),
 		Scope:       model.SchemeScopeTeam,
 	})
-	if err != nil {
-		panic(err)
-	}
+	require.Nil(tb, err)
 	return scheme
 }
 
-func (th *TestHelper) SetupChannelScheme() *model.Scheme {
+func (th *TestHelper) SetupChannelScheme(tb testing.TB) *model.Scheme {
 	scheme, err := th.App.CreateScheme(&model.Scheme{
 		Name:        model.NewId(),
 		DisplayName: model.NewId(),
 		Scope:       model.SchemeScopeChannel,
 	})
-	if err != nil {
-		panic(err)
-	}
+	require.Nil(tb, err)
 	return scheme
 }
 
@@ -789,11 +715,9 @@ func (th *TestHelper) SetupPluginAPI() *PluginAPI {
 	return NewPluginAPI(th.App, th.Context, manifest)
 }
 
-func (th *TestHelper) RemovePermissionFromRole(permission string, roleName string) {
+func (th *TestHelper) RemovePermissionFromRole(tb testing.TB, permission string, roleName string) {
 	role, err1 := th.App.GetRoleByName(th.Context, roleName)
-	if err1 != nil {
-		panic(err1)
-	}
+	require.Nil(tb, err1)
 
 	var newPermissions []string
 	for _, p := range role.Permissions {
@@ -809,16 +733,12 @@ func (th *TestHelper) RemovePermissionFromRole(permission string, roleName strin
 	role.Permissions = newPermissions
 
 	_, err2 := th.App.UpdateRole(role)
-	if err2 != nil {
-		panic(err2)
-	}
+	require.Nil(tb, err2)
 }
 
-func (th *TestHelper) AddPermissionToRole(permission string, roleName string) {
-	role, err1 := th.App.GetRoleByName(th.Context, roleName)
-	if err1 != nil {
-		panic(err1)
-	}
+func (th *TestHelper) AddPermissionToRole(tb testing.TB, permission string, roleName string) {
+	role, appErr := th.App.GetRoleByName(th.Context, roleName)
+	require.Nil(tb, appErr)
 
 	if slices.Contains(role.Permissions, permission) {
 		return
@@ -827,12 +747,10 @@ func (th *TestHelper) AddPermissionToRole(permission string, roleName string) {
 	role.Permissions = append(role.Permissions, permission)
 
 	_, err2 := th.App.UpdateRole(role)
-	if err2 != nil {
-		panic(err2)
-	}
+	require.Nil(tb, err2)
 }
 
-func (th *TestHelper) CreateFileInfo(userId, postId, channelId string) *model.FileInfo {
+func (th *TestHelper) CreateFileInfo(tb testing.TB, userId, postId, channelId string) *model.FileInfo {
 	fileInfo := &model.FileInfo{
 		Id:        model.NewId(),
 		CreatorId: userId,
@@ -844,14 +762,12 @@ func (th *TestHelper) CreateFileInfo(userId, postId, channelId string) *model.Fi
 	}
 
 	createdFileInfo, err := th.App.Srv().Store().FileInfo().Save(th.Context, fileInfo)
-	if err != nil {
-		panic(err)
-	}
+	require.NoError(tb, err)
 
 	return createdFileInfo
 }
 
-func (th *TestHelper) PostPatch(post *model.Post, message string, options ...PostPatchOptions) *model.Post {
+func (th *TestHelper) PostPatch(tb testing.TB, post *model.Post, message string, options ...PostPatchOptions) *model.Post {
 	postPatch := &model.PostPatch{
 		Message: model.NewPointer(message),
 	}
@@ -860,9 +776,7 @@ func (th *TestHelper) PostPatch(post *model.Post, message string, options ...Pos
 	}
 
 	updatedPost, appErr := th.App.PatchPost(th.Context, post.Id, postPatch, nil)
-	if appErr != nil {
-		panic(appErr)
-	}
+	require.Nil(tb, appErr)
 
 	return updatedPost
 }
@@ -884,7 +798,7 @@ func (th *TestHelper) NewPluginAPI(manifest *model.Manifest) plugin.API {
 	return th.App.NewPluginAPI(th.Context, manifest)
 }
 
-func decodeJSON[T any](o any, result *T) *T {
+func decodeJSON[T any](tb testing.TB, o any, result *T) *T {
 	var r io.Reader
 	switch v := o.(type) {
 	case string:
@@ -894,13 +808,11 @@ func decodeJSON[T any](o any, result *T) *T {
 	case io.Reader:
 		r = v
 	default:
-		panic(fmt.Sprintf("Unable to decode JSON from %T (%v)", v, v))
+		require.Fail(tb, fmt.Sprintf("Unable to decode JSON from %T (%v)", v, v))
 	}
 
 	err := json.NewDecoder(r).Decode(result)
-	if err != nil {
-		panic(err)
-	}
+	require.NoError(tb, err)
 
 	return result
 }
