@@ -35,7 +35,7 @@ func TestGeneratePassword(t *testing.T) {
 	})
 
 	t.Run("Should not fail on concurrent calls", func(t *testing.T) {
-		for i := 0; i < 10; i++ {
+		for range 10 {
 			go func() {
 				_, err := generatePassword(10)
 				require.NoError(t, err)
