@@ -24,8 +24,7 @@ import (
 // Test for MM-13598 where an invalid integration URL was causing a crash
 func TestPostActionInvalidURL(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	th.App.UpdateConfig(func(cfg *model.Config) {
 		*cfg.ServiceSettings.AllowedUntrustedInternalConnections = "localhost,127.0.0.1"
@@ -75,8 +74,7 @@ func TestPostActionInvalidURL(t *testing.T) {
 
 func TestPostActionEmptyResponse(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	channel := th.BasicChannel
 	th.App.UpdateConfig(func(cfg *model.Config) {
@@ -185,22 +183,21 @@ func TestPostAction(t *testing.T) {
 			return th.BasicChannel
 		}},
 		{"direct channel", func(th *TestHelper) *model.Channel {
-			user1 := th.CreateUser()
+			user1 := th.CreateUser(t)
 
-			return th.CreateDmChannel(user1)
+			return th.CreateDmChannel(t, user1)
 		}},
 		{"group channel", func(th *TestHelper) *model.Channel {
-			user1 := th.CreateUser()
-			user2 := th.CreateUser()
+			user1 := th.CreateUser(t)
+			user2 := th.CreateUser(t)
 
-			return th.CreateGroupChannel(th.Context, user1, user2)
+			return th.CreateGroupChannel(t, user1, user2)
 		}},
 	}
 
 	for _, testCase := range testCases {
 		t.Run(testCase.Description, func(t *testing.T) {
-			th := Setup(t).InitBasic()
-			defer th.TearDown()
+			th := Setup(t).InitBasic(t)
 
 			channel := testCase.Channel(th)
 
@@ -469,8 +466,7 @@ func TestPostAction(t *testing.T) {
 
 func TestPostActionProps(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	th.App.UpdateConfig(func(cfg *model.Config) {
 		*cfg.ServiceSettings.AllowedUntrustedInternalConnections = "localhost,127.0.0.1"
@@ -554,8 +550,7 @@ func TestPostActionProps(t *testing.T) {
 
 func TestSubmitInteractiveDialog(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	th.App.UpdateConfig(func(cfg *model.Config) {
 		*cfg.ServiceSettings.AllowedUntrustedInternalConnections = "localhost,127.0.0.1"
@@ -677,8 +672,7 @@ func TestSubmitInteractiveDialog(t *testing.T) {
 
 func TestPostActionRelativeURL(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		var request model.PostActionIntegrationRequest
@@ -891,8 +885,7 @@ func TestPostActionRelativeURL(t *testing.T) {
 
 func TestPostActionRelativePluginURL(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	setupPluginAPITest(t,
 		`
@@ -1089,8 +1082,7 @@ func TestPostActionRelativePluginURL(t *testing.T) {
 
 func TestLookupInteractiveDialog(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	th.App.UpdateConfig(func(cfg *model.Config) {
 		*cfg.ServiceSettings.AllowedUntrustedInternalConnections = "localhost,127.0.0.1"
@@ -1327,8 +1319,7 @@ func TestLookupInteractiveDialog(t *testing.T) {
 
 func TestOpenInteractiveDialog(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	t.Run("should successfully open dialog with valid trigger ID", func(t *testing.T) {
 		_, triggerId, err := model.GenerateTriggerId(th.BasicUser.Id, th.App.AsymmetricSigningKey())
@@ -1426,8 +1417,7 @@ func TestOpenInteractiveDialog(t *testing.T) {
 
 func TestDoActionRequest(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	th.App.UpdateConfig(func(cfg *model.Config) {
 		*cfg.ServiceSettings.AllowedUntrustedInternalConnections = "localhost,127.0.0.1"
@@ -1521,8 +1511,7 @@ func TestDoActionRequest(t *testing.T) {
 
 func TestDoLocalRequest(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	t.Run("should delegate to doPluginRequest", func(t *testing.T) {
 		requestBody := []byte(`{"test": "data"}`)
@@ -1535,8 +1524,7 @@ func TestDoLocalRequest(t *testing.T) {
 
 func TestDoPostActionWithCookieEdgeCases(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	th.App.UpdateConfig(func(cfg *model.Config) {
 		*cfg.ServiceSettings.AllowedUntrustedInternalConnections = "localhost,127.0.0.1"
@@ -1615,7 +1603,6 @@ func TestDoPostActionWithCookieEdgeCases(t *testing.T) {
 func TestDoPluginRequest(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	th.App.UpdateConfig(func(cfg *model.Config) {
 		*cfg.ServiceSettings.AllowedUntrustedInternalConnections = "localhost,127.0.0.1"
