@@ -18,8 +18,7 @@ func TestGetServerLimits(t *testing.T) {
 	mainHelper.Parallel(t)
 
 	t.Run("unlicensed server shows hard-coded limits", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		th.App.Srv().SetLicense(nil)
 
@@ -33,8 +32,7 @@ func TestGetServerLimits(t *testing.T) {
 	})
 
 	t.Run("user count should increase on creating new user and decrease on permanently deleting", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		th.App.Srv().SetLicense(nil)
 
@@ -43,7 +41,7 @@ func TestGetServerLimits(t *testing.T) {
 		require.Equal(t, int64(3), serverLimits.ActiveUserCount)
 
 		// now we create a new user
-		newUser := th.CreateUser()
+		newUser := th.CreateUser(t)
 
 		serverLimits, appErr = th.App.GetServerLimits()
 		require.Nil(t, appErr)
@@ -57,8 +55,7 @@ func TestGetServerLimits(t *testing.T) {
 	})
 
 	t.Run("user count should increase on creating new guest user and decrease on permanently deleting", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		th.App.Srv().SetLicense(nil)
 
@@ -67,7 +64,7 @@ func TestGetServerLimits(t *testing.T) {
 		require.Equal(t, int64(3), serverLimits.ActiveUserCount)
 
 		// now we create a new user
-		newGuestUser := th.CreateGuest()
+		newGuestUser := th.CreateGuest(t)
 
 		serverLimits, appErr = th.App.GetServerLimits()
 		require.Nil(t, appErr)
@@ -81,8 +78,7 @@ func TestGetServerLimits(t *testing.T) {
 	})
 
 	t.Run("user count should increase on creating new user and decrease on soft deleting", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		th.App.Srv().SetLicense(nil)
 
@@ -91,7 +87,7 @@ func TestGetServerLimits(t *testing.T) {
 		require.Equal(t, int64(3), serverLimits.ActiveUserCount)
 
 		// now we create a new user
-		newUser := th.CreateUser()
+		newUser := th.CreateUser(t)
 
 		serverLimits, appErr = th.App.GetServerLimits()
 		require.Nil(t, appErr)
@@ -106,8 +102,7 @@ func TestGetServerLimits(t *testing.T) {
 	})
 
 	t.Run("user count should increase on creating new guest user and decrease on soft deleting", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		th.App.Srv().SetLicense(nil)
 
@@ -116,7 +111,7 @@ func TestGetServerLimits(t *testing.T) {
 		require.Equal(t, int64(3), serverLimits.ActiveUserCount)
 
 		// now we create a new user
-		newGuestUser := th.CreateGuest()
+		newGuestUser := th.CreateGuest(t)
 
 		serverLimits, appErr = th.App.GetServerLimits()
 		require.Nil(t, appErr)
@@ -131,8 +126,7 @@ func TestGetServerLimits(t *testing.T) {
 	})
 
 	t.Run("user count should not change on creating or deleting bots", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		th.App.Srv().SetLicense(nil)
 
@@ -141,7 +135,7 @@ func TestGetServerLimits(t *testing.T) {
 		require.Equal(t, int64(3), serverLimits.ActiveUserCount)
 
 		// now we create a new bot
-		newBot := th.CreateBot()
+		newBot := th.CreateBot(t)
 
 		serverLimits, appErr = th.App.GetServerLimits()
 		require.Nil(t, appErr)
@@ -155,8 +149,7 @@ func TestGetServerLimits(t *testing.T) {
 	})
 
 	t.Run("licensed server without seat count enforcement shows no limits", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		license := model.NewTestLicense("")
 		license.IsSeatCountEnforced = false
@@ -171,8 +164,7 @@ func TestGetServerLimits(t *testing.T) {
 	})
 
 	t.Run("licensed server with seat count enforcement shows license limits with configurable extra users", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		userLimit := 100
 		extraUsers := 10
@@ -192,8 +184,7 @@ func TestGetServerLimits(t *testing.T) {
 	})
 
 	t.Run("licensed server with seat count enforcement and no ExtraUsers configured defaults to zero", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		userLimit := 100
 		license := model.NewTestLicense("")
@@ -212,8 +203,7 @@ func TestGetServerLimits(t *testing.T) {
 	})
 
 	t.Run("licensed server with seat count enforcement and zero ExtraUsers creates hard cap", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		userLimit := 100
 		extraUsers := 0
@@ -233,8 +223,7 @@ func TestGetServerLimits(t *testing.T) {
 	})
 
 	t.Run("licensed server with seat count enforcement but no Users feature shows no limits", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		license := model.NewTestLicense("")
 		license.IsSeatCountEnforced = true
@@ -250,8 +239,7 @@ func TestGetServerLimits(t *testing.T) {
 	})
 
 	t.Run("licensed server with seat count enforcement and zero Users shows zero limits", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		userLimit := 0
 		license := model.NewTestLicense("")
@@ -274,7 +262,6 @@ func TestIsAtUserLimit(t *testing.T) {
 	t.Run("unlicensed server", func(t *testing.T) {
 		t.Run("below hard limit", func(t *testing.T) {
 			th := SetupWithStoreMock(t)
-			defer th.TearDown()
 
 			th.App.Srv().SetLicense(nil)
 
@@ -290,7 +277,6 @@ func TestIsAtUserLimit(t *testing.T) {
 
 		t.Run("at hard limit", func(t *testing.T) {
 			th := SetupWithStoreMock(t)
-			defer th.TearDown()
 
 			th.App.Srv().SetLicense(nil)
 
@@ -306,7 +292,6 @@ func TestIsAtUserLimit(t *testing.T) {
 
 		t.Run("above hard limit", func(t *testing.T) {
 			th := SetupWithStoreMock(t)
-			defer th.TearDown()
 
 			th.App.Srv().SetLicense(nil)
 
@@ -323,8 +308,7 @@ func TestIsAtUserLimit(t *testing.T) {
 
 	t.Run("licensed server with seat count enforcement", func(t *testing.T) {
 		t.Run("below base limit", func(t *testing.T) {
-			th := Setup(t).InitBasic()
-			defer th.TearDown()
+			th := Setup(t).InitBasic(t)
 
 			userLimit := 5
 			license := model.NewTestLicense("")
@@ -339,8 +323,7 @@ func TestIsAtUserLimit(t *testing.T) {
 		})
 
 		t.Run("at base limit but below hard limit with extra users", func(t *testing.T) {
-			th := Setup(t).InitBasic()
-			defer th.TearDown()
+			th := Setup(t).InitBasic(t)
 
 			userLimit := 5
 			extraUsers := 2
@@ -351,8 +334,8 @@ func TestIsAtUserLimit(t *testing.T) {
 			th.App.Srv().SetLicense(license)
 
 			// Create 2 additional users to have 5 total (at base limit of 5, but below hard limit of 7)
-			th.CreateUser()
-			th.CreateUser()
+			th.CreateUser(t)
+			th.CreateUser(t)
 
 			atLimit, appErr := th.App.isAtUserLimit()
 			require.Nil(t, appErr)
@@ -361,7 +344,6 @@ func TestIsAtUserLimit(t *testing.T) {
 
 		t.Run("at hard limit with extra users", func(t *testing.T) {
 			th := SetupWithStoreMock(t)
-			defer th.TearDown()
 
 			userLimit := 5
 			extraUsers := 1
@@ -383,7 +365,6 @@ func TestIsAtUserLimit(t *testing.T) {
 
 		t.Run("above hard limit with extra users", func(t *testing.T) {
 			th := SetupWithStoreMock(t)
-			defer th.TearDown()
 
 			userLimit := 5
 			extraUsers := 1
@@ -406,8 +387,7 @@ func TestIsAtUserLimit(t *testing.T) {
 
 	t.Run("licensed server without seat count enforcement", func(t *testing.T) {
 		t.Run("below unenforced limit", func(t *testing.T) {
-			th := Setup(t).InitBasic()
-			defer th.TearDown()
+			th := Setup(t).InitBasic(t)
 
 			userLimit := 5
 			license := model.NewTestLicense("")
@@ -416,8 +396,8 @@ func TestIsAtUserLimit(t *testing.T) {
 			th.App.Srv().SetLicense(license)
 
 			// Create 2 additional users to have 3 total (below limit of 5)
-			th.CreateUser()
-			th.CreateUser()
+			th.CreateUser(t)
+			th.CreateUser(t)
 
 			atLimit, appErr := th.App.isAtUserLimit()
 			require.Nil(t, appErr)
@@ -425,8 +405,7 @@ func TestIsAtUserLimit(t *testing.T) {
 		})
 
 		t.Run("at unenforced limit", func(t *testing.T) {
-			th := Setup(t).InitBasic()
-			defer th.TearDown()
+			th := Setup(t).InitBasic(t)
 
 			userLimit := 5
 			license := model.NewTestLicense("")
@@ -435,10 +414,10 @@ func TestIsAtUserLimit(t *testing.T) {
 			th.App.Srv().SetLicense(license)
 
 			// Create 4 additional users to have 5 total (at limit of 5)
-			th.CreateUser()
-			th.CreateUser()
-			th.CreateUser()
-			th.CreateUser()
+			th.CreateUser(t)
+			th.CreateUser(t)
+			th.CreateUser(t)
+			th.CreateUser(t)
 
 			atLimit, appErr := th.App.isAtUserLimit()
 			require.Nil(t, appErr)
@@ -446,8 +425,7 @@ func TestIsAtUserLimit(t *testing.T) {
 		})
 
 		t.Run("above unenforced limit", func(t *testing.T) {
-			th := Setup(t).InitBasic()
-			defer th.TearDown()
+			th := Setup(t).InitBasic(t)
 
 			userLimit := 5
 			license := model.NewTestLicense("")
@@ -456,11 +434,11 @@ func TestIsAtUserLimit(t *testing.T) {
 			th.App.Srv().SetLicense(license)
 
 			// Create 5 additional users to have 6 total (above limit of 5)
-			th.CreateUser()
-			th.CreateUser()
-			th.CreateUser()
-			th.CreateUser()
-			th.CreateUser()
+			th.CreateUser(t)
+			th.CreateUser(t)
+			th.CreateUser(t)
+			th.CreateUser(t)
+			th.CreateUser(t)
 
 			atLimit, appErr := th.App.isAtUserLimit()
 			require.Nil(t, appErr)
@@ -519,8 +497,7 @@ func TestExtraUsersBehavior(t *testing.T) {
 
 		for _, tt := range tests {
 			t.Run(tt.name, func(t *testing.T) {
-				th := Setup(t).InitBasic()
-				defer th.TearDown()
+				th := Setup(t).InitBasic(t)
 
 				license := model.NewTestLicense("")
 				license.IsSeatCountEnforced = true
@@ -538,8 +515,7 @@ func TestExtraUsersBehavior(t *testing.T) {
 	})
 
 	t.Run("unlicensed server has no extra users", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		th.App.Srv().SetLicense(nil)
 
@@ -556,8 +532,7 @@ func TestGetServerLimitsWithPostHistory(t *testing.T) {
 	mainHelper.Parallel(t)
 
 	t.Run("unlicensed server has no post history limits", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		th.App.Srv().SetLicense(nil)
 
@@ -570,8 +545,7 @@ func TestGetServerLimitsWithPostHistory(t *testing.T) {
 	})
 
 	t.Run("licensed server without post history limits", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		license := model.NewTestLicense("")
 		license.Limits = nil // No limits configured
@@ -586,8 +560,7 @@ func TestGetServerLimitsWithPostHistory(t *testing.T) {
 	})
 
 	t.Run("licensed server with zero post history limit", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		license := model.NewTestLicense("")
 		license.Limits = &model.LicenseLimits{
@@ -605,7 +578,6 @@ func TestGetServerLimitsWithPostHistory(t *testing.T) {
 
 	t.Run("licensed server with positive post history limit and successful GetLastAccessiblePostTime", func(t *testing.T) {
 		th := SetupWithStoreMock(t)
-		defer th.TearDown()
 
 		// Mock user store for existing functionality
 		mockStore := th.App.Srv().Store().(*storemocks.Store)
@@ -639,7 +611,6 @@ func TestGetServerLimitsWithPostHistory(t *testing.T) {
 
 	t.Run("licensed server with post history limit but GetLastAccessiblePostTime fails", func(t *testing.T) {
 		th := SetupWithStoreMock(t)
-		defer th.TearDown()
 
 		// Mock user store for existing functionality
 		mockStore := th.App.Srv().Store().(*storemocks.Store)
@@ -666,7 +637,6 @@ func TestGetServerLimitsWithPostHistory(t *testing.T) {
 
 	t.Run("licensed server with post history limit but no system value found", func(t *testing.T) {
 		th := SetupWithStoreMock(t)
-		defer th.TearDown()
 
 		// Mock user store for existing functionality
 		mockStore := th.App.Srv().Store().(*storemocks.Store)
@@ -699,8 +669,7 @@ func TestGetPostHistoryLimit(t *testing.T) {
 	mainHelper.Parallel(t)
 
 	t.Run("unlicensed server returns zero limit", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		th.App.Srv().SetLicense(nil)
 
@@ -709,8 +678,7 @@ func TestGetPostHistoryLimit(t *testing.T) {
 	})
 
 	t.Run("licensed server with no Limits returns zero", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		license := model.NewTestLicense("")
 		license.Limits = nil // No limits configured
@@ -721,8 +689,7 @@ func TestGetPostHistoryLimit(t *testing.T) {
 	})
 
 	t.Run("licensed server with zero PostHistory returns zero", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		license := model.NewTestLicense("")
 		license.Limits = &model.LicenseLimits{
@@ -735,8 +702,7 @@ func TestGetPostHistoryLimit(t *testing.T) {
 	})
 
 	t.Run("licensed server with positive PostHistory returns exact value", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		license := model.NewTestLicense("")
 		license.Limits = &model.LicenseLimits{
@@ -749,8 +715,7 @@ func TestGetPostHistoryLimit(t *testing.T) {
 	})
 
 	t.Run("Entry license with PostHistory returns exact value", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		license := model.NewTestLicenseSKU(model.LicenseShortSkuMattermostEntry)
 
