@@ -17,8 +17,7 @@ import (
 func Test_SendNotifyAdminPosts(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("no error sending non trial upgrade post when no notifications are available", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		th.App.Srv().SetLicense(model.NewTestLicense("cloud"))
 
@@ -27,8 +26,7 @@ func Test_SendNotifyAdminPosts(t *testing.T) {
 	})
 
 	t.Run("no error sending trial upgrade post when no notifications are available", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		th.App.Srv().SetLicense(model.NewTestLicense("cloud"))
 
@@ -37,8 +35,7 @@ func Test_SendNotifyAdminPosts(t *testing.T) {
 	})
 
 	t.Run("successfully send upgrade notification", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		th.App.Srv().SetLicense(model.NewTestLicense("cloud"))
 
@@ -90,8 +87,7 @@ func Test_SendNotifyAdminPosts(t *testing.T) {
 	})
 
 	t.Run("successfully send trial upgrade notification", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		th.App.Srv().SetLicense(model.NewTestLicense("cloud"))
 
@@ -137,8 +133,7 @@ func Test_SendNotifyAdminPosts(t *testing.T) {
 	})
 
 	t.Run("error when trying to send upgrade post before end of cool off period", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		th.App.Srv().SetLicense(model.NewTestLicense("cloud"))
 
@@ -168,8 +163,7 @@ func Test_SendNotifyAdminPosts(t *testing.T) {
 	})
 
 	t.Run("can send upgrade post at the end of cool off period", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		th.App.Srv().SetLicense(model.NewTestLicense("cloud"))
 
@@ -203,8 +197,7 @@ func Test_SendNotifyAdminPosts(t *testing.T) {
 	})
 
 	t.Run("can filter notifications when plan changes within cool off period", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		th.App.Srv().SetLicense(model.NewTestLicense("cloud"))
 
