@@ -24,12 +24,11 @@ func (tw testWriter) Write(p []byte) (int, error) {
 func TestExportPermissions(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	var scheme *model.Scheme
 	var roles []*model.Role
 	withMigrationMarkedComplete(t, th, func() {
-		scheme, roles = th.CreateScheme()
+		scheme, roles = th.CreateScheme(t)
 	})
 
 	results := [][]byte{}
@@ -90,7 +89,6 @@ func TestExportPermissions(t *testing.T) {
 func TestMigration(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	role, err := th.App.GetRoleByName(th.Context, model.SystemAdminRoleId)
 	require.Nil(t, err)
