@@ -34,16 +34,11 @@ type TestHelper struct {
 	// BasicPost    *model.Post
 
 	SystemAdminUser *model.User
-}
 
-var (
-	initBasicOnce sync.Once
-	userCache     struct {
-		SystemAdminUser *model.User
-		BasicUser       *model.User
-		BasicUser2      *model.User
-	}
-)
+	runShutdown sync.Once
+
+	tempWorkspace string
+}
 
 type mockSuite struct{}
 
@@ -98,32 +93,19 @@ func Setup(tb testing.TB, options ...Option) *TestHelper {
 	return setupTestHelper(dbStore, dbSettings, false, true, tb, options...)
 }
 
-func (th *TestHelper) InitBasic() *TestHelper {
-	// create users once and cache them because password hashing is slow
-	initBasicOnce.Do(func() {
-		th.SystemAdminUser = th.CreateAdmin()
-		userCache.SystemAdminUser = th.SystemAdminUser.DeepCopy()
+func (th *TestHelper) InitBasic(tb testing.TB) *TestHelper {
+	th.SystemAdminUser = th.CreateAdmin(tb)
 
-		th.BasicUser = th.CreateUserOrGuest(false)
-		userCache.BasicUser = th.BasicUser.DeepCopy()
+	th.BasicUser = th.CreateUserOrGuest(tb, false)
 
-		th.BasicUser2 = th.CreateUserOrGuest(false)
-		userCache.BasicUser2 = th.BasicUser2.DeepCopy()
-	})
-	// restore cached users
-	th.SystemAdminUser = userCache.SystemAdminUser.DeepCopy()
-	th.BasicUser = userCache.BasicUser.DeepCopy()
-	th.BasicUser2 = userCache.BasicUser2.DeepCopy()
+	th.BasicUser2 = th.CreateUserOrGuest(tb, false)
 
-	users := []*model.User{th.SystemAdminUser, th.BasicUser, th.BasicUser2}
-	th.Store.User().InsertUsers(users)
+	th.BasicTeam = th.CreateTeam(tb)
 
-	th.BasicTeam = th.CreateTeam()
-
-	// th.LinkUserToTeam(th.BasicUser, th.BasicTeam)
-	// th.LinkUserToTeam(th.BasicUser2, th.BasicTeam)
-	th.BasicChannel = th.CreateChannel(th.BasicTeam)
-	// th.BasicPost = th.CreatePost(th.BasicChannel)
+	// th.LinkUserToTeam(t, th.BasicUser, th.BasicTeam)
+	// th.LinkUserToTeam(t, th.BasicUser2, th.BasicTeam)
+	th.BasicChannel = th.CreateChannel(tb, th.BasicTeam)
+	// th.BasicPost = th.CreatePost(t, th.BasicChannel)
 	return th
 }
 
@@ -149,9 +131,7 @@ func SetupWithCluster(tb testing.TB, cluster einterfaces.ClusterInterface) *Test
 
 func setupTestHelper(dbStore store.Store, dbSettings *model.SqlSettings, enterprise bool, includeCacheLayer bool, tb testing.TB, options ...Option) *TestHelper {
 	tempWorkspace, err := os.MkdirTemp("", "apptest")
-	if err != nil {
-		panic(err)
-	}
+	require.NoError(tb, err)
 
 	configStore := config.NewTestMemoryStore()
 
@@ -180,10 +160,11 @@ func setupTestHelper(dbStore store.Store, dbSettings *model.SqlSettings, enterpr
 	}
 
 	th := &TestHelper{
-		Context: request.TestContext(tb),
-		Service: ps,
-		Suite:   &mockSuite{},
-		Store:   dbStore,
+		Context:       request.TestContext(tb),
+		Service:       ps,
+		Suite:         &mockSuite{},
+		Store:         dbStore,
+		tempWorkspace: tempWorkspace,
 	}
 
 	if _, ok := dbStore.(*mocks.Store); ok {
@@ -221,20 +202,33 @@ func setupTestHelper(dbStore store.Store, dbSettings *model.SqlSettings, enterpr
 	}
 
 	err = th.Service.Start(nil)
-	if err != nil {
-		panic(err)
-	}
+	require.NoError(tb, err)
+
+	tb.Cleanup(func() {
+		th.Shutdown(tb)
+	})
 
 	return th
 }
 
-func (th *TestHelper) TearDown() {
-	th.Service.ShutdownMetrics()
-	th.Service.Shutdown()
-	th.Service.ShutdownConfig()
+// Shutdown may be called by tests to manually shut down the [TestHelper].
+// If it's not called manually, it will get called automatically via [testing.TB.Cleanup].
+func (th *TestHelper) Shutdown(tb testing.TB) {
+	th.runShutdown.Do(func() {
+		err := th.Service.ShutdownMetrics()
+		require.NoError(tb, err)
+		err = th.Service.Shutdown()
+		require.NoError(tb, err)
+		err = th.Service.ShutdownConfig()
+		require.NoError(tb, err)
+		if th.tempWorkspace != "" {
+			err := os.RemoveAll(th.tempWorkspace)
+			require.NoError(tb, err)
+		}
+	})
 }
 
-func (th *TestHelper) CreateTeam() *model.Team {
+func (th *TestHelper) CreateTeam(tb testing.TB) *model.Team {
 	id := model.NewId()
 
 	team := &model.Team{
@@ -244,14 +238,13 @@ func (th *TestHelper) CreateTeam() *model.Team {
 		Type:        model.TeamOpen,
 	}
 
-	var err error
-	if team, err = th.Service.Store.Team().Save(team); err != nil {
-		panic(err)
-	}
+	team, err := th.Service.Store.Team().Save(team)
+	require.NoError(tb, err)
+
 	return team
 }
 
-func (th *TestHelper) CreateUserOrGuest(guest bool) *model.User {
+func (th *TestHelper) CreateUserOrGuest(tb testing.TB, guest bool) *model.User {
 	id := model.NewId()
 
 	user := &model.User{
@@ -263,16 +256,13 @@ func (th *TestHelper) CreateUserOrGuest(guest bool) *model.User {
 		Roles:         model.SystemUserRoleId,
 	}
 
-	var err error
-	user, err = th.Service.Store.User().Save(th.Context, user)
-	if err != nil {
-		panic(err)
-	}
+	user, err := th.Service.Store.User().Save(th.Context, user)
+	require.NoError(tb, err)
 
 	return user
 }
 
-func (th *TestHelper) CreateAdmin() *model.User {
+func (th *TestHelper) CreateAdmin(tb testing.TB) *model.User {
 	id := model.NewId()
 
 	user := &model.User{
@@ -284,11 +274,8 @@ func (th *TestHelper) CreateAdmin() *model.User {
 		Roles:         model.SystemAdminRoleId + " " + model.SystemUserRoleId,
 	}
 
-	var err error
-	user, err = th.Service.Store.User().Save(th.Context, user)
-	if err != nil {
-		panic(err)
-	}
+	user, err := th.Service.Store.User().Save(th.Context, user)
+	require.NoError(tb, err)
 
 	return user
 }
@@ -301,7 +288,7 @@ func WithShared(v bool) ChannelOption {
 	}
 }
 
-func (th *TestHelper) CreateChannel(team *model.Team, options ...ChannelOption) *model.Channel {
+func (th *TestHelper) CreateChannel(tb testing.TB, team *model.Team, options ...ChannelOption) *model.Channel {
 	id := model.NewId()
 
 	channel := &model.Channel{
@@ -315,11 +302,8 @@ func (th *TestHelper) CreateChannel(team *model.Team, options ...ChannelOption)
 		option(channel)
 	}
 
-	var err error
-	channel, err = th.Service.Store.Channel().Save(th.Context, channel, 999)
-	if err != nil {
-		panic(err)
-	}
+	channel, err := th.Service.Store.Channel().Save(th.Context, channel, 999)
+	require.NoError(tb, err)
 
 	return channel
 }
