@@ -62,8 +62,7 @@ func registerDummyWebConn(t *testing.T, th *TestHelper, addr net.Addr, session *
 
 func TestHubStopWithMultipleConnections(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	s := httptest.NewServer(dummyWebsocketHandler(t))
 	defer s.Close()
@@ -85,11 +84,8 @@ func TestHubStopWithMultipleConnections(t *testing.T) {
 // block the caller indefinitely.
 func TestHubStopRaceCondition(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.Service.Store.Close()
-	// We do not call TearDown because th.TearDown shuts down the hub again. And hub close is not idempotent.
-	// Making it idempotent is not really important to the server because close only happens once.
-	// So we just use this quick hack for the test.
+	th := Setup(t).InitBasic(t)
+
 	s := httptest.NewServer(dummyWebsocketHandler(t))
 
 	session, err := th.Service.CreateSession(th.Context, &model.Session{
@@ -101,7 +97,7 @@ func TestHubStopRaceCondition(t *testing.T) {
 	defer wc1.Close()
 
 	hub := th.Service.hubs[0]
-	th.Service.HubStop()
+	th.Shutdown(t)
 
 	done := make(chan bool)
 	go func() {
@@ -132,7 +128,6 @@ func TestHubStopRaceCondition(t *testing.T) {
 func TestHubSessionRevokeRace(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	// This needs to be false for the condition to trigger
 	th.Service.UpdateConfig(func(cfg *model.Config) {
@@ -185,8 +180,7 @@ func TestHubSessionRevokeRace(t *testing.T) {
 
 func TestHubConnIndex(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	_, err := th.Service.Store.Channel().SaveMember(th.Context, &model.ChannelMember{
 		ChannelId:   th.BasicChannel.Id,
@@ -410,7 +404,7 @@ func TestHubConnIndex(t *testing.T) {
 			require.Len(t, slices.Collect(connIndex.ForChannel("notexist")), 0)
 		})
 
-		ch := th.CreateChannel(th.BasicTeam)
+		ch := th.CreateChannel(t, th.BasicTeam)
 		_, err = th.Service.Store.Channel().SaveMember(th.Context, &model.ChannelMember{
 			ChannelId:   ch.Id,
 			UserId:      th.BasicUser2.Id,
@@ -438,7 +432,6 @@ func TestHubConnIndex(t *testing.T) {
 func TestHubConnIndexIncorrectRemoval(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	connIndex := newHubConnectionIndex(1*time.Second, th.Service.Store, th.Service.logger, false)
 
@@ -489,7 +482,6 @@ func TestHubConnIndexIncorrectRemoval(t *testing.T) {
 func TestHubConnIndexInactive(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	connIndex := newHubConnectionIndex(2*time.Second, th.Service.Store, th.Service.logger, false)
 
@@ -556,7 +548,6 @@ func TestReliableWebSocketSend(t *testing.T) {
 	testCluster := &testlib.FakeClusterInterface{}
 
 	th := SetupWithCluster(t, testCluster)
-	defer th.TearDown()
 
 	ev := model.NewWebSocketEvent("test_unreliable_event", "", "", "", nil, "")
 	ev = ev.SetBroadcast(&model.WebsocketBroadcast{})
@@ -589,8 +580,7 @@ func TestReliableWebSocketSend(t *testing.T) {
 
 func TestHubIsRegistered(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	session, err := th.Service.CreateSession(th.Context, &model.Session{
 		UserId: th.BasicUser.Id,
@@ -625,8 +615,7 @@ func TestHubIsRegistered(t *testing.T) {
 
 func TestHubWebConnCount(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	session, err := th.Service.CreateSession(th.Context, &model.Session{
 		UserId: th.BasicUser.Id,
@@ -657,7 +646,6 @@ var globalIter iter.Seq[*WebConn]
 
 func BenchmarkHubConnIndexIteratorForUser(b *testing.B) {
 	th := Setup(b)
-	defer th.TearDown()
 
 	connIndex := newHubConnectionIndex(2*time.Second, th.Service.Store, th.Service.logger, false)
 
@@ -729,8 +717,7 @@ func BenchmarkHubConnIndexIteratorForUser(b *testing.B) {
 }
 
 func BenchmarkHubConnIndexIteratorForChannel(b *testing.B) {
-	th := Setup(b).InitBasic()
-	defer th.TearDown()
+	th := Setup(b).InitBasic(b)
 
 	_, err := th.Service.Store.Channel().SaveMember(th.Context, &model.ChannelMember{
 		ChannelId:   th.BasicChannel.Id,
@@ -792,8 +779,7 @@ func BenchmarkHubConnIndexIteratorForChannel(b *testing.B) {
 // Always run this with -benchtime=0.1s
 // See: https://github.com/golang/go/issues/27217.
 func BenchmarkHubConnIndex(b *testing.B) {
-	th := Setup(b).InitBasic()
-	defer th.TearDown()
+	th := Setup(b).InitBasic(b)
 	connIndex := newHubConnectionIndex(1*time.Second, th.Service.Store, th.Service.logger, false)
 
 	// User1
@@ -843,7 +829,6 @@ func BenchmarkHubConnIndex(b *testing.B) {
 func TestHubConnIndexRemoveMemLeak(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	connIndex := newHubConnectionIndex(1*time.Second, th.Service.Store, th.Service.logger, false)
 
@@ -881,8 +866,7 @@ func TestHubConnIndexRemoveMemLeak(t *testing.T) {
 var hubSink *Hub
 
 func BenchmarkGetHubForUserId(b *testing.B) {
-	th := Setup(b).InitBasic()
-	defer th.TearDown()
+	th := Setup(b).InitBasic(b)
 
 	err := th.Service.Start(nil)
 	require.NoError(b, err)
@@ -897,7 +881,6 @@ func TestClusterBroadcast(t *testing.T) {
 	testCluster := &testlib.FakeClusterInterface{}
 
 	th := SetupWithCluster(t, testCluster)
-	defer th.TearDown()
 
 	ev := model.NewWebSocketEvent("test_event", "", "", "", nil, "")
 	broadcast := &model.WebsocketBroadcast{
@@ -927,7 +910,6 @@ func TestClusterBroadcastHooks(t *testing.T) {
 		testCluster := &testlib.FakeClusterInterface{}
 
 		th := SetupWithCluster(t, testCluster)
-		defer th.TearDown()
 
 		hookID := broadcastTest
 		hookArgs := map[string]any{
@@ -951,7 +933,6 @@ func TestClusterBroadcastHooks(t *testing.T) {
 		testCluster := &testlib.FakeClusterInterface{}
 
 		th := SetupWithCluster(t, testCluster)
-		defer th.TearDown()
 
 		hookID := "test_broadcast_hook_with_args"
 		hookArgs := map[string]any{
