@@ -120,7 +120,7 @@ func (api *PluginAPI) GetPluginConfig() map[string]any {
 }
 
 func (api *PluginAPI) SavePluginConfig(pluginConfig map[string]any) *model.AppError {
-	cfg := api.app.GetSanitizedConfig()
+	cfg := api.app.Config().Clone()
 	cfg.PluginSettings.Plugins[api.manifest.Id] = pluginConfig
 	_, _, err := api.app.SaveConfig(cfg, true)
 	return err
@@ -1202,9 +1202,33 @@ func (api *PluginAPI) PluginHTTP(request *http.Request) *http.Response {
 			Body:       io.NopCloser(bytes.NewBufferString(message)),
 		}
 	}
-	responseTransfer := &PluginResponseWriter{}
-	api.app.ServeInterPluginRequest(responseTransfer, request, api.id, destinationPluginId)
-	return responseTransfer.GenerateResponse()
+
+	// Create pipe for streaming response
+	pr, pw := io.Pipe()
+	responseTransfer := NewPluginResponseWriter(pw)
+
+	// Serve the request in a goroutine, streaming the response through the pipe
+	go func() {
+		defer func() {
+			// Ensure pipe is closed when request completes
+			var closeErr error
+			if err := recover(); err != nil {
+				closeErr = responseTransfer.CloseWithError(fmt.Errorf("panic in plugin request: %v", err))
+			} else {
+				closeErr = responseTransfer.Close()
+			}
+
+			if closeErr != nil {
+				api.logger.Errorw("Failed to close plugin response pipe", "error", closeErr)
+			}
+		}()
+		api.app.ServeInterPluginRequest(responseTransfer, request, api.id, destinationPluginId)
+	}()
+
+	// Wait for headers to be ready before returning response
+	<-responseTransfer.ResponseReady
+
+	return responseTransfer.GenerateResponse(pr)
 }
 
 func (api *PluginAPI) CreateCommand(cmd *model.Command) (*model.Command, error) {
