@@ -18,8 +18,7 @@ import (
 func TestPluginDeadlock(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("Single Plugin", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		pluginPostOnActivate := template.Must(template.New("pluginPostOnActivate").Parse(`
 			package main
@@ -107,8 +106,7 @@ func TestPluginDeadlock(t *testing.T) {
 	})
 
 	t.Run("Multiple Plugins", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		pluginPostOnHasBeenPosted := template.Must(template.New("pluginPostOnHasBeenPosted").Parse(`
 			package main
@@ -215,7 +213,7 @@ func TestPluginDeadlock(t *testing.T) {
 	})
 
 	t.Run("CreatePost on OnDeactivate Plugin", func(t *testing.T) {
-		th := Setup(t).InitBasic()
+		th := Setup(t).InitBasic(t)
 
 		pluginPostOnActivate := template.Must(template.New("pluginPostOnActivate").Parse(`
 			package main
@@ -296,7 +294,8 @@ func TestPluginDeadlock(t *testing.T) {
 			require.False(t, messageWillBePostedCalled, "MessageWillBePosted should not have been called")
 
 			SetAppEnvironmentWithPlugins(t, plugins, th.App, th.NewPluginAPI)
-			th.TearDown()
+			// Shut down all plugins
+			th.App.ch.ShutDownPlugins()
 
 			posts, appErr = th.App.GetPosts(th.Context, th.BasicChannel.Id, 0, 2)
 			require.Nil(t, appErr)
