@@ -79,8 +79,7 @@ func TestHookMessageWillBePosted(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("rejected", func(t *testing.T) {
 		mainHelper.Parallel(t)
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		tearDown, _, _ := SetAppEnvironmentWithPlugins(t, []string{
 			`
@@ -120,8 +119,7 @@ func TestHookMessageWillBePosted(t *testing.T) {
 
 	t.Run("rejected, returned post ignored", func(t *testing.T) {
 		mainHelper.Parallel(t)
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		tearDown, _, _ := SetAppEnvironmentWithPlugins(t, []string{
 			`
@@ -162,8 +160,7 @@ func TestHookMessageWillBePosted(t *testing.T) {
 
 	t.Run("allowed", func(t *testing.T) {
 		mainHelper.Parallel(t)
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		tearDown, _, _ := SetAppEnvironmentWithPlugins(t, []string{
 			`
@@ -206,8 +203,7 @@ func TestHookMessageWillBePosted(t *testing.T) {
 
 	t.Run("updated", func(t *testing.T) {
 		mainHelper.Parallel(t)
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		tearDown, _, _ := SetAppEnvironmentWithPlugins(t, []string{
 			`
@@ -251,8 +247,7 @@ func TestHookMessageWillBePosted(t *testing.T) {
 
 	t.Run("multiple updated", func(t *testing.T) {
 		mainHelper.Parallel(t)
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		tearDown, _, _ := SetAppEnvironmentWithPlugins(t, []string{
 			`
@@ -315,8 +310,7 @@ func TestHookMessageWillBePosted(t *testing.T) {
 
 func TestHookMessageHasBeenPosted(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	var mockAPI plugintest.API
 	mockAPI.On("LoadPluginConfiguration", mock.Anything).Return(nil)
@@ -359,8 +353,7 @@ func TestHookMessageHasBeenPosted(t *testing.T) {
 
 func TestHookMessageWillBeUpdated(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	tearDown, _, _ := SetAppEnvironmentWithPlugins(t,
 		[]string{
@@ -405,8 +398,7 @@ func TestHookMessageWillBeUpdated(t *testing.T) {
 
 func TestHookMessageHasBeenUpdated(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	var mockAPI plugintest.API
 	mockAPI.On("LoadPluginConfiguration", mock.Anything).Return(nil)
@@ -454,8 +446,7 @@ func TestHookMessageHasBeenUpdated(t *testing.T) {
 
 func TestHookMessageHasBeenDeleted(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	var mockAPI plugintest.API
 	mockAPI.On("LoadPluginConfiguration", mock.Anything).Return(nil)
@@ -502,8 +493,7 @@ func TestHookFileWillBeUploaded(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("rejected", func(t *testing.T) {
 		mainHelper.Parallel(t)
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		var mockAPI plugintest.API
 		mockAPI.On("LoadPluginConfiguration", mock.Anything).Return(nil)
@@ -547,8 +537,7 @@ func TestHookFileWillBeUploaded(t *testing.T) {
 
 	t.Run("rejected, returned file ignored", func(t *testing.T) {
 		mainHelper.Parallel(t)
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		var mockAPI plugintest.API
 		mockAPI.On("LoadPluginConfiguration", mock.Anything).Return(nil)
@@ -598,8 +587,7 @@ func TestHookFileWillBeUploaded(t *testing.T) {
 
 	t.Run("allowed", func(t *testing.T) {
 		mainHelper.Parallel(t)
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		var mockAPI plugintest.API
 		mockAPI.On("LoadPluginConfiguration", mock.Anything).Return(nil)
@@ -655,8 +643,7 @@ func TestHookFileWillBeUploaded(t *testing.T) {
 
 	t.Run("updated", func(t *testing.T) {
 		mainHelper.Parallel(t)
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		var mockAPI plugintest.API
 		mockAPI.On("LoadPluginConfiguration", mock.Anything).Return(nil)
@@ -729,8 +716,7 @@ func TestHookFileWillBeUploaded(t *testing.T) {
 
 func TestUserWillLogIn_Blocked(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	err := th.App.UpdatePassword(th.Context, th.BasicUser, "hunter2")
 	assert.Nil(t, err, "Error updating user password: %s", err)
@@ -769,8 +755,7 @@ func TestUserWillLogIn_Blocked(t *testing.T) {
 
 func TestUserWillLogInIn_Passed(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	err := th.App.UpdatePassword(th.Context, th.BasicUser, "hunter2")
 
@@ -812,8 +797,7 @@ func TestUserWillLogInIn_Passed(t *testing.T) {
 
 func TestUserHasLoggedIn(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	err := th.App.UpdatePassword(th.Context, th.BasicUser, "hunter2")
 
@@ -861,7 +845,6 @@ func TestUserHasLoggedIn(t *testing.T) {
 func TestUserHasBeenDeactivated(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	tearDown, _, _ := SetAppEnvironmentWithPlugins(t,
 		[]string{
@@ -911,7 +894,6 @@ func TestUserHasBeenDeactivated(t *testing.T) {
 func TestUserHasBeenCreated(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	tearDown, _, _ := SetAppEnvironmentWithPlugins(t,
 		[]string{
@@ -957,7 +939,6 @@ func TestUserHasBeenCreated(t *testing.T) {
 func TestErrorString(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	t.Run("errors.New", func(t *testing.T) {
 		tearDown, _, activationErrors := SetAppEnvironmentWithPlugins(t,
@@ -1031,8 +1012,8 @@ func TestErrorString(t *testing.T) {
 
 func TestHookContext(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
+
 	ctx := request.EmptyContext(th.TestLogger)
 
 	// We don't actually have a session, we are faking it so just set something arbitrarily
@@ -1088,7 +1069,6 @@ func TestHookContext(t *testing.T) {
 func TestActiveHooks(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	t.Run("", func(t *testing.T) {
 		tearDown, pluginIDs, _ := SetAppEnvironmentWithPlugins(t,
@@ -1160,7 +1140,6 @@ func TestActiveHooks(t *testing.T) {
 func TestHookMetrics(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	t.Run("", func(t *testing.T) {
 		metricsMock := &mocks.MetricsInterface{}
@@ -1259,8 +1238,7 @@ func TestHookMetrics(t *testing.T) {
 
 func TestHookReactionHasBeenAdded(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	var mockAPI plugintest.API
 	mockAPI.On("LogDebug", "smile").Return(nil)
@@ -1306,8 +1284,7 @@ func TestHookReactionHasBeenAdded(t *testing.T) {
 
 func TestHookReactionHasBeenRemoved(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	var mockAPI plugintest.API
 	mockAPI.On("LogDebug", "star").Return(nil)
@@ -1355,8 +1332,7 @@ func TestHookReactionHasBeenRemoved(t *testing.T) {
 
 func TestHookRunDataRetention(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	tearDown, pluginIDs, _ := SetAppEnvironmentWithPlugins(t,
 		[]string{
@@ -1401,8 +1377,7 @@ func TestHookRunDataRetention(t *testing.T) {
 
 func TestHookOnSendDailyTelemetry(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	tearDown, pluginIDs, _ := SetAppEnvironmentWithPlugins(t,
 		[]string{
@@ -1446,8 +1421,7 @@ func TestHookOnSendDailyTelemetry(t *testing.T) {
 
 func TestHookOnCloudLimitsUpdated(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	tearDown, pluginIDs, _ := SetAppEnvironmentWithPlugins(t,
 		[]string{
@@ -1527,8 +1501,7 @@ func TestHookNotificationWillBePushed(t *testing.T) {
 		t.Run(tt.name, func(t *testing.T) {
 			mainHelper.Parallel(t)
 
-			th := Setup(t).InitBasic()
-			defer th.TearDown()
+			th := Setup(t).InitBasic(t)
 
 			templatedPlugin := fmt.Sprintf(hookNotificationWillBePushedTmpl, tt.testCode)
 			tearDown, _, _ := SetAppEnvironmentWithPlugins(t, []string{templatedPlugin}, th.App, th.NewPluginAPI)
@@ -1541,7 +1514,7 @@ func TestHookNotificationWillBePushed(t *testing.T) {
 			}
 			var userSessions []userSession
 			for range 3 {
-				u := th.CreateUser()
+				u := th.CreateUser(t)
 				sess, err := th.App.CreateSession(th.Context, &model.Session{
 					UserId:    u.Id,
 					DeviceId:  "deviceID" + u.Id,
@@ -1557,7 +1530,7 @@ func TestHookNotificationWillBePushed(t *testing.T) {
 				require.Nil(t, err)
 				_, err = th.App.AddTeamMember(th.Context, th.BasicTeam.Id, u.Id)
 				require.Nil(t, err)
-				th.AddUserToChannel(u, th.BasicChannel)
+				th.AddUserToChannel(t, u, th.BasicChannel)
 				userSessions = append(userSessions, userSession{
 					user:    u,
 					session: sess,
@@ -1584,7 +1557,7 @@ func TestHookNotificationWillBePushed(t *testing.T) {
 				go func(user model.User) {
 					defer wg.Done()
 					notification := &PostNotification{
-						Post:    th.CreatePost(th.BasicChannel),
+						Post:    th.CreatePost(t, th.BasicChannel),
 						Channel: th.BasicChannel,
 						ProfileMap: map[string]*model.User{
 							user.Id: &user,
@@ -1662,13 +1635,12 @@ func TestHookEmailNotificationWillBeSent(t *testing.T) {
 		t.Run(tt.name, func(t *testing.T) {
 			mainHelper.Parallel(t)
 
-			th := Setup(t).InitBasic()
-			defer th.TearDown()
+			th := Setup(t).InitBasic(t)
 
 			// Create a test user for email notifications
-			user := th.CreateUser()
-			th.LinkUserToTeam(user, th.BasicTeam)
-			th.AddUserToChannel(user, th.BasicChannel)
+			user := th.CreateUser(t)
+			th.LinkUserToTeam(t, user, th.BasicTeam)
+			th.AddUserToChannel(t, user, th.BasicChannel)
 
 			// Set up email notification preferences to disable batching
 			appErr := th.App.UpdatePreferences(th.Context, user.Id, model.Preferences{
@@ -1784,8 +1756,7 @@ func TestHookMessagesWillBeConsumed(t *testing.T) {
 
 		th := SetupConfig(t, func(cfg *model.Config) {
 			cfg.FeatureFlags.ConsumePostHook = false
-		}).InitBasic()
-		t.Cleanup(th.TearDown)
+		}).InitBasic(t)
 
 		setupPlugin(t, th)
 
@@ -1808,9 +1779,7 @@ func TestHookMessagesWillBeConsumed(t *testing.T) {
 
 		th := SetupConfig(t, func(cfg *model.Config) {
 			cfg.FeatureFlags.ConsumePostHook = true
-		}).InitBasic()
-
-		t.Cleanup(th.TearDown)
+		}).InitBasic(t)
 
 		setupPlugin(t, th)
 
@@ -1833,8 +1802,7 @@ func TestHookPreferencesHaveChanged(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("should be called when preferences are changed by non-plugin code", func(t *testing.T) {
 		mainHelper.Parallel(t)
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		// Setup plugin
 		var mockAPI plugintest.API
@@ -1902,8 +1870,7 @@ func TestHookPreferencesHaveChanged(t *testing.T) {
 
 	t.Run("should be called when preferences are changed by plugin code", func(t *testing.T) {
 		mainHelper.Parallel(t)
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		// Setup plugin
 		pluginCode := `
@@ -2026,13 +1993,12 @@ func TestChannelHasBeenCreated(t *testing.T) {
 
 	t.Run("should call hook when a regular channel is created", func(t *testing.T) {
 		mainHelper.Parallel(t)
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		// Setup plugin
 		setupPluginAPITest(t, getPluginCode(th), pluginManifest, pluginID, th.App, th.Context)
 
-		user1 := th.CreateUser()
+		user1 := th.CreateUser(t)
 
 		channel, appErr := th.App.CreateChannel(th.Context, &model.Channel{
 			CreatorId: user1.Id,
@@ -2058,14 +2024,13 @@ func TestChannelHasBeenCreated(t *testing.T) {
 
 	t.Run("should call hook when a DM is created", func(t *testing.T) {
 		mainHelper.Parallel(t)
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		// Setup plugin
 		setupPluginAPITest(t, getPluginCode(th), pluginManifest, pluginID, th.App, th.Context)
 
-		user1 := th.CreateUser()
-		user2 := th.CreateUser()
+		user1 := th.CreateUser(t)
+		user2 := th.CreateUser(t)
 
 		channel, appErr := th.App.GetOrCreateDirectChannel(th.Context, user1.Id, user2.Id)
 		require.Nil(t, appErr)
@@ -2085,15 +2050,14 @@ func TestChannelHasBeenCreated(t *testing.T) {
 
 	t.Run("should call hook when a GM is created", func(t *testing.T) {
 		mainHelper.Parallel(t)
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		// Setup plugin
 		setupPluginAPITest(t, getPluginCode(th), pluginManifest, pluginID, th.App, th.Context)
 
-		user1 := th.CreateUser()
-		user2 := th.CreateUser()
-		user3 := th.CreateUser()
+		user1 := th.CreateUser(t)
+		user2 := th.CreateUser(t)
+		user3 := th.CreateUser(t)
 
 		channel, appErr := th.App.CreateGroupChannel(th.Context, []string{user1.Id, user2.Id, user3.Id}, user1.Id)
 		require.Nil(t, appErr)
@@ -2159,13 +2123,12 @@ func TestUserHasJoinedChannel(t *testing.T) {
 
 	t.Run("should call hook when a user joins an existing channel", func(t *testing.T) {
 		mainHelper.Parallel(t)
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
-		user1 := th.CreateUser()
-		th.LinkUserToTeam(user1, th.BasicTeam)
-		user2 := th.CreateUser()
-		th.LinkUserToTeam(user2, th.BasicTeam)
+		user1 := th.CreateUser(t)
+		th.LinkUserToTeam(t, user1, th.BasicTeam)
+		user2 := th.CreateUser(t)
+		th.LinkUserToTeam(t, user2, th.BasicTeam)
 
 		channel, appErr := th.App.CreateChannel(th.Context, &model.Channel{
 			CreatorId: user1.Id,
@@ -2205,13 +2168,12 @@ func TestUserHasJoinedChannel(t *testing.T) {
 
 	t.Run("should call hook when a user is added to an existing channel", func(t *testing.T) {
 		mainHelper.Parallel(t)
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
-		user1 := th.CreateUser()
-		th.LinkUserToTeam(user1, th.BasicTeam)
-		user2 := th.CreateUser()
-		th.LinkUserToTeam(user2, th.BasicTeam)
+		user1 := th.CreateUser(t)
+		th.LinkUserToTeam(t, user1, th.BasicTeam)
+		user2 := th.CreateUser(t)
+		th.LinkUserToTeam(t, user2, th.BasicTeam)
 
 		channel, appErr := th.App.CreateChannel(th.Context, &model.Channel{
 			CreatorId: user1.Id,
@@ -2251,13 +2213,12 @@ func TestUserHasJoinedChannel(t *testing.T) {
 
 	t.Run("should not call hook when a regular channel is created", func(t *testing.T) {
 		mainHelper.Parallel(t)
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		// Setup plugin
 		setupPluginAPITest(t, getPluginCode(th), pluginManifest, pluginID, th.App, th.Context)
 
-		user1 := th.CreateUser()
+		user1 := th.CreateUser(t)
 
 		channel, appErr := th.App.CreateChannel(th.Context, &model.Channel{
 			CreatorId: user1.Id,
@@ -2286,14 +2247,13 @@ func TestUserHasJoinedChannel(t *testing.T) {
 
 	t.Run("should not call hook when a DM is created", func(t *testing.T) {
 		mainHelper.Parallel(t)
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		// Setup plugin
 		setupPluginAPITest(t, getPluginCode(th), pluginManifest, pluginID, th.App, th.Context)
 
-		user1 := th.CreateUser()
-		user2 := th.CreateUser()
+		user1 := th.CreateUser(t)
+		user2 := th.CreateUser(t)
 
 		channel, appErr := th.App.GetOrCreateDirectChannel(th.Context, user1.Id, user2.Id)
 		require.Nil(t, appErr)
@@ -2317,15 +2277,14 @@ func TestUserHasJoinedChannel(t *testing.T) {
 
 	t.Run("should not call hook when a GM is created", func(t *testing.T) {
 		mainHelper.Parallel(t)
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		// Setup plugin
 		setupPluginAPITest(t, getPluginCode(th), pluginManifest, pluginID, th.App, th.Context)
 
-		user1 := th.CreateUser()
-		user2 := th.CreateUser()
-		user3 := th.CreateUser()
+		user1 := th.CreateUser(t)
+		user2 := th.CreateUser(t)
+		user3 := th.CreateUser(t)
 
 		channel, appErr := th.App.CreateGroupChannel(th.Context, []string{user1.Id, user2.Id, user3.Id}, user1.Id)
 		require.Nil(t, appErr)
