@@ -12,8 +12,7 @@ import (
 )
 
 func TestPluginProperties(t *testing.T) {
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	t.Run("test property field methods", func(t *testing.T) {
 		groupName := model.NewId()
