@@ -36,7 +36,6 @@ func getHashedKey(key string) string {
 func TestPluginKeyValueStore(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	pluginID := "testpluginid"
 
@@ -137,7 +136,6 @@ func TestPluginKeyValueStore(t *testing.T) {
 func TestPluginKeyValueStoreCompareAndSet(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	pluginID := "testpluginid"
 
@@ -198,7 +196,6 @@ func TestPluginKeyValueStoreSetWithOptionsJSON(t *testing.T) {
 
 	t.Run("storing a value without providing options works", func(t *testing.T) {
 		th := Setup(t)
-		defer th.TearDown()
 
 		result, err := th.App.SetPluginKeyWithOptions(pluginID, "key", []byte("value-1"), model.PluginKVSetOptions{})
 		assert.True(t, result)
@@ -212,7 +209,6 @@ func TestPluginKeyValueStoreSetWithOptionsJSON(t *testing.T) {
 
 	t.Run("test that setting it atomic when it doesn't match doesn't change anything", func(t *testing.T) {
 		th := Setup(t)
-		defer th.TearDown()
 
 		err := th.App.SetPluginKey(pluginID, "key", []byte("value-1"))
 		require.Nil(t, err)
@@ -232,7 +228,6 @@ func TestPluginKeyValueStoreSetWithOptionsJSON(t *testing.T) {
 
 	t.Run("test the atomic change with the proper old value", func(t *testing.T) {
 		th := Setup(t)
-		defer th.TearDown()
 
 		err := th.App.SetPluginKey(pluginID, "key", []byte("value-2"))
 		require.Nil(t, err)
@@ -252,7 +247,6 @@ func TestPluginKeyValueStoreSetWithOptionsJSON(t *testing.T) {
 
 	t.Run("when new value is nil and old value matches with the current, it should delete the currently set value", func(t *testing.T) {
 		th := Setup(t)
-		defer th.TearDown()
 
 		// first set a value.
 		result, err := th.App.SetPluginKeyWithOptions(pluginID, "nil-test-key-2", []byte("value-1"), model.PluginKVSetOptions{})
@@ -274,7 +268,6 @@ func TestPluginKeyValueStoreSetWithOptionsJSON(t *testing.T) {
 
 	t.Run("when new value is nil and there is a value set for the key already, it should delete the currently set value", func(t *testing.T) {
 		th := Setup(t)
-		defer th.TearDown()
 
 		// first set a value.
 		result, err := th.App.SetPluginKeyWithOptions(pluginID, "nil-test-key-3", []byte("value-1"), model.PluginKVSetOptions{})
@@ -299,7 +292,6 @@ func TestPluginKeyValueStoreSetWithOptionsJSON(t *testing.T) {
 
 	t.Run("when old value is nil and there is no value set for the key before, it should set the new value", func(t *testing.T) {
 		th := Setup(t)
-		defer th.TearDown()
 
 		result, err := th.App.SetPluginKeyWithOptions(pluginID, "nil-test-key-4", []byte("value-1"), model.PluginKVSetOptions{
 			Atomic:   true,
@@ -315,7 +307,6 @@ func TestPluginKeyValueStoreSetWithOptionsJSON(t *testing.T) {
 
 	t.Run("test that value is set and unset with ExpireInSeconds", func(t *testing.T) {
 		th := Setup(t)
-		defer th.TearDown()
 
 		result, err := th.App.SetPluginKeyWithOptions(pluginID, "key", []byte("value-1"), model.PluginKVSetOptions{
 			ExpireInSeconds: 1,
@@ -340,7 +331,6 @@ func TestPluginKeyValueStoreSetWithOptionsJSON(t *testing.T) {
 func TestGetPluginStatusesDisabled(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	th.App.UpdateConfig(func(cfg *model.Config) {
 		*cfg.PluginSettings.Enable = false
@@ -354,7 +344,6 @@ func TestGetPluginStatusesDisabled(t *testing.T) {
 func TestGetPluginStatuses(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	th.App.UpdateConfig(func(cfg *model.Config) {
 		*cfg.PluginSettings.Enable = true
@@ -374,7 +363,6 @@ func TestPluginSync(t *testing.T) {
 			filepath.Join(path, "development-private-key.asc"),
 		}
 	})
-	defer th.TearDown()
 
 	testCases := []struct {
 		Description string
@@ -531,7 +519,6 @@ func TestPluginSync(t *testing.T) {
 func TestChannelsPluginsInit(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	runNoPanicTest := func(t *testing.T) {
 		path, _ := fileutils.FindDir("tests")
@@ -561,7 +548,6 @@ func TestChannelsPluginsInit(t *testing.T) {
 func TestSyncPluginsActiveState(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	th.App.UpdateConfig(func(cfg *model.Config) {
 		*cfg.PluginSettings.Enable = true
@@ -621,8 +607,7 @@ func TestSyncPluginsActiveState(t *testing.T) {
 func TestPluginPanicLogs(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("should panic", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		tearDown, _, _ := SetAppEnvironmentWithPlugins(t, []string{
 			`
@@ -670,8 +655,7 @@ func TestPluginPanicLogs(t *testing.T) {
 func TestPluginStatusActivateError(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("should return error from OnActivate in plugin statuses", func(t *testing.T) {
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		pluginSource := `
 		package main
@@ -731,7 +715,6 @@ func TestProcessPrepackagedPlugins(t *testing.T) {
 				filepath.Join(testsPath, "development-private-key.asc"),
 			}
 		})
-		t.Cleanup(th.TearDown)
 
 		// Make a prepackaged_plugins directory for use with the tests.
 		err := os.Mkdir(filepath.Join(th.tempWorkspace, prepackagedPluginsDir), os.ModePerm)
@@ -1268,7 +1251,6 @@ func TestProcessPrepackagedPlugins(t *testing.T) {
 func TestGetPluginStateOverride(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	t.Run("no override", func(t *testing.T) {
 		overrides, value := th.App.ch.getPluginStateOverride("focalboard")
@@ -1288,7 +1270,6 @@ func TestGetPluginStateOverride(t *testing.T) {
 			th2 := SetupConfig(t, func(cfg *model.Config) {
 				cfg.FeatureFlags.AppsEnabled = true
 			})
-			defer th2.TearDown()
 
 			overrides, value := th2.App.ch.getPluginStateOverride("com.mattermost.apps")
 			require.False(t, overrides)
@@ -1300,7 +1281,6 @@ func TestGetPluginStateOverride(t *testing.T) {
 			th2 := SetupConfig(t, func(cfg *model.Config) {
 				cfg.FeatureFlags.AppsEnabled = false
 			})
-			defer th2.TearDown()
 
 			overrides, value := th2.App.ch.getPluginStateOverride("com.mattermost.apps")
 			require.True(t, overrides)
