@@ -50,8 +50,6 @@ func TestNoticeValidation(t *testing.T) {
 		*cfg.AnnouncementSettings.UserNoticesEnabled = true
 	})
 
-	defer th.TearDown()
-
 	type args struct {
 		client               model.NoticeClientType
 		clientVersion        string
@@ -548,8 +546,7 @@ func TestNoticeValidation(t *testing.T) {
 
 func TestNoticeFetch(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	notices := model.ProductNotices{model.ProductNotice{
 		Conditions: model.Conditions{},
