@@ -12,6 +12,7 @@ import (
 	"github.com/mattermost/mattermost/server/public/plugin"
 	"github.com/mattermost/mattermost/server/public/shared/mlog"
 	"github.com/mattermost/mattermost/server/public/shared/request"
+	"github.com/mattermost/mattermost/server/v8/channels/store"
 )
 
 func (a *App) SaveReactionForPost(rctx request.CTX, reaction *model.Reaction) (*model.Reaction, *model.AppError) {
@@ -20,6 +21,16 @@ func (a *App) SaveReactionForPost(rctx request.CTX, reaction *model.Reaction) (*
 		return nil, err
 	}
 
+	if post.Type == model.PostTypeBurnOnRead && post.UserId != reaction.UserId {
+		receipt, err := a.Srv().Store().ReadReceipt().Get(rctx, post.Id, reaction.UserId)
+		if err != nil && !store.IsErrNotFound(err) {
+			return nil, model.NewAppError("SaveReactionForPost", "app.reaction.save.save.app_error", nil, "", http.StatusInternalServerError).Wrap(err)
+		}
+		if receipt == nil || receipt.ExpireAt < model.GetMillis() {
+			return nil, model.NewAppError("SaveReactionForPost", "api.reaction.save.burn_on_read.app_error", nil, "", http.StatusForbidden)
+		}
+	}
+
 	// Check whether this is a valid emoji
 	if _, ok := model.GetSystemEmojiId(reaction.EmojiName); !ok {
 		if _, emojiErr := a.GetEmojiByName(rctx, reaction.EmojiName); emojiErr != nil {
@@ -194,5 +205,11 @@ func (a *App) sendReactionEvent(rctx request.CTX, event model.WebsocketEventType
 		rctx.Logger().Warn("Failed to encode reaction to JSON", mlog.Err(err))
 	}
 	message.Add("reaction", string(reactionJSON))
+
+	// For burn-on-read posts, filter recipients based on read receipts
+	if post.Type == model.PostTypeBurnOnRead {
+		useBurnOnReadReactionHook(message, post.UserId, post.Id)
+	}
+
 	a.Publish(message)
 }
