@@ -16,9 +16,9 @@ import (
 
 func TestSaveReactionForPost(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
+	th := Setup(t).InitBasic(t)
 
-	post := th.CreatePost(th.BasicChannel)
+	post := th.CreatePost(t, th.BasicChannel)
 	reaction1, err := th.App.SaveReactionForPost(th.Context, &model.Reaction{
 		UserId:    th.BasicUser.Id,
 		PostId:    post.Id,
@@ -55,11 +55,11 @@ func TestSaveReactionForPost(t *testing.T) {
 
 	t.Run("should not add reaction if we are over the limit", func(t *testing.T) {
 		var originalLimit *int
-		th.UpdateConfig(func(cfg *model.Config) {
+		th.UpdateConfig(t, func(cfg *model.Config) {
 			originalLimit = cfg.ServiceSettings.UniqueEmojiReactionLimitPerPost
 			*cfg.ServiceSettings.UniqueEmojiReactionLimitPerPost = 3
 		})
-		defer th.UpdateConfig(func(cfg *model.Config) {
+		defer th.UpdateConfig(t, func(cfg *model.Config) {
 			cfg.ServiceSettings.UniqueEmojiReactionLimitPerPost = originalLimit
 		})
 
@@ -75,14 +75,14 @@ func TestSaveReactionForPost(t *testing.T) {
 	})
 
 	t.Run("should always add reaction if we are over the limit but the reaction is not unique", func(t *testing.T) {
-		user := th.CreateUser()
+		user := th.CreateUser(t)
 
 		var originalLimit *int
-		th.UpdateConfig(func(cfg *model.Config) {
+		th.UpdateConfig(t, func(cfg *model.Config) {
 			originalLimit = cfg.ServiceSettings.UniqueEmojiReactionLimitPerPost
 			*cfg.ServiceSettings.UniqueEmojiReactionLimitPerPost = 3
 		})
-		defer th.UpdateConfig(func(cfg *model.Config) {
+		defer th.UpdateConfig(t, func(cfg *model.Config) {
 			cfg.ServiceSettings.UniqueEmojiReactionLimitPerPost = originalLimit
 		})
 
@@ -103,7 +103,7 @@ func TestSaveReactionForPost(t *testing.T) {
 		})
 
 		// Create a DM channel between two users who don't share a team
-		dmChannel := th.CreateDmChannel(th.BasicUser2)
+		dmChannel := th.CreateDmChannel(t, th.BasicUser2)
 
 		// Ensure the two users do not share a team
 		teams, err := th.App.GetTeamsForUser(th.BasicUser.Id)
@@ -120,10 +120,10 @@ func TestSaveReactionForPost(t *testing.T) {
 		}
 
 		// Create separate teams for each user
-		team1 := th.CreateTeam()
-		team2 := th.CreateTeam()
-		th.LinkUserToTeam(th.BasicUser, team1)
-		th.LinkUserToTeam(th.BasicUser2, team2)
+		team1 := th.CreateTeam(t)
+		team2 := th.CreateTeam(t)
+		th.LinkUserToTeam(t, th.BasicUser, team1)
+		th.LinkUserToTeam(t, th.BasicUser2, team2)
 
 		// Create a post in the DM channel
 		post := &model.Post{
@@ -156,15 +156,14 @@ func TestDeleteReactionForPostWithRestrictedDM(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("cannot delete reaction in restricted DM", func(t *testing.T) {
 		mainHelper.Parallel(t)
-		th := Setup(t).InitBasic()
-		defer th.TearDown()
+		th := Setup(t).InitBasic(t)
 
 		th.App.UpdateConfig(func(cfg *model.Config) {
 			*cfg.TeamSettings.RestrictDirectMessage = model.DirectMessageTeam
 		})
 
 		// Create a DM channel between two users who don't share a team
-		dmChannel := th.CreateDmChannel(th.BasicUser2)
+		dmChannel := th.CreateDmChannel(t, th.BasicUser2)
 
 		// Ensure the two users do not share a team
 		teams, err := th.App.GetTeamsForUser(th.BasicUser.Id)
@@ -181,10 +180,10 @@ func TestDeleteReactionForPostWithRestrictedDM(t *testing.T) {
 		}
 
 		// Create separate teams for each user
-		team1 := th.CreateTeam()
-		team2 := th.CreateTeam()
-		th.LinkUserToTeam(th.BasicUser, team1)
-		th.LinkUserToTeam(th.BasicUser2, team2)
+		team1 := th.CreateTeam(t)
+		team2 := th.CreateTeam(t)
+		th.LinkUserToTeam(t, th.BasicUser, team1)
+		th.LinkUserToTeam(t, th.BasicUser2, team2)
 
 		// Create a post in the DM channel
 		post := &model.Post{
@@ -216,7 +215,7 @@ func TestDeleteReactionForPostWithRestrictedDM(t *testing.T) {
 func TestSharedChannelSyncForReactionActions(t *testing.T) {
 	mainHelper.Parallel(t)
 	t.Run("adding a reaction in a shared channel performs a content sync when sync service is running on that node", func(t *testing.T) {
-		th := setupSharedChannels(t).InitBasic()
+		th := setupSharedChannels(t).InitBasic(t)
 
 		sharedChannelService := NewMockSharedChannelService(th.Server.GetSharedChannelSyncService())
 		th.Server.SetSharedChannelSyncService(sharedChannelService)
@@ -225,7 +224,7 @@ func TestSharedChannelSyncForReactionActions(t *testing.T) {
 
 		user := th.BasicUser
 
-		channel := th.CreateChannel(th.Context, th.BasicTeam, WithShared(true))
+		channel := th.CreateChannel(t, th.BasicTeam, WithShared(true))
 
 		post, err := th.App.CreatePost(th.Context, &model.Post{
 			UserId:    user.Id,
@@ -242,16 +241,13 @@ func TestSharedChannelSyncForReactionActions(t *testing.T) {
 
 		_, err = th.App.SaveReactionForPost(th.Context, reaction)
 		require.Nil(t, err, "Adding a reaction should not error")
-
-		th.TearDown() // We need to enforce teardown because reaction instrumentation happens in a goroutine
-
 		assert.Len(t, sharedChannelService.channelNotifications, 2)
 		assert.Equal(t, channel.Id, sharedChannelService.channelNotifications[0])
 		assert.Equal(t, channel.Id, sharedChannelService.channelNotifications[1])
 	})
 
 	t.Run("removing a reaction in a shared channel performs a content sync when sync service is running on that node", func(t *testing.T) {
-		th := setupSharedChannels(t).InitBasic()
+		th := setupSharedChannels(t).InitBasic(t)
 
 		sharedChannelService := NewMockSharedChannelService(th.Server.GetSharedChannelSyncService())
 		th.Server.SetSharedChannelSyncService(sharedChannelService)
@@ -260,7 +256,7 @@ func TestSharedChannelSyncForReactionActions(t *testing.T) {
 
 		user := th.BasicUser
 
-		channel := th.CreateChannel(th.Context, th.BasicTeam, WithShared(true))
+		channel := th.CreateChannel(t, th.BasicTeam, WithShared(true))
 
 		post, err := th.App.CreatePost(th.Context, &model.Post{
 			UserId:    user.Id,
@@ -277,23 +273,19 @@ func TestSharedChannelSyncForReactionActions(t *testing.T) {
 
 		err = th.App.DeleteReactionForPost(th.Context, reaction)
 		require.Nil(t, err, "Adding a reaction should not error")
-
-		th.TearDown() // We need to enforce teardown because reaction instrumentation happens in a goroutine
-
 		assert.Len(t, sharedChannelService.channelNotifications, 2)
 		assert.Equal(t, channel.Id, sharedChannelService.channelNotifications[0])
 		assert.Equal(t, channel.Id, sharedChannelService.channelNotifications[1])
 	})
 }
 
-func (th *TestHelper) UpdateConfig(f func(*model.Config)) {
+func (th *TestHelper) UpdateConfig(tb testing.TB, f func(*model.Config)) {
 	if th.ConfigStore.IsReadOnly() {
 		return
 	}
 	old := th.ConfigStore.Get()
 	updated := old.Clone()
 	f(updated)
-	if _, _, err := th.ConfigStore.Set(updated); err != nil {
-		panic(err)
-	}
+	_, _, err := th.ConfigStore.Set(updated)
+	require.NoError(tb, err)
 }
