@@ -11,8 +11,7 @@ import (
 
 func TestProcessSlackText(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	if th.App.ProcessSlackText(th.Context, "<!channel> foo <!channel>") != "@channel foo @channel" {
 		t.Fail()
@@ -35,8 +34,7 @@ func TestProcessSlackText(t *testing.T) {
 
 func TestProcessSlackAnnouncement(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	userID := th.BasicUser.Id
 	username := th.BasicUser.Username
