@@ -54,7 +54,14 @@ func setupTestHelper(dbStore store.Store, enterprise bool, includeCacheLayer boo
 	*memoryConfig.PluginSettings.ClientDirectory = filepath.Join(tempWorkspace, "webapp")
 	*memoryConfig.PluginSettings.AutomaticPrepackagedPlugins = false
 	*memoryConfig.LogSettings.EnableSentry = false // disable error reporting during tests
-	*memoryConfig.LogSettings.ConsoleLevel = mlog.LvlStdLog.Name
+
+	// Check for environment variable override for console log level (useful for debugging tests)
+	consoleLevel := os.Getenv("MM_LOGSETTINGS_CONSOLELEVEL")
+	if consoleLevel == "" {
+		consoleLevel = mlog.LvlStdLog.Name
+	}
+	*memoryConfig.LogSettings.ConsoleLevel = consoleLevel
+
 	_, _, err = memoryStore.Set(memoryConfig)
 	require.NoError(tb, err)
 
@@ -88,6 +95,7 @@ func setupTestHelper(dbStore store.Store, enterprise bool, includeCacheLayer boo
 		LogBuffer:         buffer,
 		TestLogger:        testLogger,
 		IncludeCacheLayer: includeCacheLayer,
+		tempWorkspace:     tempWorkspace,
 	}
 
 	if enterprise {
@@ -130,10 +138,6 @@ func setupTestHelper(dbStore store.Store, enterprise bool, includeCacheLayer boo
 		*cfg.PasswordSettings.Number = false
 	})
 
-	if th.tempWorkspace == "" {
-		th.tempWorkspace = tempWorkspace
-	}
-
 	tb.Cleanup(func() {
 		if th.IncludeCacheLayer {
 			// Clean all the caches
@@ -141,19 +145,8 @@ func setupTestHelper(dbStore store.Store, enterprise bool, includeCacheLayer boo
 			require.Nil(tb, appErr)
 		}
 
-		done := make(chan bool)
-		go func() {
-			th.Server.Shutdown()
-			close(done)
-		}()
+		th.ShutdownApp()
 
-		select {
-		case <-done:
-		case <-time.After(30 * time.Second):
-			// Use require.FailNow to terminate all tests in this package, otherwise the
-			// still running App could spuriously fail subsequent tests.
-			require.FailNow(tb, "failed to shutdown App within 30 seconds")
-		}
 		if th.tempWorkspace != "" {
 			os.RemoveAll(th.tempWorkspace)
 		}
@@ -162,6 +155,22 @@ func setupTestHelper(dbStore store.Store, enterprise bool, includeCacheLayer boo
 	return th
 }
 
+func (th *TestHelper) ShutdownApp() {
+	done := make(chan bool)
+	go func() {
+		th.Server.Shutdown()
+		close(done)
+	}()
+
+	select {
+	case <-done:
+	case <-time.After(30 * time.Second):
+		// panic instead of fatal to terminate all tests in this package, otherwise the
+		// still running App could spuriously fail subsequent tests.
+		panic("failed to shutdown App within 30 seconds")
+	}
+}
+
 func getLicense(enterprise bool, cfg *model.Config) *model.License {
 	if *cfg.ConnectedWorkspacesSettings.EnableRemoteClusterService || *cfg.ConnectedWorkspacesSettings.EnableSharedChannels {
 		return model.NewTestLicenseSKU(model.LicenseShortSkuProfessional)
