@@ -11,11 +11,12 @@ import (
 	"path/filepath"
 	"testing"
 
+	"github.com/goccy/go-yaml"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
-	"gopkg.in/yaml.v3"
 
 	"github.com/mattermost/mattermost/server/public/model"
+	"github.com/mattermost/mattermost/server/public/shared/request"
 	smocks "github.com/mattermost/mattermost/server/v8/channels/store/storetest/mocks"
 	"github.com/mattermost/mattermost/server/v8/channels/utils/fileutils"
 	"github.com/mattermost/mattermost/server/v8/config"
@@ -24,7 +25,6 @@ import (
 func TestGenerateSupportPacket(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	err := th.App.SetPhase2PermissionsMigrationStatus(true)
 	require.NoError(t, err)
@@ -272,7 +272,6 @@ func TestGenerateSupportPacket(t *testing.T) {
 func TestGetPluginsFile(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	getJobList := func(t *testing.T) *model.SupportPacketPluginList {
 		t.Helper()
@@ -336,14 +335,13 @@ func TestGetPluginsFile(t *testing.T) {
 
 func TestGetSupportPacketStats(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t)
 
-	generateStats := func(t *testing.T) *model.SupportPacketStats {
+	generateStats := func(t *testing.T, rctx request.CTX, a *App) *model.SupportPacketStats {
 		t.Helper()
 
-		require.NoError(t, th.App.Srv().Store().Post().RefreshPostStats())
+		require.NoError(t, a.Srv().Store().Post().RefreshPostStats())
 
-		fileData, err := th.App.getSupportPacketStats(th.Context)
+		fileData, err := a.getSupportPacketStats(rctx)
 		require.NotNil(t, fileData)
 		assert.Equal(t, "stats.yaml", fileData.Filename)
 		assert.Positive(t, len(fileData.Body))
@@ -356,8 +354,10 @@ func TestGetSupportPacketStats(t *testing.T) {
 		return &packet
 	}
 
+	th := Setup(t)
+
 	t.Run("fresh server", func(t *testing.T) {
-		sp := generateStats(t)
+		sp := generateStats(t, th.Context, th.App)
 
 		assert.Equal(t, int64(0), sp.RegisteredUsers)
 		assert.Equal(t, int64(0), sp.ActiveUsers)
@@ -377,29 +377,29 @@ func TestGetSupportPacketStats(t *testing.T) {
 	t.Run("Happy path", func(t *testing.T) {
 		var user *model.User
 		for range 4 {
-			user = th.CreateUser()
+			user = th.CreateUser(t)
 		}
 		th.BasicUser = user
 
 		for range 3 {
-			deactivatedUser := th.CreateUser()
+			deactivatedUser := th.CreateUser(t)
 			require.NotNil(t, deactivatedUser)
 			_, appErr := th.App.UpdateActive(th.Context, deactivatedUser, false)
 			require.Nil(t, appErr)
 		}
 
 		for range 2 {
-			guest := th.CreateGuest()
+			guest := th.CreateGuest(t)
 			require.NotNil(t, guest)
 		}
 
-		th.CreateBot()
+		th.CreateBot(t)
 
-		team := th.CreateTeam()
-		channel := th.CreateChannel(th.Context, team)
+		team := th.CreateTeam(t)
+		channel := th.CreateChannel(t, team)
 
 		for range 3 {
-			p := th.CreatePost(channel)
+			p := th.CreatePost(t, channel)
 			require.NotNil(t, p)
 		}
 
@@ -426,7 +426,7 @@ func TestGetSupportPacketStats(t *testing.T) {
 		require.Nil(t, appErr)
 		require.NotNil(t, webhookOut)
 
-		sp := generateStats(t)
+		sp := generateStats(t, th.Context, th.App)
 
 		assert.Equal(t, int64(9), sp.RegisteredUsers)
 		assert.Equal(t, int64(6), sp.ActiveUsers)
@@ -443,31 +443,27 @@ func TestGetSupportPacketStats(t *testing.T) {
 		assert.Equal(t, int64(1), sp.OutgoingWebhooks)
 	})
 
-	// Reset test server
-	th.TearDown()
-	th = Setup(t).InitBasic()
-	defer th.TearDown()
-
 	t.Run("post count should be present if number of users extends AnalyticsSettings.MaxUsersForStatistics", func(t *testing.T) {
+		// Setup a new test helper
+		th := Setup(t).InitBasic(t)
 		th.App.UpdateConfig(func(cfg *model.Config) {
 			cfg.AnalyticsSettings.MaxUsersForStatistics = model.NewPointer(1)
 		})
 
 		for range 5 {
-			p := th.CreatePost(th.BasicChannel)
+			p := th.CreatePost(t, th.BasicChannel)
 			require.NotNil(t, p)
 		}
 
-		// InitBasic() already creats 5 posts
-		packet := generateStats(t)
-		assert.Equal(t, int64(10), packet.Posts)
+		// InitBasic(t) already creats 5 posts
+		sp := generateStats(t, th.Context, th.App)
+		assert.Equal(t, int64(10), sp.Posts)
 	})
 }
 
 func TestGetSupportPacketJobList(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	getJobList := func(t *testing.T) *model.SupportPacketJobList {
 		t.Helper()
@@ -574,8 +570,7 @@ func TestGetSupportPacketJobList(t *testing.T) {
 
 func TestGetSupportPacketPermissionsInfo(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	err := th.App.SetPhase2PermissionsMigrationStatus(true)
 	require.NoError(t, err)
@@ -662,7 +657,6 @@ func TestGetSupportPacketPermissionsInfo(t *testing.T) {
 func TestGetSupportPacketMetadata(t *testing.T) {
 	mainHelper.Parallel(t)
 	th := Setup(t)
-	defer th.TearDown()
 
 	t.Run("Happy path", func(t *testing.T) {
 		fileData, err := th.App.getSupportPacketMetadata(th.Context)
@@ -683,7 +677,6 @@ func TestGetSupportPacketMetadata(t *testing.T) {
 
 func TestGetSupportPacketDatabaseSchema(t *testing.T) {
 	th := Setup(t)
-	defer th.TearDown()
 
 	// Mock store for testing
 	mockStore := &smocks.Store{}
