@@ -18,8 +18,7 @@ import (
 //nolint:govet // The setup code leads to a lot of variable shadowing.
 func TestCreateDefaultMemberships(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
 	singersTeam, err := th.App.CreateTeam(th.Context, &model.Team{
 		DisplayName: "Singers",
@@ -353,7 +352,7 @@ func TestCreateDefaultMemberships(t *testing.T) {
 	}
 
 	t.Run("Team with restricted domains skips over members that do not match the allowed domains", func(t *testing.T) {
-		restrictedUser := th.CreateUser()
+		restrictedUser := th.CreateUser(t)
 		restrictedUser.Email = "restricted@mattermost.org"
 		_, err = th.App.UpdateUser(th.Context, restrictedUser, false)
 		require.Nil(t, err)
@@ -502,11 +501,11 @@ func TestCreateDefaultMemberships(t *testing.T) {
 	})
 
 	t.Run("error should contain a information about all users that failed", func(t *testing.T) {
-		user1 := th.CreateUser()
+		user1 := th.CreateUser(t)
 		_, err = th.App.UpsertGroupMember(scienceGroup.Id, user1.Id)
 		require.Nil(t, err)
 
-		user2 := th.CreateUser()
+		user2 := th.CreateUser(t)
 		_, err = th.App.UpsertGroupMember(scienceGroup.Id, user2.Id)
 		require.Nil(t, err)
 
@@ -544,10 +543,9 @@ func (us *mokeUserStore) Get(_ context.Context, id string) (*model.User, error)
 
 func TestDeleteGroupMemberships(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
-	group := th.CreateGroup()
+	group := th.CreateGroup(t)
 
 	userIDs := []string{th.BasicUser.Id, th.BasicUser2.Id, th.SystemAdminUser.Id}
 
@@ -612,19 +610,18 @@ func TestDeleteGroupMemberships(t *testing.T) {
 
 func TestSyncSyncableRoles(t *testing.T) {
 	mainHelper.Parallel(t)
-	th := Setup(t).InitBasic()
-	defer th.TearDown()
+	th := Setup(t).InitBasic(t)
 
-	team := th.CreateTeam()
+	team := th.CreateTeam(t)
 
-	channel := th.CreateChannel(th.Context, team)
+	channel := th.CreateChannel(t, team)
 	channel.GroupConstrained = model.NewPointer(true)
 	channel, err := th.App.UpdateChannel(th.Context, channel)
 	require.Nil(t, err)
 
-	user1 := th.CreateUser()
-	user2 := th.CreateUser()
-	group := th.CreateGroup()
+	user1 := th.CreateUser(t)
+	user2 := th.CreateUser(t)
+	group := th.CreateGroup(t)
 
 	teamSyncable, err := th.App.UpsertGroupSyncable(&model.GroupSyncable{
 		SyncableId: team.Id,
@@ -649,7 +646,7 @@ func TestSyncSyncableRoles(t *testing.T) {
 		require.Nil(t, err)
 		require.False(t, tm.SchemeAdmin)
 
-		cm := th.AddUserToChannel(user, channel)
+		cm := th.AddUserToChannel(t, user, channel)
 		require.False(t, cm.SchemeAdmin)
 	}
 
