@@ -4,25 +4,17 @@
 package teams
 
 import (
-	"flag"
 	"testing"
 
 	"github.com/mattermost/mattermost/server/v8/channels/testlib"
 )
 
 var mainHelper *testlib.MainHelper
-var replicaFlag bool
 
 func TestMain(m *testing.M) {
-	if f := flag.Lookup("mysql-replica"); f == nil {
-		flag.BoolVar(&replicaFlag, "mysql-replica", false, "")
-		flag.Parse()
-	}
-
 	var options = testlib.HelperOptions{
 		EnableStore:     true,
 		EnableResources: true,
-		WithReadReplica: replicaFlag,
 	}
 
 	mainHelper = testlib.NewMainHelperWithOptions(&options)
