@@ -23,12 +23,12 @@ var searchFileInfoStoreTests = []searchTest{
 	{
 		Name: "Should be able to search posts using pagination",
 		Fn:   testFileInfoSearchFileInfosWithPagination,
-		Tags: []string{EngineElasticSearch, EngineBleve},
+		Tags: []string{EngineElasticSearch},
 	},
 	{
 		Name: "Should be able to search for exact phrases in quotes",
 		Fn:   testFileInfoSearchExactPhraseInQuotes,
-		Tags: []string{EnginePostgres, EngineMySQL, EngineElasticSearch},
+		Tags: []string{EnginePostgres, EngineElasticSearch},
 	},
 	{
 		Name: "Should be able to search for email addresses with or without quotes",
@@ -93,12 +93,12 @@ var searchFileInfoStoreTests = []searchTest{
 	{
 		Name: "Should be able to exclude messages that contain a search term",
 		Fn:   testFileInfoFilterFilesWithATerm,
-		Tags: []string{EngineMySQL, EnginePostgres},
+		Tags: []string{EnginePostgres},
 	},
 	{
 		Name: "Should be able to search using boolean operators",
 		Fn:   testFileInfoSearchUsingBooleanOperators,
-		Tags: []string{EngineMySQL, EnginePostgres, EngineElasticSearch},
+		Tags: []string{EnginePostgres, EngineElasticSearch},
 	},
 	{
 		Name: "Should be able to search with combined filters",
@@ -108,7 +108,7 @@ var searchFileInfoStoreTests = []searchTest{
 	{
 		Name: "Should be able to ignore stop words",
 		Fn:   testFileInfoSearchIgnoringStopWords,
-		Tags: []string{EngineMySQL, EngineElasticSearch},
+		Tags: []string{EngineElasticSearch},
 	},
 	{
 		Name: "Should support search stemming",
@@ -139,12 +139,12 @@ var searchFileInfoStoreTests = []searchTest{
 	{
 		Name: "Should support terms with underscore",
 		Fn:   testFileInfoSupportTermsWithUnderscore,
-		Tags: []string{EngineMySQL, EngineElasticSearch},
+		Tags: []string{EngineElasticSearch},
 	},
 	{
 		Name: "Should be able to search in deleted/archived channels",
 		Fn:   testFileInfoSearchInDeletedOrArchivedChannels,
-		Tags: []string{EngineMySQL, EnginePostgres},
+		Tags: []string{EnginePostgres},
 	},
 	{
 		Name:        "Should be able to search terms with dashes",
@@ -161,7 +161,7 @@ var searchFileInfoStoreTests = []searchTest{
 	{
 		Name: "Should be able to search terms with underscores",
 		Fn:   testFileInfoSearchTermsWithUnderscores,
-		Tags: []string{EngineMySQL, EngineElasticSearch},
+		Tags: []string{EngineElasticSearch},
 	},
 	{
 		Name: "Should be able to combine stemming and wildcards",
@@ -176,7 +176,7 @@ var searchFileInfoStoreTests = []searchTest{
 	{
 		Name: "Should not support slash as character separator",
 		Fn:   testFileInfoSlashShouldNotBeCharSeparator,
-		Tags: []string{EngineMySQL, EngineElasticSearch},
+		Tags: []string{EngineElasticSearch},
 	},
 	{
 		Name: "Should be able to search emails without quoting them",
@@ -191,12 +191,12 @@ var searchFileInfoStoreTests = []searchTest{
 	{
 		Name: "Should not search files not attached to a post",
 		Fn:   testFileInfoSearchNoResultForPostlessFileInfos,
-		Tags: []string{EnginePostgres, EngineMySQL},
+		Tags: []string{EnginePostgres},
 	},
 	{
 		Name: "Should search files part of channel bookmarks",
 		Fn:   testFileInfoSearchShowChannelBookmarkFiles,
-		Tags: []string{EnginePostgres, EngineMySQL, EngineElasticSearch},
+		Tags: []string{EnginePostgres, EngineElasticSearch},
 	},
 	{
 		Name: "Should search files across teams",
