@@ -23,7 +23,7 @@ var searchPostStoreTests = []searchTest{
 	{
 		Name: "Should be able to search posts using pagination",
 		Fn:   testSearchPostsWithPagination,
-		Tags: []string{EngineElasticSearch, EngineBleve},
+		Tags: []string{EngineElasticSearch},
 	},
 	{
 		Name: "Should return pinned and unpinned posts",
@@ -33,12 +33,12 @@ var searchPostStoreTests = []searchTest{
 	{
 		Name: "Should be able to search for quoted patterns with AND OR combinations",
 		Fn:   testSearchANDORQuotesCombinations,
-		Tags: []string{EnginePostgres, EngineMySQL, EngineElasticSearch},
+		Tags: []string{EnginePostgres, EngineElasticSearch},
 	},
 	{
 		Name: "Should be able to search without stemming",
 		Fn:   testStemming,
-		Tags: []string{EnginePostgres, EngineMySQL},
+		Tags: []string{EnginePostgres},
 	},
 	{
 		// Postgres supports search with and without quotes
@@ -50,7 +50,7 @@ var searchPostStoreTests = []searchTest{
 		// MySql supports search with quotes only
 		Name: "Should be able to search for email addresses with quotes",
 		Fn:   testSearchEmailAddressesWithQuotes,
-		Tags: []string{EngineMySQL},
+		Tags: []string{EngineElasticSearch},
 	},
 	{
 		Name: "Should be able to search when markdown underscores are applied",
@@ -105,12 +105,12 @@ var searchPostStoreTests = []searchTest{
 	{
 		Name: "Should be able to exclude messages that contain a search term",
 		Fn:   testFilterMessagesWithATerm,
-		Tags: []string{EngineMySQL, EnginePostgres},
+		Tags: []string{EnginePostgres},
 	},
 	{
 		Name: "Should be able to search using boolean operators",
 		Fn:   testSearchUsingBooleanOperators,
-		Tags: []string{EngineMySQL, EnginePostgres, EngineElasticSearch},
+		Tags: []string{EnginePostgres, EngineElasticSearch},
 	},
 	{
 		Name: "Should be able to search with combined filters",
@@ -120,7 +120,7 @@ var searchPostStoreTests = []searchTest{
 	{
 		Name: "Should be able to ignore stop words",
 		Fn:   testSearchIgnoringStopWords,
-		Tags: []string{EngineMySQL, EngineElasticSearch},
+		Tags: []string{EngineElasticSearch},
 	},
 	{
 		Name: "Should support search stemming",
@@ -151,7 +151,7 @@ var searchPostStoreTests = []searchTest{
 	{
 		Name: "Should support terms with underscore",
 		Fn:   testSupportTermsWithUnderscore,
-		Tags: []string{EngineMySQL, EngineElasticSearch},
+		Tags: []string{EngineElasticSearch},
 	},
 	{
 		Name: "Should search or exclude post using hashtags",
@@ -216,7 +216,7 @@ var searchPostStoreTests = []searchTest{
 	{
 		Name: "Should be able to search in deleted/archived channels",
 		Fn:   testSearchInDeletedOrArchivedChannels,
-		Tags: []string{EngineMySQL, EnginePostgres},
+		Tags: []string{EnginePostgres},
 	},
 	{
 		Name:        "Should be able to search terms with dashes",
@@ -233,7 +233,7 @@ var searchPostStoreTests = []searchTest{
 	{
 		Name: "Should be able to search terms with underscores",
 		Fn:   testSearchTermsWithUnderscores,
-		Tags: []string{EngineMySQL, EngineElasticSearch},
+		Tags: []string{EngineElasticSearch},
 	},
 	{
 		Name: "Should be able to search posts made by bot accounts",
@@ -258,7 +258,7 @@ var searchPostStoreTests = []searchTest{
 	{
 		Name: "Should not support slash as character separator",
 		Fn:   testSlashShouldNotBeCharSeparator,
-		Tags: []string{EngineMySQL, EngineElasticSearch},
+		Tags: []string{EngineElasticSearch},
 	},
 	{
 		Name: "Should be able to search in comments",
@@ -268,7 +268,7 @@ var searchPostStoreTests = []searchTest{
 	{
 		Name: "Should be able to search terms within links",
 		Fn:   testSupportSearchTermsWithinLinks,
-		Tags: []string{EngineMySQL, EngineElasticSearch},
+		Tags: []string{EngineElasticSearch},
 	},
 	{
 		Name: "Should not return links that are embedded in markdown",
