@@ -7,17 +7,7 @@ import (
 	"context"
 
 	"github.com/mattermost/mattermost/server/public/shared/request"
-)
-
-// storeContextKey is the base type for all context keys for the store.
-type storeContextKey string
-
-// contextValue is a type to hold some pre-determined context values.
-type contextValue string
-
-// Different possible values of contextValue.
-const (
-	useMaster contextValue = "useMaster"
+	"github.com/mattermost/mattermost/server/v8/channels/store"
 )
 
 // WithMaster adds the context value that master DB should be selected for this request.
@@ -25,24 +15,17 @@ const (
 // Deprecated: This method is deprecated and there's ongoing change to use `request.CTX` across
 // instead of `context.Context`. Please use `RequestContextWithMaster` instead.
 func WithMaster(ctx context.Context) context.Context {
-	return context.WithValue(ctx, storeContextKey(useMaster), true)
+	return store.WithMaster(ctx)
 }
 
 // RequestContextWithMaster adds the context value that master DB should be selected for this request.
-func RequestContextWithMaster(c request.CTX) request.CTX {
-	ctx := WithMaster(c.Context())
-	c = c.WithContext(ctx)
-	return c
+func RequestContextWithMaster(rctx request.CTX) request.CTX {
+	return store.RequestContextWithMaster(rctx)
 }
 
 // HasMaster is a helper function to check whether master DB should be selected or not.
 func HasMaster(ctx context.Context) bool {
-	if v := ctx.Value(storeContextKey(useMaster)); v != nil {
-		if res, ok := v.(bool); ok && res {
-			return true
-		}
-	}
-	return false
+	return store.HasMaster(ctx)
 }
 
 // DBXFromContext is a helper utility that returns the sqlx DB handle from a given context.
