@@ -16,7 +16,9 @@ func TestAccessControlPolicyStore(t *testing.T, rctx request.CTX, ss store.Store
 	t.Run("Save", func(t *testing.T) { testAccessControlPolicyStoreSaveAndGet(t, rctx, ss) })
 	t.Run("Delete", func(t *testing.T) { testAccessControlPolicyStoreDelete(t, rctx, ss) })
 	t.Run("SetActive", func(t *testing.T) { testAccessControlPolicyStoreSetActive(t, rctx, ss) })
+	t.Run("SetActiveMultiple", func(t *testing.T) { testAccessControlPolicyStoreSetActiveMultiple(t, rctx, ss) })
 	t.Run("GetAll", func(t *testing.T) { testAccessControlPolicyStoreGetAll(t, rctx, ss) })
+	t.Run("Search", func(t *testing.T) { testAccessControlPolicyStoreSearch(t, rctx, ss) })
 }
 
 func testAccessControlPolicyStoreSaveAndGet(t *testing.T, rctx request.CTX, ss store.Store) {
@@ -307,7 +309,7 @@ func testAccessControlPolicyStoreGetAll(t *testing.T, rctx request.CTX, ss store
 		},
 	}
 	t.Cleanup(func() {
-		err = ss.AccessControlPolicy().Delete(rctx, id)
+		err = ss.AccessControlPolicy().Delete(rctx, id3)
 		require.NoError(t, err)
 	})
 
@@ -403,3 +405,141 @@ func testAccessControlPolicyStoreGetAll(t *testing.T, rctx request.CTX, ss store
 		require.Equal(t, parentPolicy.ID, policies[0].ID)
 	})
 }
+
+func testAccessControlPolicyStoreSearch(t *testing.T, rctx request.CTX, ss store.Store) {
+	t.Run("ensure paging works fine", func(t *testing.T) {
+		ids := make([]string, 0, 15)
+		// Create 15 policies
+		for i := range 15 {
+			policy := &model.AccessControlPolicy{
+				ID:       model.NewId(),
+				Name:     "Policy " + string(rune('A'+i)),
+				Type:     model.AccessControlPolicyTypeChannel,
+				Active:   true,
+				Revision: 1,
+				Version:  model.AccessControlPolicyVersionV0_2,
+				Imports:  []string{},
+				Rules: []model.AccessControlPolicyRule{
+					{
+						Actions:    []string{"action"},
+						Expression: "user.properties.program == \"engineering\"",
+					},
+				},
+			}
+
+			policy, err := ss.AccessControlPolicy().Save(rctx, policy)
+			require.NoError(t, err)
+			require.NotNil(t, policy)
+			ids = append(ids, policy.ID)
+		}
+
+		t.Cleanup(func() {
+			// Clean up created policies
+			for _, id := range ids {
+				err := ss.AccessControlPolicy().Delete(rctx, id)
+				require.NoError(t, err)
+			}
+		})
+
+		// firt page should get 10
+		policies, _, err := ss.AccessControlPolicy().SearchPolicies(rctx, model.AccessControlPolicySearch{
+			Limit: 10,
+		})
+		require.NoError(t, err)
+		require.NotNil(t, policies)
+		require.Len(t, policies, 10)
+
+		// second page should get only 5
+		policies, _, err = ss.AccessControlPolicy().SearchPolicies(rctx, model.AccessControlPolicySearch{
+			Limit: 10,
+			Cursor: model.AccessControlPolicyCursor{
+				ID: policies[len(policies)-1].ID,
+			},
+		})
+		require.NoError(t, err)
+		require.NotNil(t, policies)
+		require.Len(t, policies, 5)
+
+		// should get all 15 when no paging
+		policies, _, err = ss.AccessControlPolicy().SearchPolicies(rctx, model.AccessControlPolicySearch{
+			Limit: 20,
+		})
+		require.NoError(t, err)
+		require.NotNil(t, policies)
+		require.Len(t, policies, 15)
+	})
+}
+
+func testAccessControlPolicyStoreSetActiveMultiple(t *testing.T, rctx request.CTX, ss store.Store) {
+	t.Run("Set active status for multiple policies", func(t *testing.T) {
+		policy1 := &model.AccessControlPolicy{
+			ID:       model.NewId(),
+			Name:     "Policy1",
+			Type:     model.AccessControlPolicyTypeChannel,
+			Active:   false,
+			Revision: 1,
+			Version:  model.AccessControlPolicyVersionV0_2,
+			Imports:  []string{},
+			Rules: []model.AccessControlPolicyRule{
+				{
+					Actions:    []string{"action1"},
+					Expression: "user.properties.program == \"engineering\"",
+				},
+			},
+		}
+
+		policy2 := &model.AccessControlPolicy{
+			ID:       model.NewId(),
+			Name:     "Policy2",
+			Type:     model.AccessControlPolicyTypeParent,
+			Active:   false,
+			Revision: 1,
+			Version:  model.AccessControlPolicyVersionV0_2,
+			Imports:  []string{},
+			Rules: []model.AccessControlPolicyRule{
+				{
+					Actions:    []string{"action2"},
+					Expression: "user.properties.department == \"sales\"",
+				},
+			},
+		}
+
+		policy1, err := ss.AccessControlPolicy().Save(rctx, policy1)
+		require.NoError(t, err)
+		require.NotNil(t, policy1)
+
+		policy2, err = ss.AccessControlPolicy().Save(rctx, policy2)
+		require.NoError(t, err)
+		require.NotNil(t, policy2)
+
+		t.Cleanup(func() {
+			err = ss.AccessControlPolicy().Delete(rctx, policy1.ID)
+			require.NoError(t, err)
+			err = ss.AccessControlPolicy().Delete(rctx, policy2.ID)
+			require.NoError(t, err)
+		})
+
+		updates := []model.AccessControlPolicyActiveUpdate{
+			{ID: policy1.ID, Active: true},
+			{ID: policy2.ID, Active: true},
+		}
+
+		updatedPolicies, err := ss.AccessControlPolicy().SetActiveStatusMultiple(rctx, updates)
+		require.NoError(t, err)
+		require.Len(t, updatedPolicies, 2)
+
+		for _, p := range updatedPolicies {
+			require.True(t, p.Active)
+		}
+
+		p1, err := ss.AccessControlPolicy().Get(rctx, policy1.ID)
+		require.NoError(t, err)
+		require.NotNil(t, p1)
+		require.True(t, p1.Active)
+
+		p2, err := ss.AccessControlPolicy().Get(rctx, policy2.ID)
+		require.NoError(t, err)
+		require.NotNil(t, p2)
+		require.True(t, p2.Active)
+	})
+}
