@@ -4,8 +4,6 @@
 package storetest
 
 import (
-	"fmt"
-
 	"github.com/mattermost/mattermost/server/public/model"
 )
 
@@ -22,15 +20,7 @@ func NewTestID() string {
 	return string(newID)
 }
 
-// Adds backtiks to the column name for MySQL, this is required if
-// the column name is a reserved keyword.
-//
-//	`ColumnName` -  MySQL
-//	ColumnName   -  Postgres
+// Returns the column name for PostgreSQL.
 func quoteColumnName(driver string, columnName string) string {
-	if driver == model.DatabaseDriverMysql {
-		return fmt.Sprintf("`%s`", columnName)
-	}
-
 	return columnName
 }
