@@ -757,6 +757,17 @@ func (c *Context) RequireInvoiceId() *Context {
 	return c
 }
 
+func (c *Context) RequireContentReviewerId() *Context {
+	if c.Err != nil {
+		return c
+	}
+
+	if !model.IsValidId(c.Params.ContentReviewerId) {
+		c.SetInvalidURLParam("content_reviewer_id")
+	}
+	return c
+}
+
 func (c *Context) GetRemoteID(r *http.Request) string {
 	return r.Header.Get(model.HeaderRemoteclusterId)
 }
