@@ -37,34 +37,14 @@ type testHelper struct {
 	disableAutoConfig bool
 }
 
-// Setup creates an instance of testHelper.
-func Setup(tb testing.TB) *testHelper {
-	dir, err := testlib.SetupTestResources()
-	if err != nil {
-		panic("failed to create temporary directory: " + err.Error())
-	}
-
-	api4TestHelper := api4.Setup(tb)
-
-	testHelper := &testHelper{
-		TestHelper:     api4TestHelper,
-		tempDir:        dir,
-		configFilePath: filepath.Join(dir, "config-helper.json"),
-	}
-
-	config := &model.Config{}
-	config.SetDefaults()
-	testHelper.SetConfig(config)
-
-	return testHelper
-}
-
 // Setup creates an instance of testHelper.
 func SetupWithStoreMock(tb testing.TB) *testHelper {
 	dir, err := testlib.SetupTestResources()
-	if err != nil {
-		panic("failed to create temporary directory: " + err.Error())
-	}
+	require.NoError(tb, err)
+	tb.Cleanup(func() {
+		err = os.RemoveAll(dir)
+		require.NoError(tb, err)
+	})
 
 	api4TestHelper := api4.SetupWithStoreMock(tb)
 	systemStore := mocks.SystemStore{}
@@ -88,8 +68,8 @@ func SetupWithStoreMock(tb testing.TB) *testHelper {
 }
 
 // InitBasic simply proxies to api4.InitBasic, while still returning a testHelper.
-func (h *testHelper) InitBasic() *testHelper {
-	h.TestHelper.InitBasic()
+func (h *testHelper) InitBasic(tb testing.TB) *testHelper {
+	h.TestHelper.InitBasic(tb)
 	return h
 }
 
@@ -137,12 +117,6 @@ func (h *testHelper) SetAutoConfig(autoConfig bool) {
 	h.disableAutoConfig = !autoConfig
 }
 
-// TearDown cleans up temporary files and assets created during the life of the test helper.
-func (h *testHelper) TearDown() {
-	h.TestHelper.TearDown()
-	os.RemoveAll(h.tempDir)
-}
-
 func (h *testHelper) execArgs(t *testing.T, args []string) []string {
 	ret := []string{"-test.v", "-test.run", "ExecCommand"}
 	if coverprofile := flag.Lookup("test.coverprofile").Value.String(); coverprofile != "" {
