@@ -50,13 +50,8 @@ func (s *MmctlE2ETestSuite) SetupTest() {
 }
 
 func (s *MmctlE2ETestSuite) TearDownTest() {
-	// if a test helper was used, we run the teardown and remove it
-	// from the structure to avoid reusing the same helper between
-	// tests
-	if s.th != nil {
-		s.th.TearDown()
-		s.th = nil
-	}
+	// Remove the test helper from the structure to avoid reusing the same helper between tests
+	s.th = nil
 }
 
 func (s *MmctlE2ETestSuite) SetupTestHelper() *api4.TestHelper {
@@ -78,7 +73,7 @@ func (s *MmctlE2ETestSuite) SetupMessageExportTestHelper() *api4.TestHelper {
 	}
 
 	jobs.DefaultWatcherPollingInterval = 100
-	s.th = api4.SetupEnterprise(s.T()).InitBasic()
+	s.th = api4.SetupEnterprise(s.T()).InitBasic(s.T())
 	s.th.App.Srv().SetLicense(model.NewTestLicense("message_export"))
 	s.th.App.UpdateConfig(func(cfg *model.Config) {
 		*cfg.MessageExportSettings.DownloadExportResults = true
