@@ -13,7 +13,7 @@ import (
 )
 
 func (s *MmctlE2ETestSuite) TestShowRoleCmd() {
-	s.SetupEnterpriseTestHelper().InitBasic()
+	s.SetupEnterpriseTestHelper().InitBasic(s.T())
 
 	s.RunForAllClients("MM-T3928 Should allow all users to see a role", func(c client.Client) {
 		printer.Clean()
@@ -35,7 +35,7 @@ func (s *MmctlE2ETestSuite) TestShowRoleCmd() {
 }
 
 func (s *MmctlE2ETestSuite) TestAddPermissionsCmd() {
-	s.SetupEnterpriseTestHelper().InitBasic()
+	s.SetupEnterpriseTestHelper().InitBasic(s.T())
 
 	role, appErr := s.th.App.GetRoleByName(s.th.Context, model.SystemUserRoleId)
 	s.Require().Nil(appErr)
@@ -71,7 +71,7 @@ func (s *MmctlE2ETestSuite) TestAddPermissionsCmd() {
 }
 
 func (s *MmctlE2ETestSuite) TestRemovePermissionsCmd() {
-	s.SetupEnterpriseTestHelper().InitBasic()
+	s.SetupEnterpriseTestHelper().InitBasic(s.T())
 
 	role, appErr := s.th.App.GetRoleByName(s.th.Context, model.SystemUserRoleId)
 	s.Require().Nil(appErr)
