@@ -21,8 +21,7 @@ func BenchmarkDiff(b *testing.B) {
 	b.Run("equal empty", func(b *testing.B) {
 		baseCfg := &model.Config{}
 		actualCfg := &model.Config{}
-		b.ResetTimer()
-		for i := 0; i < b.N; i++ {
+		for b.Loop() {
 			_, _ = Diff(baseCfg, actualCfg)
 		}
 	})
@@ -30,8 +29,7 @@ func BenchmarkDiff(b *testing.B) {
 	b.Run("equal with defaults", func(b *testing.B) {
 		baseCfg := defaultConfigGen()
 		actualCfg := defaultConfigGen()
-		b.ResetTimer()
-		for i := 0; i < b.N; i++ {
+		for b.Loop() {
 			_, _ = Diff(baseCfg, actualCfg)
 		}
 	})
@@ -39,8 +37,7 @@ func BenchmarkDiff(b *testing.B) {
 	b.Run("actual empty", func(b *testing.B) {
 		baseCfg := defaultConfigGen()
 		actualCfg := &model.Config{}
-		b.ResetTimer()
-		for i := 0; i < b.N; i++ {
+		for b.Loop() {
 			_, _ = Diff(baseCfg, actualCfg)
 		}
 	})
@@ -48,8 +45,7 @@ func BenchmarkDiff(b *testing.B) {
 	b.Run("base empty", func(b *testing.B) {
 		baseCfg := &model.Config{}
 		actualCfg := defaultConfigGen()
-		b.ResetTimer()
-		for i := 0; i < b.N; i++ {
+		for b.Loop() {
 			_, _ = Diff(baseCfg, actualCfg)
 		}
 	})
@@ -68,8 +64,7 @@ func BenchmarkDiff(b *testing.B) {
 			"ds1",
 			"ds2",
 		}
-		b.ResetTimer()
-		for i := 0; i < b.N; i++ {
+		for b.Loop() {
 			_, _ = Diff(baseCfg, actualCfg)
 		}
 	})
