@@ -13,9 +13,10 @@ import (
 	"net/mail"
 	"net/smtp"
 	"slices"
+	"strings"
 	"time"
 
-	"github.com/jaytaylor/html2text"
+	"code.sajari.com/docconv/v2"
 	"github.com/pkg/errors"
 	gomail "gopkg.in/mail.v2"
 
@@ -293,11 +294,10 @@ func sendMail(c smtpClient, mail mailData, date time.Time, config *SMTPConfig) e
 	mlog.Info("sending mail", mlog.String("to", mail.smtpTo), mlog.String("subject", mail.subject))
 
 	htmlMessage := mail.htmlBody
-
-	txtBody, err := html2text.FromString(mail.htmlBody)
+	text, _, err := docconv.ConvertHTML(strings.NewReader(htmlMessage), true)
 	if err != nil {
 		mlog.Warn("Unable to convert html body to text", mlog.Err(err))
-		txtBody = ""
+		text = ""
 	}
 
 	headers := map[string][]string{
@@ -345,7 +345,7 @@ func sendMail(c smtpClient, mail mailData, date time.Time, config *SMTPConfig) e
 	m := gomail.NewMessage(gomail.SetCharset("UTF-8"))
 	m.SetHeaders(headers)
 	m.SetDateHeader("Date", date)
-	m.SetBody("text/plain", txtBody)
+	m.SetBody("text/plain", text)
 	m.AddAlternative("text/html", htmlMessage)
 
 	for name, reader := range mail.embeddedFiles {
