@@ -68,7 +68,12 @@ type SupportPacketDiagnostics struct {
 		ServerVersion string `yaml:"server_version,omitempty"`
 	} `yaml:"ldap"`
 
+	SAML struct {
+		ProviderType string `yaml:"provider_type,omitempty"`
+	} `yaml:"saml"`
+
 	ElasticSearch struct {
+		Backend       string   `yaml:"backend,omitempty"`
 		ServerVersion string   `yaml:"server_version,omitempty"`
 		ServerPlugins []string `yaml:"server_plugins,omitempty"`
 		Error         string   `yaml:"error,omitempty"`
