@@ -99,6 +99,9 @@ const (
 	WebsocketEventCPAFieldDeleted                     WebsocketEventType = "custom_profile_attributes_field_deleted"
 	WebsocketEventCPAValuesUpdated                    WebsocketEventType = "custom_profile_attributes_values_updated"
 	WebsocketContentFlaggingReportValueUpdated        WebsocketEventType = "content_flagging_report_value_updated"
+	WebsocketEventPostRevealed                        WebsocketEventType = "post_revealed"
+	WebsocketEventPostBurned                          WebsocketEventType = "post_burned"
+	WebsocketEventBurnOnReadAllRevealed               WebsocketEventType = "burn_on_read_all_revealed"
 
 	WebSocketMsgTypeResponse = "response"
 	WebSocketMsgTypeEvent    = "event"
@@ -218,6 +221,7 @@ type WebSocketEvent struct {
 	broadcast       *WebsocketBroadcast
 	sequence        int64
 	precomputedJSON *precomputedWebSocketEventJSON
+	rejected        bool
 }
 
 // PrecomputeJSON precomputes and stores the serialized JSON for all fields other than Sequence.
@@ -450,3 +454,11 @@ func WebSocketResponseFromJSON(data io.Reader) (*WebSocketResponse, error) {
 	var o *WebSocketResponse
 	return o, json.NewDecoder(data).Decode(&o)
 }
+
+func (ev *WebSocketEvent) Reject() {
+	ev.rejected = true
+}
+
+func (ev *WebSocketEvent) IsRejected() bool {
+	return ev.rejected
+}
