@@ -60,12 +60,23 @@ func (w *httpResponseWriterRPCServer) SyncHeader(args http.Header, reply *struct
 	return nil
 }
 
+func (w *httpResponseWriterRPCServer) Flush(args struct{}, reply *struct{}) error {
+	// Type assert to http.Flusher and flush if supported
+	if flusher, ok := w.w.(http.Flusher); ok {
+		flusher.Flush()
+	}
+	// If the underlying writer doesn't support Flusher, silently ignore
+	// This matches the HTTP spec's "best effort" semantics
+	return nil
+}
+
 type httpResponseWriterRPCClient struct {
 	client *rpc.Client
 	header http.Header
 }
 
 var _ http.ResponseWriter = (*httpResponseWriterRPCClient)(nil)
+var _ http.Flusher = (*httpResponseWriterRPCClient)(nil)
 
 func (w *httpResponseWriterRPCClient) Header() http.Header {
 	if w.header == nil {
@@ -91,6 +102,12 @@ func (w *httpResponseWriterRPCClient) WriteHeader(statusCode int) {
 	w.client.Call("Plugin.WriteHeader", statusCode, nil)
 }
 
+// Flush implements http.Flusher interface
+func (w *httpResponseWriterRPCClient) Flush() {
+	// Best-effort flush - ignore errors per HTTP spec
+	w.client.Call("Plugin.Flush", struct{}{}, nil)
+}
+
 func (w *httpResponseWriterRPCClient) Close() error {
 	return w.client.Close()
 }
