@@ -14,6 +14,7 @@ import (
 	"os"
 	"os/exec"
 	"path/filepath"
+	"slices"
 	"strings"
 	"text/template"
 
@@ -612,12 +613,7 @@ func removeExcluded(info *PluginInterfaceInfo, excluded []string) *PluginInterfa
 		FileSet: info.FileSet,
 	}
 	toBeExcluded := func(item string) bool {
-		for _, exclusion := range excluded {
-			if exclusion == item {
-				return true
-			}
-		}
-		return false
+		return slices.Contains(excluded, item)
 	}
 	hooksResult := make([]IHookEntry, 0, len(info.Hooks))
 	for _, hook := range info.Hooks {
