@@ -12,6 +12,7 @@ import (
 	"log"
 	"maps"
 	"os"
+	"slices"
 	"strings"
 	"sync/atomic"
 	"time"
@@ -69,7 +70,7 @@ func (lc LoggerConfiguration) Append(cfg LoggerConfiguration) {
 	maps.Copy(lc, cfg)
 }
 
-func (lc LoggerConfiguration) IsValid() error {
+func (lc LoggerConfiguration) IsValid(validLevels []Level) error {
 	logger, err := logr.New()
 	if err != nil {
 		return errors.Wrap(err, "failed to create logger")
@@ -81,6 +82,19 @@ func (lc LoggerConfiguration) IsValid() error {
 		return errors.Wrap(err, "logger configuration is invalid")
 	}
 
+	validLevelIDs := make([]logr.LevelID, 0, len(validLevels))
+	for _, l := range validLevels {
+		validLevelIDs = append(validLevelIDs, l.ID)
+	}
+
+	for _, c := range lc {
+		for _, l := range c.Levels {
+			if !slices.Contains(validLevelIDs, l.ID) {
+				return errors.Errorf("invalid log level id %d", l.ID)
+			}
+		}
+	}
+
 	return nil
 }
 
